// GENERATED FILE
// ALL CHANGES MADE IN THIS FOLDER WILL BE LOST!

#[test]
fn test() {
    use crate::{find_raw, find_tz, time_zone};

    const TIME_ZONES: &[(&tz::TimeZoneRef<'static>, &[u8], &[&[u8]])] = &[
        (&time_zone::africa::ACCRA, time_zone::africa::RAW_ACCRA, &[
            b"Africa/Accra",
            b"africa/accra",
            b"AFRICA/ACCRA",
            b"aFRICA/aCCRA",
            b"AfRiCa/aCcRa",
            b"aFrIcA/AcCrA",
        ]),
        (
            &time_zone::africa::ADDIS_ABABA,
            time_zone::africa::RAW_ADDIS_ABABA,
            &[
                b"Africa/Addis_Ababa",
                b"africa/addis_ababa",
                b"AFRICA/ADDIS_ABABA",
                b"aFRICA/aDDIS_aBABA",
                b"AfRiCa/aDdIs_aBaBa",
                b"aFrIcA/AdDiS_AbAbA",
            ],
        ),
        (
            &time_zone::africa::ALGIERS,
            time_zone::africa::RAW_ALGIERS,
            &[
                b"Africa/Algiers",
                b"africa/algiers",
                b"AFRICA/ALGIERS",
                b"aFRICA/aLGIERS",
                b"AfRiCa/aLgIeRs",
                b"aFrIcA/AlGiErS",
            ],
        ),
        (
            &time_zone::africa::ASMARA,
            time_zone::africa::RAW_ASMARA,
            &[
                b"Africa/Asmara",
                b"africa/asmara",
                b"AFRICA/ASMARA",
                b"aFRICA/aSMARA",
                b"AfRiCa/aSmArA",
                b"aFrIcA/AsMaRa",
            ],
        ),
        (
            &time_zone::africa::ASMERA,
            time_zone::africa::RAW_ASMERA,
            &[
                b"Africa/Asmera",
                b"africa/asmera",
                b"AFRICA/ASMERA",
                b"aFRICA/aSMERA",
                b"AfRiCa/aSmErA",
                b"aFrIcA/AsMeRa",
            ],
        ),
        (
            &time_zone::africa::NAIROBI,
            time_zone::africa::RAW_NAIROBI,
            &[
                b"Africa/Nairobi",
                b"africa/nairobi",
                b"AFRICA/NAIROBI",
                b"aFRICA/nAIROBI",
                b"AfRiCa/nAiRoBi",
                b"aFrIcA/NaIrObI",
            ],
        ),
        (
            &time_zone::africa::BAMAKO,
            time_zone::africa::RAW_BAMAKO,
            &[
                b"Africa/Bamako",
                b"africa/bamako",
                b"AFRICA/BAMAKO",
                b"aFRICA/bAMAKO",
                b"AfRiCa/bAmAkO",
                b"aFrIcA/BaMaKo",
            ],
        ),
        (
            &time_zone::africa::BANGUI,
            time_zone::africa::RAW_BANGUI,
            &[
                b"Africa/Bangui",
                b"africa/bangui",
                b"AFRICA/BANGUI",
                b"aFRICA/bANGUI",
                b"AfRiCa/bAnGuI",
                b"aFrIcA/BaNgUi",
            ],
        ),
        (
            &time_zone::africa::BANJUL,
            time_zone::africa::RAW_BANJUL,
            &[
                b"Africa/Banjul",
                b"africa/banjul",
                b"AFRICA/BANJUL",
                b"aFRICA/bANJUL",
                b"AfRiCa/bAnJuL",
                b"aFrIcA/BaNjUl",
            ],
        ),
        (
            &time_zone::africa::BISSAU,
            time_zone::africa::RAW_BISSAU,
            &[
                b"Africa/Bissau",
                b"africa/bissau",
                b"AFRICA/BISSAU",
                b"aFRICA/bISSAU",
                b"AfRiCa/bIsSaU",
                b"aFrIcA/BiSsAu",
            ],
        ),
        (
            &time_zone::africa::BLANTYRE,
            time_zone::africa::RAW_BLANTYRE,
            &[
                b"Africa/Blantyre",
                b"africa/blantyre",
                b"AFRICA/BLANTYRE",
                b"aFRICA/bLANTYRE",
                b"AfRiCa/bLaNtYrE",
                b"aFrIcA/BlAnTyRe",
            ],
        ),
        (
            &time_zone::africa::BRAZZAVILLE,
            time_zone::africa::RAW_BRAZZAVILLE,
            &[
                b"Africa/Brazzaville",
                b"africa/brazzaville",
                b"AFRICA/BRAZZAVILLE",
                b"aFRICA/bRAZZAVILLE",
                b"AfRiCa/bRaZzAvIlLe",
                b"aFrIcA/BrAzZaViLlE",
            ],
        ),
        (
            &time_zone::africa::BUJUMBURA,
            time_zone::africa::RAW_BUJUMBURA,
            &[
                b"Africa/Bujumbura",
                b"africa/bujumbura",
                b"AFRICA/BUJUMBURA",
                b"aFRICA/bUJUMBURA",
                b"AfRiCa/bUjUmBuRa",
                b"aFrIcA/BuJuMbUrA",
            ],
        ),
        (
            &time_zone::africa::CASABLANCA,
            time_zone::africa::RAW_CASABLANCA,
            &[
                b"Africa/Casablanca",
                b"africa/casablanca",
                b"AFRICA/CASABLANCA",
                b"aFRICA/cASABLANCA",
                b"AfRiCa/cAsAbLaNcA",
                b"aFrIcA/CaSaBlAnCa",
            ],
        ),
        (&time_zone::africa::CEUTA, time_zone::africa::RAW_CEUTA, &[
            b"Africa/Ceuta",
            b"africa/ceuta",
            b"AFRICA/CEUTA",
            b"aFRICA/cEUTA",
            b"AfRiCa/cEuTa",
            b"aFrIcA/CeUtA",
        ]),
        (
            &time_zone::africa::CONAKRY,
            time_zone::africa::RAW_CONAKRY,
            &[
                b"Africa/Conakry",
                b"africa/conakry",
                b"AFRICA/CONAKRY",
                b"aFRICA/cONAKRY",
                b"AfRiCa/cOnAkRy",
                b"aFrIcA/CoNaKrY",
            ],
        ),
        (&time_zone::africa::DAKAR, time_zone::africa::RAW_DAKAR, &[
            b"Africa/Dakar",
            b"africa/dakar",
            b"AFRICA/DAKAR",
            b"aFRICA/dAKAR",
            b"AfRiCa/dAkAr",
            b"aFrIcA/DaKaR",
        ]),
        (
            &time_zone::africa::DAR_ES_SALAAM,
            time_zone::africa::RAW_DAR_ES_SALAAM,
            &[
                b"Africa/Dar_es_Salaam",
                b"africa/dar_es_salaam",
                b"AFRICA/DAR_ES_SALAAM",
                b"aFRICA/dAR_ES_sALAAM",
                b"AfRiCa/dAr_eS_SaLaAm",
                b"aFrIcA/DaR_Es_sAlAaM",
            ],
        ),
        (
            &time_zone::africa::DJIBOUTI,
            time_zone::africa::RAW_DJIBOUTI,
            &[
                b"Africa/Djibouti",
                b"africa/djibouti",
                b"AFRICA/DJIBOUTI",
                b"aFRICA/dJIBOUTI",
                b"AfRiCa/dJiBoUtI",
                b"aFrIcA/DjIbOuTi",
            ],
        ),
        (
            &time_zone::africa::DOUALA,
            time_zone::africa::RAW_DOUALA,
            &[
                b"Africa/Douala",
                b"africa/douala",
                b"AFRICA/DOUALA",
                b"aFRICA/dOUALA",
                b"AfRiCa/dOuAlA",
                b"aFrIcA/DoUaLa",
            ],
        ),
        (
            &time_zone::africa::EL_AAIUN,
            time_zone::africa::RAW_EL_AAIUN,
            &[
                b"Africa/El_Aaiun",
                b"africa/el_aaiun",
                b"AFRICA/EL_AAIUN",
                b"aFRICA/eL_aAIUN",
                b"AfRiCa/eL_AaIuN",
                b"aFrIcA/El_aAiUn",
            ],
        ),
        (
            &time_zone::africa::FREETOWN,
            time_zone::africa::RAW_FREETOWN,
            &[
                b"Africa/Freetown",
                b"africa/freetown",
                b"AFRICA/FREETOWN",
                b"aFRICA/fREETOWN",
                b"AfRiCa/fReEtOwN",
                b"aFrIcA/FrEeToWn",
            ],
        ),
        (
            &time_zone::africa::GABORONE,
            time_zone::africa::RAW_GABORONE,
            &[
                b"Africa/Gaborone",
                b"africa/gaborone",
                b"AFRICA/GABORONE",
                b"aFRICA/gABORONE",
                b"AfRiCa/gAbOrOnE",
                b"aFrIcA/GaBoRoNe",
            ],
        ),
        (
            &time_zone::africa::HARARE,
            time_zone::africa::RAW_HARARE,
            &[
                b"Africa/Harare",
                b"africa/harare",
                b"AFRICA/HARARE",
                b"aFRICA/hARARE",
                b"AfRiCa/hArArE",
                b"aFrIcA/HaRaRe",
            ],
        ),
        (
            &time_zone::africa::JOHANNESBURG,
            time_zone::africa::RAW_JOHANNESBURG,
            &[
                b"Africa/Johannesburg",
                b"africa/johannesburg",
                b"AFRICA/JOHANNESBURG",
                b"aFRICA/jOHANNESBURG",
                b"AfRiCa/jOhAnNeSbUrG",
                b"aFrIcA/JoHaNnEsBuRg",
            ],
        ),
        (&time_zone::africa::JUBA, time_zone::africa::RAW_JUBA, &[
            b"Africa/Juba",
            b"africa/juba",
            b"AFRICA/JUBA",
            b"aFRICA/jUBA",
            b"AfRiCa/jUbA",
            b"aFrIcA/JuBa",
        ]),
        (
            &time_zone::africa::KAMPALA,
            time_zone::africa::RAW_KAMPALA,
            &[
                b"Africa/Kampala",
                b"africa/kampala",
                b"AFRICA/KAMPALA",
                b"aFRICA/kAMPALA",
                b"AfRiCa/kAmPaLa",
                b"aFrIcA/KaMpAlA",
            ],
        ),
        (
            &time_zone::africa::KHARTOUM,
            time_zone::africa::RAW_KHARTOUM,
            &[
                b"Africa/Khartoum",
                b"africa/khartoum",
                b"AFRICA/KHARTOUM",
                b"aFRICA/kHARTOUM",
                b"AfRiCa/kHaRtOuM",
                b"aFrIcA/KhArToUm",
            ],
        ),
        (
            &time_zone::africa::KIGALI,
            time_zone::africa::RAW_KIGALI,
            &[
                b"Africa/Kigali",
                b"africa/kigali",
                b"AFRICA/KIGALI",
                b"aFRICA/kIGALI",
                b"AfRiCa/kIgAlI",
                b"aFrIcA/KiGaLi",
            ],
        ),
        (
            &time_zone::africa::KINSHASA,
            time_zone::africa::RAW_KINSHASA,
            &[
                b"Africa/Kinshasa",
                b"africa/kinshasa",
                b"AFRICA/KINSHASA",
                b"aFRICA/kINSHASA",
                b"AfRiCa/kInShAsA",
                b"aFrIcA/KiNsHaSa",
            ],
        ),
        (&time_zone::africa::LAGOS, time_zone::africa::RAW_LAGOS, &[
            b"Africa/Lagos",
            b"africa/lagos",
            b"AFRICA/LAGOS",
            b"aFRICA/lAGOS",
            b"AfRiCa/lAgOs",
            b"aFrIcA/LaGoS",
        ]),
        (
            &time_zone::africa::LIBREVILLE,
            time_zone::africa::RAW_LIBREVILLE,
            &[
                b"Africa/Libreville",
                b"africa/libreville",
                b"AFRICA/LIBREVILLE",
                b"aFRICA/lIBREVILLE",
                b"AfRiCa/lIbReViLlE",
                b"aFrIcA/LiBrEvIlLe",
            ],
        ),
        (&time_zone::africa::LOME, time_zone::africa::RAW_LOME, &[
            b"Africa/Lome",
            b"africa/lome",
            b"AFRICA/LOME",
            b"aFRICA/lOME",
            b"AfRiCa/lOmE",
            b"aFrIcA/LoMe",
        ]),
        (
            &time_zone::africa::LUANDA,
            time_zone::africa::RAW_LUANDA,
            &[
                b"Africa/Luanda",
                b"africa/luanda",
                b"AFRICA/LUANDA",
                b"aFRICA/lUANDA",
                b"AfRiCa/lUaNdA",
                b"aFrIcA/LuAnDa",
            ],
        ),
        (
            &time_zone::africa::LUBUMBASHI,
            time_zone::africa::RAW_LUBUMBASHI,
            &[
                b"Africa/Lubumbashi",
                b"africa/lubumbashi",
                b"AFRICA/LUBUMBASHI",
                b"aFRICA/lUBUMBASHI",
                b"AfRiCa/lUbUmBaShI",
                b"aFrIcA/LuBuMbAsHi",
            ],
        ),
        (
            &time_zone::africa::LUSAKA,
            time_zone::africa::RAW_LUSAKA,
            &[
                b"Africa/Lusaka",
                b"africa/lusaka",
                b"AFRICA/LUSAKA",
                b"aFRICA/lUSAKA",
                b"AfRiCa/lUsAkA",
                b"aFrIcA/LuSaKa",
            ],
        ),
        (
            &time_zone::africa::MALABO,
            time_zone::africa::RAW_MALABO,
            &[
                b"Africa/Malabo",
                b"africa/malabo",
                b"AFRICA/MALABO",
                b"aFRICA/mALABO",
                b"AfRiCa/mAlAbO",
                b"aFrIcA/MaLaBo",
            ],
        ),
        (
            &time_zone::africa::MAPUTO,
            time_zone::africa::RAW_MAPUTO,
            &[
                b"Africa/Maputo",
                b"africa/maputo",
                b"AFRICA/MAPUTO",
                b"aFRICA/mAPUTO",
                b"AfRiCa/mApUtO",
                b"aFrIcA/MaPuTo",
            ],
        ),
        (
            &time_zone::africa::MASERU,
            time_zone::africa::RAW_MASERU,
            &[
                b"Africa/Maseru",
                b"africa/maseru",
                b"AFRICA/MASERU",
                b"aFRICA/mASERU",
                b"AfRiCa/mAsErU",
                b"aFrIcA/MaSeRu",
            ],
        ),
        (
            &time_zone::africa::MBABANE,
            time_zone::africa::RAW_MBABANE,
            &[
                b"Africa/Mbabane",
                b"africa/mbabane",
                b"AFRICA/MBABANE",
                b"aFRICA/mBABANE",
                b"AfRiCa/mBaBaNe",
                b"aFrIcA/MbAbAnE",
            ],
        ),
        (
            &time_zone::africa::MOGADISHU,
            time_zone::africa::RAW_MOGADISHU,
            &[
                b"Africa/Mogadishu",
                b"africa/mogadishu",
                b"AFRICA/MOGADISHU",
                b"aFRICA/mOGADISHU",
                b"AfRiCa/mOgAdIsHu",
                b"aFrIcA/MoGaDiShU",
            ],
        ),
        (
            &time_zone::africa::MONROVIA,
            time_zone::africa::RAW_MONROVIA,
            &[
                b"Africa/Monrovia",
                b"africa/monrovia",
                b"AFRICA/MONROVIA",
                b"aFRICA/mONROVIA",
                b"AfRiCa/mOnRoViA",
                b"aFrIcA/MoNrOvIa",
            ],
        ),
        (
            &time_zone::africa::NDJAMENA,
            time_zone::africa::RAW_NDJAMENA,
            &[
                b"Africa/Ndjamena",
                b"africa/ndjamena",
                b"AFRICA/NDJAMENA",
                b"aFRICA/nDJAMENA",
                b"AfRiCa/nDjAmEnA",
                b"aFrIcA/NdJaMeNa",
            ],
        ),
        (
            &time_zone::africa::NIAMEY,
            time_zone::africa::RAW_NIAMEY,
            &[
                b"Africa/Niamey",
                b"africa/niamey",
                b"AFRICA/NIAMEY",
                b"aFRICA/nIAMEY",
                b"AfRiCa/nIaMeY",
                b"aFrIcA/NiAmEy",
            ],
        ),
        (
            &time_zone::africa::NOUAKCHOTT,
            time_zone::africa::RAW_NOUAKCHOTT,
            &[
                b"Africa/Nouakchott",
                b"africa/nouakchott",
                b"AFRICA/NOUAKCHOTT",
                b"aFRICA/nOUAKCHOTT",
                b"AfRiCa/nOuAkChOtT",
                b"aFrIcA/NoUaKcHoTt",
            ],
        ),
        (
            &time_zone::africa::OUAGADOUGOU,
            time_zone::africa::RAW_OUAGADOUGOU,
            &[
                b"Africa/Ouagadougou",
                b"africa/ouagadougou",
                b"AFRICA/OUAGADOUGOU",
                b"aFRICA/oUAGADOUGOU",
                b"AfRiCa/oUaGaDoUgOu",
                b"aFrIcA/OuAgAdOuGoU",
            ],
        ),
        (
            &time_zone::africa::PORTO_NOVO,
            time_zone::africa::RAW_PORTO_NOVO,
            &[
                b"Africa/Porto-Novo",
                b"africa/porto-novo",
                b"AFRICA/PORTO-NOVO",
                b"aFRICA/pORTO-nOVO",
                b"AfRiCa/pOrTo-nOvO",
                b"aFrIcA/PoRtO-NoVo",
            ],
        ),
        (
            &time_zone::africa::SAO_TOME,
            time_zone::africa::RAW_SAO_TOME,
            &[
                b"Africa/Sao_Tome",
                b"africa/sao_tome",
                b"AFRICA/SAO_TOME",
                b"aFRICA/sAO_tOME",
                b"AfRiCa/sAo_tOmE",
                b"aFrIcA/SaO_ToMe",
            ],
        ),
        (&time_zone::africa::TUNIS, time_zone::africa::RAW_TUNIS, &[
            b"Africa/Tunis",
            b"africa/tunis",
            b"AFRICA/TUNIS",
            b"aFRICA/tUNIS",
            b"AfRiCa/tUnIs",
            b"aFrIcA/TuNiS",
        ]),
        (
            &time_zone::africa::WINDHOEK,
            time_zone::africa::RAW_WINDHOEK,
            &[
                b"Africa/Windhoek",
                b"africa/windhoek",
                b"AFRICA/WINDHOEK",
                b"aFRICA/wINDHOEK",
                b"AfRiCa/wInDhOeK",
                b"aFrIcA/WiNdHoEk",
            ],
        ),
        (&time_zone::america::ADAK, time_zone::america::RAW_ADAK, &[
            b"America/Adak",
            b"america/adak",
            b"AMERICA/ADAK",
            b"aMERICA/aDAK",
            b"AmErIcA/AdAk",
            b"aMeRiCa/aDaK",
        ]),
        (&time_zone::america::ATKA, time_zone::america::RAW_ATKA, &[
            b"America/Atka",
            b"america/atka",
            b"AMERICA/ATKA",
            b"aMERICA/aTKA",
            b"AmErIcA/AtKa",
            b"aMeRiCa/aTkA",
        ]),
        (&time_zone::us::ALEUTIAN, time_zone::us::RAW_ALEUTIAN, &[
            b"US/Aleutian",
            b"us/aleutian",
            b"US/ALEUTIAN",
            b"us/aLEUTIAN",
            b"Us/aLeUtIaN",
            b"uS/AlEuTiAn",
        ]),
        (
            &time_zone::america::ANCHORAGE,
            time_zone::america::RAW_ANCHORAGE,
            &[
                b"America/Anchorage",
                b"america/anchorage",
                b"AMERICA/ANCHORAGE",
                b"aMERICA/aNCHORAGE",
                b"AmErIcA/AnChOrAgE",
                b"aMeRiCa/aNcHoRaGe",
            ],
        ),
        (&time_zone::us::ALASKA, time_zone::us::RAW_ALASKA, &[
            b"US/Alaska",
            b"us/alaska",
            b"US/ALASKA",
            b"us/aLASKA",
            b"Us/aLaSkA",
            b"uS/AlAsKa",
        ]),
        (
            &time_zone::america::ANGUILLA,
            time_zone::america::RAW_ANGUILLA,
            &[
                b"America/Anguilla",
                b"america/anguilla",
                b"AMERICA/ANGUILLA",
                b"aMERICA/aNGUILLA",
                b"AmErIcA/AnGuIlLa",
                b"aMeRiCa/aNgUiLlA",
            ],
        ),
        (
            &time_zone::america::ANTIGUA,
            time_zone::america::RAW_ANTIGUA,
            &[
                b"America/Antigua",
                b"america/antigua",
                b"AMERICA/ANTIGUA",
                b"aMERICA/aNTIGUA",
                b"AmErIcA/AnTiGuA",
                b"aMeRiCa/aNtIgUa",
            ],
        ),
        (
            &time_zone::america::ARAGUAINA,
            time_zone::america::RAW_ARAGUAINA,
            &[
                b"America/Araguaina",
                b"america/araguaina",
                b"AMERICA/ARAGUAINA",
                b"aMERICA/aRAGUAINA",
                b"AmErIcA/ArAgUaInA",
                b"aMeRiCa/aRaGuAiNa",
            ],
        ),
        (
            &time_zone::america_argentina::LA_RIOJA,
            time_zone::america_argentina::RAW_LA_RIOJA,
            &[
                b"America/Argentina/La_Rioja",
                b"america/argentina/la_rioja",
                b"AMERICA/ARGENTINA/LA_RIOJA",
                b"aMERICA/aRGENTINA/lA_rIOJA",
                b"AmErIcA/ArGeNtInA/La_rIoJa",
                b"aMeRiCa/aRgEnTiNa/lA_RiOjA",
            ],
        ),
        (
            &time_zone::america_argentina::RIO_GALLEGOS,
            time_zone::america_argentina::RAW_RIO_GALLEGOS,
            &[
                b"America/Argentina/Rio_Gallegos",
                b"america/argentina/rio_gallegos",
                b"AMERICA/ARGENTINA/RIO_GALLEGOS",
                b"aMERICA/aRGENTINA/rIO_gALLEGOS",
                b"AmErIcA/ArGeNtInA/RiO_GaLlEgOs",
                b"aMeRiCa/aRgEnTiNa/rIo_gAlLeGoS",
            ],
        ),
        (
            &time_zone::america_argentina::SALTA,
            time_zone::america_argentina::RAW_SALTA,
            &[
                b"America/Argentina/Salta",
                b"america/argentina/salta",
                b"AMERICA/ARGENTINA/SALTA",
                b"aMERICA/aRGENTINA/sALTA",
                b"AmErIcA/ArGeNtInA/SaLtA",
                b"aMeRiCa/aRgEnTiNa/sAlTa",
            ],
        ),
        (
            &time_zone::america_argentina::SAN_JUAN,
            time_zone::america_argentina::RAW_SAN_JUAN,
            &[
                b"America/Argentina/San_Juan",
                b"america/argentina/san_juan",
                b"AMERICA/ARGENTINA/SAN_JUAN",
                b"aMERICA/aRGENTINA/sAN_jUAN",
                b"AmErIcA/ArGeNtInA/SaN_JuAn",
                b"aMeRiCa/aRgEnTiNa/sAn_jUaN",
            ],
        ),
        (
            &time_zone::america_argentina::SAN_LUIS,
            time_zone::america_argentina::RAW_SAN_LUIS,
            &[
                b"America/Argentina/San_Luis",
                b"america/argentina/san_luis",
                b"AMERICA/ARGENTINA/SAN_LUIS",
                b"aMERICA/aRGENTINA/sAN_lUIS",
                b"AmErIcA/ArGeNtInA/SaN_LuIs",
                b"aMeRiCa/aRgEnTiNa/sAn_lUiS",
            ],
        ),
        (
            &time_zone::america_argentina::TUCUMAN,
            time_zone::america_argentina::RAW_TUCUMAN,
            &[
                b"America/Argentina/Tucuman",
                b"america/argentina/tucuman",
                b"AMERICA/ARGENTINA/TUCUMAN",
                b"aMERICA/aRGENTINA/tUCUMAN",
                b"AmErIcA/ArGeNtInA/TuCuMaN",
                b"aMeRiCa/aRgEnTiNa/tUcUmAn",
            ],
        ),
        (
            &time_zone::america_argentina::USHUAIA,
            time_zone::america_argentina::RAW_USHUAIA,
            &[
                b"America/Argentina/Ushuaia",
                b"america/argentina/ushuaia",
                b"AMERICA/ARGENTINA/USHUAIA",
                b"aMERICA/aRGENTINA/uSHUAIA",
                b"AmErIcA/ArGeNtInA/UsHuAiA",
                b"aMeRiCa/aRgEnTiNa/uShUaIa",
            ],
        ),
        (
            &time_zone::america::ARUBA,
            time_zone::america::RAW_ARUBA,
            &[
                b"America/Aruba",
                b"america/aruba",
                b"AMERICA/ARUBA",
                b"aMERICA/aRUBA",
                b"AmErIcA/ArUbA",
                b"aMeRiCa/aRuBa",
            ],
        ),
        (
            &time_zone::america::ASUNCION,
            time_zone::america::RAW_ASUNCION,
            &[
                b"America/Asuncion",
                b"america/asuncion",
                b"AMERICA/ASUNCION",
                b"aMERICA/aSUNCION",
                b"AmErIcA/AsUnCiOn",
                b"aMeRiCa/aSuNcIoN",
            ],
        ),
        (
            &time_zone::america::ATIKOKAN,
            time_zone::america::RAW_ATIKOKAN,
            &[
                b"America/Atikokan",
                b"america/atikokan",
                b"AMERICA/ATIKOKAN",
                b"aMERICA/aTIKOKAN",
                b"AmErIcA/AtIkOkAn",
                b"aMeRiCa/aTiKoKaN",
            ],
        ),
        (
            &time_zone::america::BAHIA,
            time_zone::america::RAW_BAHIA,
            &[
                b"America/Bahia",
                b"america/bahia",
                b"AMERICA/BAHIA",
                b"aMERICA/bAHIA",
                b"AmErIcA/BaHiA",
                b"aMeRiCa/bAhIa",
            ],
        ),
        (
            &time_zone::america::BAHIA_BANDERAS,
            time_zone::america::RAW_BAHIA_BANDERAS,
            &[
                b"America/Bahia_Banderas",
                b"america/bahia_banderas",
                b"AMERICA/BAHIA_BANDERAS",
                b"aMERICA/bAHIA_bANDERAS",
                b"AmErIcA/BaHiA_BaNdErAs",
                b"aMeRiCa/bAhIa_bAnDeRaS",
            ],
        ),
        (
            &time_zone::america::BARBADOS,
            time_zone::america::RAW_BARBADOS,
            &[
                b"America/Barbados",
                b"america/barbados",
                b"AMERICA/BARBADOS",
                b"aMERICA/bARBADOS",
                b"AmErIcA/BaRbAdOs",
                b"aMeRiCa/bArBaDoS",
            ],
        ),
        (
            &time_zone::america::BELEM,
            time_zone::america::RAW_BELEM,
            &[
                b"America/Belem",
                b"america/belem",
                b"AMERICA/BELEM",
                b"aMERICA/bELEM",
                b"AmErIcA/BeLeM",
                b"aMeRiCa/bElEm",
            ],
        ),
        (
            &time_zone::america::BELIZE,
            time_zone::america::RAW_BELIZE,
            &[
                b"America/Belize",
                b"america/belize",
                b"AMERICA/BELIZE",
                b"aMERICA/bELIZE",
                b"AmErIcA/BeLiZe",
                b"aMeRiCa/bElIzE",
            ],
        ),
        (
            &time_zone::america::BLANC_SABLON,
            time_zone::america::RAW_BLANC_SABLON,
            &[
                b"America/Blanc-Sablon",
                b"america/blanc-sablon",
                b"AMERICA/BLANC-SABLON",
                b"aMERICA/bLANC-sABLON",
                b"AmErIcA/BlAnC-SaBlOn",
                b"aMeRiCa/bLaNc-sAbLoN",
            ],
        ),
        (
            &time_zone::america::BOA_VISTA,
            time_zone::america::RAW_BOA_VISTA,
            &[
                b"America/Boa_Vista",
                b"america/boa_vista",
                b"AMERICA/BOA_VISTA",
                b"aMERICA/bOA_vISTA",
                b"AmErIcA/BoA_ViStA",
                b"aMeRiCa/bOa_vIsTa",
            ],
        ),
        (
            &time_zone::america::BOGOTA,
            time_zone::america::RAW_BOGOTA,
            &[
                b"America/Bogota",
                b"america/bogota",
                b"AMERICA/BOGOTA",
                b"aMERICA/bOGOTA",
                b"AmErIcA/BoGoTa",
                b"aMeRiCa/bOgOtA",
            ],
        ),
        (
            &time_zone::america::BOISE,
            time_zone::america::RAW_BOISE,
            &[
                b"America/Boise",
                b"america/boise",
                b"AMERICA/BOISE",
                b"aMERICA/bOISE",
                b"AmErIcA/BoIsE",
                b"aMeRiCa/bOiSe",
            ],
        ),
        (
            &time_zone::america::BUENOS_AIRES,
            time_zone::america::RAW_BUENOS_AIRES,
            &[
                b"America/Buenos_Aires",
                b"america/buenos_aires",
                b"AMERICA/BUENOS_AIRES",
                b"aMERICA/bUENOS_aIRES",
                b"AmErIcA/BuEnOs_aIrEs",
                b"aMeRiCa/bUeNoS_AiReS",
            ],
        ),
        (
            &time_zone::america_argentina::BUENOS_AIRES,
            time_zone::america_argentina::RAW_BUENOS_AIRES,
            &[
                b"America/Argentina/Buenos_Aires",
                b"america/argentina/buenos_aires",
                b"AMERICA/ARGENTINA/BUENOS_AIRES",
                b"aMERICA/aRGENTINA/bUENOS_aIRES",
                b"AmErIcA/ArGeNtInA/BuEnOs_aIrEs",
                b"aMeRiCa/aRgEnTiNa/bUeNoS_AiReS",
            ],
        ),
        (
            &time_zone::america::CAMBRIDGE_BAY,
            time_zone::america::RAW_CAMBRIDGE_BAY,
            &[
                b"America/Cambridge_Bay",
                b"america/cambridge_bay",
                b"AMERICA/CAMBRIDGE_BAY",
                b"aMERICA/cAMBRIDGE_bAY",
                b"AmErIcA/CaMbRiDgE_BaY",
                b"aMeRiCa/cAmBrIdGe_bAy",
            ],
        ),
        (
            &time_zone::america::CAMPO_GRANDE,
            time_zone::america::RAW_CAMPO_GRANDE,
            &[
                b"America/Campo_Grande",
                b"america/campo_grande",
                b"AMERICA/CAMPO_GRANDE",
                b"aMERICA/cAMPO_gRANDE",
                b"AmErIcA/CaMpO_GrAnDe",
                b"aMeRiCa/cAmPo_gRaNdE",
            ],
        ),
        (
            &time_zone::america::CANCUN,
            time_zone::america::RAW_CANCUN,
            &[
                b"America/Cancun",
                b"america/cancun",
                b"AMERICA/CANCUN",
                b"aMERICA/cANCUN",
                b"AmErIcA/CaNcUn",
                b"aMeRiCa/cAnCuN",
            ],
        ),
        (
            &time_zone::america::CARACAS,
            time_zone::america::RAW_CARACAS,
            &[
                b"America/Caracas",
                b"america/caracas",
                b"AMERICA/CARACAS",
                b"aMERICA/cARACAS",
                b"AmErIcA/CaRaCaS",
                b"aMeRiCa/cArAcAs",
            ],
        ),
        (
            &time_zone::america::CATAMARCA,
            time_zone::america::RAW_CATAMARCA,
            &[
                b"America/Catamarca",
                b"america/catamarca",
                b"AMERICA/CATAMARCA",
                b"aMERICA/cATAMARCA",
                b"AmErIcA/CaTaMaRcA",
                b"aMeRiCa/cAtAmArCa",
            ],
        ),
        (
            &time_zone::america_argentina::CATAMARCA,
            time_zone::america_argentina::RAW_CATAMARCA,
            &[
                b"America/Argentina/Catamarca",
                b"america/argentina/catamarca",
                b"AMERICA/ARGENTINA/CATAMARCA",
                b"aMERICA/aRGENTINA/cATAMARCA",
                b"AmErIcA/ArGeNtInA/CaTaMaRcA",
                b"aMeRiCa/aRgEnTiNa/cAtAmArCa",
            ],
        ),
        (
            &time_zone::america_argentina::COMOD_RIVADAVIA,
            time_zone::america_argentina::RAW_COMOD_RIVADAVIA,
            &[
                b"America/Argentina/ComodRivadavia",
                b"america/argentina/comodrivadavia",
                b"AMERICA/ARGENTINA/COMODRIVADAVIA",
                b"aMERICA/aRGENTINA/cOMODrIVADAVIA",
                b"AmErIcA/ArGeNtInA/CoMoDrIvAdAvIa",
                b"aMeRiCa/aRgEnTiNa/cOmOdRiVaDaViA",
            ],
        ),
        (
            &time_zone::america::CAYENNE,
            time_zone::america::RAW_CAYENNE,
            &[
                b"America/Cayenne",
                b"america/cayenne",
                b"AMERICA/CAYENNE",
                b"aMERICA/cAYENNE",
                b"AmErIcA/CaYeNnE",
                b"aMeRiCa/cAyEnNe",
            ],
        ),
        (
            &time_zone::america::CAYMAN,
            time_zone::america::RAW_CAYMAN,
            &[
                b"America/Cayman",
                b"america/cayman",
                b"AMERICA/CAYMAN",
                b"aMERICA/cAYMAN",
                b"AmErIcA/CaYmAn",
                b"aMeRiCa/cAyMaN",
            ],
        ),
        (
            &time_zone::america::CHIHUAHUA,
            time_zone::america::RAW_CHIHUAHUA,
            &[
                b"America/Chihuahua",
                b"america/chihuahua",
                b"AMERICA/CHIHUAHUA",
                b"aMERICA/cHIHUAHUA",
                b"AmErIcA/ChIhUaHuA",
                b"aMeRiCa/cHiHuAhUa",
            ],
        ),
        (
            &time_zone::america::CIUDAD_JUAREZ,
            time_zone::america::RAW_CIUDAD_JUAREZ,
            &[
                b"America/Ciudad_Juarez",
                b"america/ciudad_juarez",
                b"AMERICA/CIUDAD_JUAREZ",
                b"aMERICA/cIUDAD_jUAREZ",
                b"AmErIcA/CiUdAd_jUaReZ",
                b"aMeRiCa/cIuDaD_JuArEz",
            ],
        ),
        (
            &time_zone::america::CORDOBA,
            time_zone::america::RAW_CORDOBA,
            &[
                b"America/Cordoba",
                b"america/cordoba",
                b"AMERICA/CORDOBA",
                b"aMERICA/cORDOBA",
                b"AmErIcA/CoRdObA",
                b"aMeRiCa/cOrDoBa",
            ],
        ),
        (
            &time_zone::america::ROSARIO,
            time_zone::america::RAW_ROSARIO,
            &[
                b"America/Rosario",
                b"america/rosario",
                b"AMERICA/ROSARIO",
                b"aMERICA/rOSARIO",
                b"AmErIcA/RoSaRiO",
                b"aMeRiCa/rOsArIo",
            ],
        ),
        (
            &time_zone::america_argentina::CORDOBA,
            time_zone::america_argentina::RAW_CORDOBA,
            &[
                b"America/Argentina/Cordoba",
                b"america/argentina/cordoba",
                b"AMERICA/ARGENTINA/CORDOBA",
                b"aMERICA/aRGENTINA/cORDOBA",
                b"AmErIcA/ArGeNtInA/CoRdObA",
                b"aMeRiCa/aRgEnTiNa/cOrDoBa",
            ],
        ),
        (
            &time_zone::america::COSTA_RICA,
            time_zone::america::RAW_COSTA_RICA,
            &[
                b"America/Costa_Rica",
                b"america/costa_rica",
                b"AMERICA/COSTA_RICA",
                b"aMERICA/cOSTA_rICA",
                b"AmErIcA/CoStA_RiCa",
                b"aMeRiCa/cOsTa_rIcA",
            ],
        ),
        (
            &time_zone::america::COYHAIQUE,
            time_zone::america::RAW_COYHAIQUE,
            &[
                b"America/Coyhaique",
                b"america/coyhaique",
                b"AMERICA/COYHAIQUE",
                b"aMERICA/cOYHAIQUE",
                b"AmErIcA/CoYhAiQuE",
                b"aMeRiCa/cOyHaIqUe",
            ],
        ),
        (
            &time_zone::america::CRESTON,
            time_zone::america::RAW_CRESTON,
            &[
                b"America/Creston",
                b"america/creston",
                b"AMERICA/CRESTON",
                b"aMERICA/cRESTON",
                b"AmErIcA/CrEsToN",
                b"aMeRiCa/cReStOn",
            ],
        ),
        (
            &time_zone::america::CUIABA,
            time_zone::america::RAW_CUIABA,
            &[
                b"America/Cuiaba",
                b"america/cuiaba",
                b"AMERICA/CUIABA",
                b"aMERICA/cUIABA",
                b"AmErIcA/CuIaBa",
                b"aMeRiCa/cUiAbA",
            ],
        ),
        (
            &time_zone::america::CURACAO,
            time_zone::america::RAW_CURACAO,
            &[
                b"America/Curacao",
                b"america/curacao",
                b"AMERICA/CURACAO",
                b"aMERICA/cURACAO",
                b"AmErIcA/CuRaCaO",
                b"aMeRiCa/cUrAcAo",
            ],
        ),
        (
            &time_zone::america::DANMARKSHAVN,
            time_zone::america::RAW_DANMARKSHAVN,
            &[
                b"America/Danmarkshavn",
                b"america/danmarkshavn",
                b"AMERICA/DANMARKSHAVN",
                b"aMERICA/dANMARKSHAVN",
                b"AmErIcA/DaNmArKsHaVn",
                b"aMeRiCa/dAnMaRkShAvN",
            ],
        ),
        (
            &time_zone::america::DAWSON,
            time_zone::america::RAW_DAWSON,
            &[
                b"America/Dawson",
                b"america/dawson",
                b"AMERICA/DAWSON",
                b"aMERICA/dAWSON",
                b"AmErIcA/DaWsOn",
                b"aMeRiCa/dAwSoN",
            ],
        ),
        (
            &time_zone::america::DAWSON_CREEK,
            time_zone::america::RAW_DAWSON_CREEK,
            &[
                b"America/Dawson_Creek",
                b"america/dawson_creek",
                b"AMERICA/DAWSON_CREEK",
                b"aMERICA/dAWSON_cREEK",
                b"AmErIcA/DaWsOn_cReEk",
                b"aMeRiCa/dAwSoN_CrEeK",
            ],
        ),
        (
            &time_zone::america::DETROIT,
            time_zone::america::RAW_DETROIT,
            &[
                b"America/Detroit",
                b"america/detroit",
                b"AMERICA/DETROIT",
                b"aMERICA/dETROIT",
                b"AmErIcA/DeTrOiT",
                b"aMeRiCa/dEtRoIt",
            ],
        ),
        (&time_zone::us::MICHIGAN, time_zone::us::RAW_MICHIGAN, &[
            b"US/Michigan",
            b"us/michigan",
            b"US/MICHIGAN",
            b"us/mICHIGAN",
            b"Us/mIcHiGaN",
            b"uS/MiChIgAn",
        ]),
        (
            &time_zone::america::DOMINICA,
            time_zone::america::RAW_DOMINICA,
            &[
                b"America/Dominica",
                b"america/dominica",
                b"AMERICA/DOMINICA",
                b"aMERICA/dOMINICA",
                b"AmErIcA/DoMiNiCa",
                b"aMeRiCa/dOmInIcA",
            ],
        ),
        (
            &time_zone::america::EDMONTON,
            time_zone::america::RAW_EDMONTON,
            &[
                b"America/Edmonton",
                b"america/edmonton",
                b"AMERICA/EDMONTON",
                b"aMERICA/eDMONTON",
                b"AmErIcA/EdMoNtOn",
                b"aMeRiCa/eDmOnToN",
            ],
        ),
        (
            &time_zone::america::YELLOWKNIFE,
            time_zone::america::RAW_YELLOWKNIFE,
            &[
                b"America/Yellowknife",
                b"america/yellowknife",
                b"AMERICA/YELLOWKNIFE",
                b"aMERICA/yELLOWKNIFE",
                b"AmErIcA/YeLlOwKnIfE",
                b"aMeRiCa/yElLoWkNiFe",
            ],
        ),
        (
            &time_zone::canada::MOUNTAIN,
            time_zone::canada::RAW_MOUNTAIN,
            &[
                b"Canada/Mountain",
                b"canada/mountain",
                b"CANADA/MOUNTAIN",
                b"cANADA/mOUNTAIN",
                b"CaNaDa/mOuNtAiN",
                b"cAnAdA/MoUnTaIn",
            ],
        ),
        (
            &time_zone::america::EIRUNEPE,
            time_zone::america::RAW_EIRUNEPE,
            &[
                b"America/Eirunepe",
                b"america/eirunepe",
                b"AMERICA/EIRUNEPE",
                b"aMERICA/eIRUNEPE",
                b"AmErIcA/EiRuNePe",
                b"aMeRiCa/eIrUnEpE",
            ],
        ),
        (
            &time_zone::america::EL_SALVADOR,
            time_zone::america::RAW_EL_SALVADOR,
            &[
                b"America/El_Salvador",
                b"america/el_salvador",
                b"AMERICA/EL_SALVADOR",
                b"aMERICA/eL_sALVADOR",
                b"AmErIcA/El_sAlVaDoR",
                b"aMeRiCa/eL_SaLvAdOr",
            ],
        ),
        (
            &time_zone::america::ENSENADA,
            time_zone::america::RAW_ENSENADA,
            &[
                b"America/Ensenada",
                b"america/ensenada",
                b"AMERICA/ENSENADA",
                b"aMERICA/eNSENADA",
                b"AmErIcA/EnSeNaDa",
                b"aMeRiCa/eNsEnAdA",
            ],
        ),
        (
            &time_zone::america::SANTA_ISABEL,
            time_zone::america::RAW_SANTA_ISABEL,
            &[
                b"America/Santa_Isabel",
                b"america/santa_isabel",
                b"AMERICA/SANTA_ISABEL",
                b"aMERICA/sANTA_iSABEL",
                b"AmErIcA/SaNtA_IsAbEl",
                b"aMeRiCa/sAnTa_iSaBeL",
            ],
        ),
        (
            &time_zone::america::TIJUANA,
            time_zone::america::RAW_TIJUANA,
            &[
                b"America/Tijuana",
                b"america/tijuana",
                b"AMERICA/TIJUANA",
                b"aMERICA/tIJUANA",
                b"AmErIcA/TiJuAnA",
                b"aMeRiCa/tIjUaNa",
            ],
        ),
        (
            &time_zone::mexico::BAJA_NORTE,
            time_zone::mexico::RAW_BAJA_NORTE,
            &[
                b"Mexico/BajaNorte",
                b"mexico/bajanorte",
                b"MEXICO/BAJANORTE",
                b"mEXICO/bAJAnORTE",
                b"MeXiCo/bAjAnOrTe",
                b"mExIcO/BaJaNoRtE",
            ],
        ),
        (
            &time_zone::america::FORTALEZA,
            time_zone::america::RAW_FORTALEZA,
            &[
                b"America/Fortaleza",
                b"america/fortaleza",
                b"AMERICA/FORTALEZA",
                b"aMERICA/fORTALEZA",
                b"AmErIcA/FoRtAlEzA",
                b"aMeRiCa/fOrTaLeZa",
            ],
        ),
        (
            &time_zone::america::FORT_NELSON,
            time_zone::america::RAW_FORT_NELSON,
            &[
                b"America/Fort_Nelson",
                b"america/fort_nelson",
                b"AMERICA/FORT_NELSON",
                b"aMERICA/fORT_nELSON",
                b"AmErIcA/FoRt_nElSoN",
                b"aMeRiCa/fOrT_NeLsOn",
            ],
        ),
        (
            &time_zone::america::FORT_WAYNE,
            time_zone::america::RAW_FORT_WAYNE,
            &[
                b"America/Fort_Wayne",
                b"america/fort_wayne",
                b"AMERICA/FORT_WAYNE",
                b"aMERICA/fORT_wAYNE",
                b"AmErIcA/FoRt_wAyNe",
                b"aMeRiCa/fOrT_WaYnE",
            ],
        ),
        (
            &time_zone::america::INDIANAPOLIS,
            time_zone::america::RAW_INDIANAPOLIS,
            &[
                b"America/Indianapolis",
                b"america/indianapolis",
                b"AMERICA/INDIANAPOLIS",
                b"aMERICA/iNDIANAPOLIS",
                b"AmErIcA/InDiAnApOlIs",
                b"aMeRiCa/iNdIaNaPoLiS",
            ],
        ),
        (
            &time_zone::america_indiana::INDIANAPOLIS,
            time_zone::america_indiana::RAW_INDIANAPOLIS,
            &[
                b"America/Indiana/Indianapolis",
                b"america/indiana/indianapolis",
                b"AMERICA/INDIANA/INDIANAPOLIS",
                b"aMERICA/iNDIANA/iNDIANAPOLIS",
                b"AmErIcA/InDiAnA/InDiAnApOlIs",
                b"aMeRiCa/iNdIaNa/iNdIaNaPoLiS",
            ],
        ),
        (
            &time_zone::us::EAST_INDIANA,
            time_zone::us::RAW_EAST_INDIANA,
            &[
                b"US/East-Indiana",
                b"us/east-indiana",
                b"US/EAST-INDIANA",
                b"us/eAST-iNDIANA",
                b"Us/eAsT-InDiAnA",
                b"uS/EaSt-iNdIaNa",
            ],
        ),
        (
            &time_zone::america::GLACE_BAY,
            time_zone::america::RAW_GLACE_BAY,
            &[
                b"America/Glace_Bay",
                b"america/glace_bay",
                b"AMERICA/GLACE_BAY",
                b"aMERICA/gLACE_bAY",
                b"AmErIcA/GlAcE_BaY",
                b"aMeRiCa/gLaCe_bAy",
            ],
        ),
        (
            &time_zone::america::GODTHAB,
            time_zone::america::RAW_GODTHAB,
            &[
                b"America/Godthab",
                b"america/godthab",
                b"AMERICA/GODTHAB",
                b"aMERICA/gODTHAB",
                b"AmErIcA/GoDtHaB",
                b"aMeRiCa/gOdThAb",
            ],
        ),
        (&time_zone::america::NUUK, time_zone::america::RAW_NUUK, &[
            b"America/Nuuk",
            b"america/nuuk",
            b"AMERICA/NUUK",
            b"aMERICA/nUUK",
            b"AmErIcA/NuUk",
            b"aMeRiCa/nUuK",
        ]),
        (
            &time_zone::america::GOOSE_BAY,
            time_zone::america::RAW_GOOSE_BAY,
            &[
                b"America/Goose_Bay",
                b"america/goose_bay",
                b"AMERICA/GOOSE_BAY",
                b"aMERICA/gOOSE_bAY",
                b"AmErIcA/GoOsE_BaY",
                b"aMeRiCa/gOoSe_bAy",
            ],
        ),
        (
            &time_zone::america::GRAND_TURK,
            time_zone::america::RAW_GRAND_TURK,
            &[
                b"America/Grand_Turk",
                b"america/grand_turk",
                b"AMERICA/GRAND_TURK",
                b"aMERICA/gRAND_tURK",
                b"AmErIcA/GrAnD_TuRk",
                b"aMeRiCa/gRaNd_tUrK",
            ],
        ),
        (
            &time_zone::america::GRENADA,
            time_zone::america::RAW_GRENADA,
            &[
                b"America/Grenada",
                b"america/grenada",
                b"AMERICA/GRENADA",
                b"aMERICA/gRENADA",
                b"AmErIcA/GrEnAdA",
                b"aMeRiCa/gReNaDa",
            ],
        ),
        (
            &time_zone::america::GUADELOUPE,
            time_zone::america::RAW_GUADELOUPE,
            &[
                b"America/Guadeloupe",
                b"america/guadeloupe",
                b"AMERICA/GUADELOUPE",
                b"aMERICA/gUADELOUPE",
                b"AmErIcA/GuAdElOuPe",
                b"aMeRiCa/gUaDeLoUpE",
            ],
        ),
        (
            &time_zone::america::GUATEMALA,
            time_zone::america::RAW_GUATEMALA,
            &[
                b"America/Guatemala",
                b"america/guatemala",
                b"AMERICA/GUATEMALA",
                b"aMERICA/gUATEMALA",
                b"AmErIcA/GuAtEmAlA",
                b"aMeRiCa/gUaTeMaLa",
            ],
        ),
        (
            &time_zone::america::GUAYAQUIL,
            time_zone::america::RAW_GUAYAQUIL,
            &[
                b"America/Guayaquil",
                b"america/guayaquil",
                b"AMERICA/GUAYAQUIL",
                b"aMERICA/gUAYAQUIL",
                b"AmErIcA/GuAyAqUiL",
                b"aMeRiCa/gUaYaQuIl",
            ],
        ),
        (
            &time_zone::america::GUYANA,
            time_zone::america::RAW_GUYANA,
            &[
                b"America/Guyana",
                b"america/guyana",
                b"AMERICA/GUYANA",
                b"aMERICA/gUYANA",
                b"AmErIcA/GuYaNa",
                b"aMeRiCa/gUyAnA",
            ],
        ),
        (
            &time_zone::america::HALIFAX,
            time_zone::america::RAW_HALIFAX,
            &[
                b"America/Halifax",
                b"america/halifax",
                b"AMERICA/HALIFAX",
                b"aMERICA/hALIFAX",
                b"AmErIcA/HaLiFaX",
                b"aMeRiCa/hAlIfAx",
            ],
        ),
        (
            &time_zone::canada::ATLANTIC,
            time_zone::canada::RAW_ATLANTIC,
            &[
                b"Canada/Atlantic",
                b"canada/atlantic",
                b"CANADA/ATLANTIC",
                b"cANADA/aTLANTIC",
                b"CaNaDa/aTlAnTiC",
                b"cAnAdA/AtLaNtIc",
            ],
        ),
        (
            &time_zone::america::HERMOSILLO,
            time_zone::america::RAW_HERMOSILLO,
            &[
                b"America/Hermosillo",
                b"america/hermosillo",
                b"AMERICA/HERMOSILLO",
                b"aMERICA/hERMOSILLO",
                b"AmErIcA/HeRmOsIlLo",
                b"aMeRiCa/hErMoSiLlO",
            ],
        ),
        (
            &time_zone::america_indiana::MARENGO,
            time_zone::america_indiana::RAW_MARENGO,
            &[
                b"America/Indiana/Marengo",
                b"america/indiana/marengo",
                b"AMERICA/INDIANA/MARENGO",
                b"aMERICA/iNDIANA/mARENGO",
                b"AmErIcA/InDiAnA/MaReNgO",
                b"aMeRiCa/iNdIaNa/mArEnGo",
            ],
        ),
        (
            &time_zone::america_indiana::PETERSBURG,
            time_zone::america_indiana::RAW_PETERSBURG,
            &[
                b"America/Indiana/Petersburg",
                b"america/indiana/petersburg",
                b"AMERICA/INDIANA/PETERSBURG",
                b"aMERICA/iNDIANA/pETERSBURG",
                b"AmErIcA/InDiAnA/PeTeRsBuRg",
                b"aMeRiCa/iNdIaNa/pEtErSbUrG",
            ],
        ),
        (
            &time_zone::america_indiana::TELL_CITY,
            time_zone::america_indiana::RAW_TELL_CITY,
            &[
                b"America/Indiana/Tell_City",
                b"america/indiana/tell_city",
                b"AMERICA/INDIANA/TELL_CITY",
                b"aMERICA/iNDIANA/tELL_cITY",
                b"AmErIcA/InDiAnA/TeLl_cItY",
                b"aMeRiCa/iNdIaNa/tElL_CiTy",
            ],
        ),
        (
            &time_zone::america_indiana::VEVAY,
            time_zone::america_indiana::RAW_VEVAY,
            &[
                b"America/Indiana/Vevay",
                b"america/indiana/vevay",
                b"AMERICA/INDIANA/VEVAY",
                b"aMERICA/iNDIANA/vEVAY",
                b"AmErIcA/InDiAnA/VeVaY",
                b"aMeRiCa/iNdIaNa/vEvAy",
            ],
        ),
        (
            &time_zone::america_indiana::VINCENNES,
            time_zone::america_indiana::RAW_VINCENNES,
            &[
                b"America/Indiana/Vincennes",
                b"america/indiana/vincennes",
                b"AMERICA/INDIANA/VINCENNES",
                b"aMERICA/iNDIANA/vINCENNES",
                b"AmErIcA/InDiAnA/ViNcEnNeS",
                b"aMeRiCa/iNdIaNa/vInCeNnEs",
            ],
        ),
        (
            &time_zone::america_indiana::WINAMAC,
            time_zone::america_indiana::RAW_WINAMAC,
            &[
                b"America/Indiana/Winamac",
                b"america/indiana/winamac",
                b"AMERICA/INDIANA/WINAMAC",
                b"aMERICA/iNDIANA/wINAMAC",
                b"AmErIcA/InDiAnA/WiNaMaC",
                b"aMeRiCa/iNdIaNa/wInAmAc",
            ],
        ),
        (
            &time_zone::america::INUVIK,
            time_zone::america::RAW_INUVIK,
            &[
                b"America/Inuvik",
                b"america/inuvik",
                b"AMERICA/INUVIK",
                b"aMERICA/iNUVIK",
                b"AmErIcA/InUvIk",
                b"aMeRiCa/iNuViK",
            ],
        ),
        (
            &time_zone::america::IQALUIT,
            time_zone::america::RAW_IQALUIT,
            &[
                b"America/Iqaluit",
                b"america/iqaluit",
                b"AMERICA/IQALUIT",
                b"aMERICA/iQALUIT",
                b"AmErIcA/IqAlUiT",
                b"aMeRiCa/iQaLuIt",
            ],
        ),
        (
            &time_zone::america::PANGNIRTUNG,
            time_zone::america::RAW_PANGNIRTUNG,
            &[
                b"America/Pangnirtung",
                b"america/pangnirtung",
                b"AMERICA/PANGNIRTUNG",
                b"aMERICA/pANGNIRTUNG",
                b"AmErIcA/PaNgNiRtUnG",
                b"aMeRiCa/pAnGnIrTuNg",
            ],
        ),
        (
            &time_zone::america::JUJUY,
            time_zone::america::RAW_JUJUY,
            &[
                b"America/Jujuy",
                b"america/jujuy",
                b"AMERICA/JUJUY",
                b"aMERICA/jUJUY",
                b"AmErIcA/JuJuY",
                b"aMeRiCa/jUjUy",
            ],
        ),
        (
            &time_zone::america_argentina::JUJUY,
            time_zone::america_argentina::RAW_JUJUY,
            &[
                b"America/Argentina/Jujuy",
                b"america/argentina/jujuy",
                b"AMERICA/ARGENTINA/JUJUY",
                b"aMERICA/aRGENTINA/jUJUY",
                b"AmErIcA/ArGeNtInA/JuJuY",
                b"aMeRiCa/aRgEnTiNa/jUjUy",
            ],
        ),
        (
            &time_zone::america::JUNEAU,
            time_zone::america::RAW_JUNEAU,
            &[
                b"America/Juneau",
                b"america/juneau",
                b"AMERICA/JUNEAU",
                b"aMERICA/jUNEAU",
                b"AmErIcA/JuNeAu",
                b"aMeRiCa/jUnEaU",
            ],
        ),
        (
            &time_zone::america_kentucky::MONTICELLO,
            time_zone::america_kentucky::RAW_MONTICELLO,
            &[
                b"America/Kentucky/Monticello",
                b"america/kentucky/monticello",
                b"AMERICA/KENTUCKY/MONTICELLO",
                b"aMERICA/kENTUCKY/mONTICELLO",
                b"AmErIcA/KeNtUcKy/mOnTiCeLlO",
                b"aMeRiCa/kEnTuCkY/MoNtIcElLo",
            ],
        ),
        (
            &time_zone::america::KNOX_IN,
            time_zone::america::RAW_KNOX_IN,
            &[
                b"America/Knox_IN",
                b"america/knox_in",
                b"AMERICA/KNOX_IN",
                b"aMERICA/kNOX_in",
                b"AmErIcA/KnOx_iN",
                b"aMeRiCa/kNoX_In",
            ],
        ),
        (
            &time_zone::america_indiana::KNOX,
            time_zone::america_indiana::RAW_KNOX,
            &[
                b"America/Indiana/Knox",
                b"america/indiana/knox",
                b"AMERICA/INDIANA/KNOX",
                b"aMERICA/iNDIANA/kNOX",
                b"AmErIcA/InDiAnA/KnOx",
                b"aMeRiCa/iNdIaNa/kNoX",
            ],
        ),
        (
            &time_zone::us::INDIANA_STARKE,
            time_zone::us::RAW_INDIANA_STARKE,
            &[
                b"US/Indiana-Starke",
                b"us/indiana-starke",
                b"US/INDIANA-STARKE",
                b"us/iNDIANA-sTARKE",
                b"Us/iNdIaNa-sTaRkE",
                b"uS/InDiAnA-StArKe",
            ],
        ),
        (
            &time_zone::america::KRALENDIJK,
            time_zone::america::RAW_KRALENDIJK,
            &[
                b"America/Kralendijk",
                b"america/kralendijk",
                b"AMERICA/KRALENDIJK",
                b"aMERICA/kRALENDIJK",
                b"AmErIcA/KrAlEnDiJk",
                b"aMeRiCa/kRaLeNdIjK",
            ],
        ),
        (
            &time_zone::america::LOWER_PRINCES,
            time_zone::america::RAW_LOWER_PRINCES,
            &[
                b"America/Lower_Princes",
                b"america/lower_princes",
                b"AMERICA/LOWER_PRINCES",
                b"aMERICA/lOWER_pRINCES",
                b"AmErIcA/LoWeR_PrInCeS",
                b"aMeRiCa/lOwEr_pRiNcEs",
            ],
        ),
        (
            &time_zone::america::MARIGOT,
            time_zone::america::RAW_MARIGOT,
            &[
                b"America/Marigot",
                b"america/marigot",
                b"AMERICA/MARIGOT",
                b"aMERICA/mARIGOT",
                b"AmErIcA/MaRiGoT",
                b"aMeRiCa/mArIgOt",
            ],
        ),
        (
            &time_zone::america::PUERTO_RICO,
            time_zone::america::RAW_PUERTO_RICO,
            &[
                b"America/Puerto_Rico",
                b"america/puerto_rico",
                b"AMERICA/PUERTO_RICO",
                b"aMERICA/pUERTO_rICO",
                b"AmErIcA/PuErTo_rIcO",
                b"aMeRiCa/pUeRtO_RiCo",
            ],
        ),
        (
            &time_zone::america::ST_BARTHELEMY,
            time_zone::america::RAW_ST_BARTHELEMY,
            &[
                b"America/St_Barthelemy",
                b"america/st_barthelemy",
                b"AMERICA/ST_BARTHELEMY",
                b"aMERICA/sT_bARTHELEMY",
                b"AmErIcA/St_bArThElEmY",
                b"aMeRiCa/sT_BaRtHeLeMy",
            ],
        ),
        (
            &time_zone::america::VIRGIN,
            time_zone::america::RAW_VIRGIN,
            &[
                b"America/Virgin",
                b"america/virgin",
                b"AMERICA/VIRGIN",
                b"aMERICA/vIRGIN",
                b"AmErIcA/ViRgIn",
                b"aMeRiCa/vIrGiN",
            ],
        ),
        (
            &time_zone::america::LA_PAZ,
            time_zone::america::RAW_LA_PAZ,
            &[
                b"America/La_Paz",
                b"america/la_paz",
                b"AMERICA/LA_PAZ",
                b"aMERICA/lA_pAZ",
                b"AmErIcA/La_pAz",
                b"aMeRiCa/lA_PaZ",
            ],
        ),
        (&time_zone::america::LIMA, time_zone::america::RAW_LIMA, &[
            b"America/Lima",
            b"america/lima",
            b"AMERICA/LIMA",
            b"aMERICA/lIMA",
            b"AmErIcA/LiMa",
            b"aMeRiCa/lImA",
        ]),
        (
            &time_zone::america::LOUISVILLE,
            time_zone::america::RAW_LOUISVILLE,
            &[
                b"America/Louisville",
                b"america/louisville",
                b"AMERICA/LOUISVILLE",
                b"aMERICA/lOUISVILLE",
                b"AmErIcA/LoUiSvIlLe",
                b"aMeRiCa/lOuIsViLlE",
            ],
        ),
        (
            &time_zone::america_kentucky::LOUISVILLE,
            time_zone::america_kentucky::RAW_LOUISVILLE,
            &[
                b"America/Kentucky/Louisville",
                b"america/kentucky/louisville",
                b"AMERICA/KENTUCKY/LOUISVILLE",
                b"aMERICA/kENTUCKY/lOUISVILLE",
                b"AmErIcA/KeNtUcKy/lOuIsViLlE",
                b"aMeRiCa/kEnTuCkY/LoUiSvIlLe",
            ],
        ),
        (
            &time_zone::america::MACEIO,
            time_zone::america::RAW_MACEIO,
            &[
                b"America/Maceio",
                b"america/maceio",
                b"AMERICA/MACEIO",
                b"aMERICA/mACEIO",
                b"AmErIcA/MaCeIo",
                b"aMeRiCa/mAcEiO",
            ],
        ),
        (
            &time_zone::america::MANAGUA,
            time_zone::america::RAW_MANAGUA,
            &[
                b"America/Managua",
                b"america/managua",
                b"AMERICA/MANAGUA",
                b"aMERICA/mANAGUA",
                b"AmErIcA/MaNaGuA",
                b"aMeRiCa/mAnAgUa",
            ],
        ),
        (
            &time_zone::america::MANAUS,
            time_zone::america::RAW_MANAUS,
            &[
                b"America/Manaus",
                b"america/manaus",
                b"AMERICA/MANAUS",
                b"aMERICA/mANAUS",
                b"AmErIcA/MaNaUs",
                b"aMeRiCa/mAnAuS",
            ],
        ),
        (&time_zone::brazil::WEST, time_zone::brazil::RAW_WEST, &[
            b"Brazil/West",
            b"brazil/west",
            b"BRAZIL/WEST",
            b"bRAZIL/wEST",
            b"BrAzIl/wEsT",
            b"bRaZiL/WeSt",
        ]),
        (
            &time_zone::america::MARTINIQUE,
            time_zone::america::RAW_MARTINIQUE,
            &[
                b"America/Martinique",
                b"america/martinique",
                b"AMERICA/MARTINIQUE",
                b"aMERICA/mARTINIQUE",
                b"AmErIcA/MaRtInIqUe",
                b"aMeRiCa/mArTiNiQuE",
            ],
        ),
        (
            &time_zone::america::MATAMOROS,
            time_zone::america::RAW_MATAMOROS,
            &[
                b"America/Matamoros",
                b"america/matamoros",
                b"AMERICA/MATAMOROS",
                b"aMERICA/mATAMOROS",
                b"AmErIcA/MaTaMoRoS",
                b"aMeRiCa/mAtAmOrOs",
            ],
        ),
        (
            &time_zone::america::MAZATLAN,
            time_zone::america::RAW_MAZATLAN,
            &[
                b"America/Mazatlan",
                b"america/mazatlan",
                b"AMERICA/MAZATLAN",
                b"aMERICA/mAZATLAN",
                b"AmErIcA/MaZaTlAn",
                b"aMeRiCa/mAzAtLaN",
            ],
        ),
        (
            &time_zone::mexico::BAJA_SUR,
            time_zone::mexico::RAW_BAJA_SUR,
            &[
                b"Mexico/BajaSur",
                b"mexico/bajasur",
                b"MEXICO/BAJASUR",
                b"mEXICO/bAJAsUR",
                b"MeXiCo/bAjAsUr",
                b"mExIcO/BaJaSuR",
            ],
        ),
        (
            &time_zone::america::MENDOZA,
            time_zone::america::RAW_MENDOZA,
            &[
                b"America/Mendoza",
                b"america/mendoza",
                b"AMERICA/MENDOZA",
                b"aMERICA/mENDOZA",
                b"AmErIcA/MeNdOzA",
                b"aMeRiCa/mEnDoZa",
            ],
        ),
        (
            &time_zone::america_argentina::MENDOZA,
            time_zone::america_argentina::RAW_MENDOZA,
            &[
                b"America/Argentina/Mendoza",
                b"america/argentina/mendoza",
                b"AMERICA/ARGENTINA/MENDOZA",
                b"aMERICA/aRGENTINA/mENDOZA",
                b"AmErIcA/ArGeNtInA/MeNdOzA",
                b"aMeRiCa/aRgEnTiNa/mEnDoZa",
            ],
        ),
        (
            &time_zone::america::MENOMINEE,
            time_zone::america::RAW_MENOMINEE,
            &[
                b"America/Menominee",
                b"america/menominee",
                b"AMERICA/MENOMINEE",
                b"aMERICA/mENOMINEE",
                b"AmErIcA/MeNoMiNeE",
                b"aMeRiCa/mEnOmInEe",
            ],
        ),
        (
            &time_zone::america::MERIDA,
            time_zone::america::RAW_MERIDA,
            &[
                b"America/Merida",
                b"america/merida",
                b"AMERICA/MERIDA",
                b"aMERICA/mERIDA",
                b"AmErIcA/MeRiDa",
                b"aMeRiCa/mErIdA",
            ],
        ),
        (
            &time_zone::america::METLAKATLA,
            time_zone::america::RAW_METLAKATLA,
            &[
                b"America/Metlakatla",
                b"america/metlakatla",
                b"AMERICA/METLAKATLA",
                b"aMERICA/mETLAKATLA",
                b"AmErIcA/MeTlAkAtLa",
                b"aMeRiCa/mEtLaKaTlA",
            ],
        ),
        (
            &time_zone::america::MEXICO_CITY,
            time_zone::america::RAW_MEXICO_CITY,
            &[
                b"America/Mexico_City",
                b"america/mexico_city",
                b"AMERICA/MEXICO_CITY",
                b"aMERICA/mEXICO_cITY",
                b"AmErIcA/MeXiCo_cItY",
                b"aMeRiCa/mExIcO_CiTy",
            ],
        ),
        (
            &time_zone::mexico::GENERAL,
            time_zone::mexico::RAW_GENERAL,
            &[
                b"Mexico/General",
                b"mexico/general",
                b"MEXICO/GENERAL",
                b"mEXICO/gENERAL",
                b"MeXiCo/gEnErAl",
                b"mExIcO/GeNeRaL",
            ],
        ),
        (
            &time_zone::america::MIQUELON,
            time_zone::america::RAW_MIQUELON,
            &[
                b"America/Miquelon",
                b"america/miquelon",
                b"AMERICA/MIQUELON",
                b"aMERICA/mIQUELON",
                b"AmErIcA/MiQuElOn",
                b"aMeRiCa/mIqUeLoN",
            ],
        ),
        (
            &time_zone::america::MONCTON,
            time_zone::america::RAW_MONCTON,
            &[
                b"America/Moncton",
                b"america/moncton",
                b"AMERICA/MONCTON",
                b"aMERICA/mONCTON",
                b"AmErIcA/MoNcToN",
                b"aMeRiCa/mOnCtOn",
            ],
        ),
        (
            &time_zone::america::MONTERREY,
            time_zone::america::RAW_MONTERREY,
            &[
                b"America/Monterrey",
                b"america/monterrey",
                b"AMERICA/MONTERREY",
                b"aMERICA/mONTERREY",
                b"AmErIcA/MoNtErReY",
                b"aMeRiCa/mOnTeRrEy",
            ],
        ),
        (
            &time_zone::america::MONTEVIDEO,
            time_zone::america::RAW_MONTEVIDEO,
            &[
                b"America/Montevideo",
                b"america/montevideo",
                b"AMERICA/MONTEVIDEO",
                b"aMERICA/mONTEVIDEO",
                b"AmErIcA/MoNtEvIdEo",
                b"aMeRiCa/mOnTeViDeO",
            ],
        ),
        (
            &time_zone::america::MONTREAL,
            time_zone::america::RAW_MONTREAL,
            &[
                b"America/Montreal",
                b"america/montreal",
                b"AMERICA/MONTREAL",
                b"aMERICA/mONTREAL",
                b"AmErIcA/MoNtReAl",
                b"aMeRiCa/mOnTrEaL",
            ],
        ),
        (
            &time_zone::america::NIPIGON,
            time_zone::america::RAW_NIPIGON,
            &[
                b"America/Nipigon",
                b"america/nipigon",
                b"AMERICA/NIPIGON",
                b"aMERICA/nIPIGON",
                b"AmErIcA/NiPiGoN",
                b"aMeRiCa/nIpIgOn",
            ],
        ),
        (
            &time_zone::america::THUNDER_BAY,
            time_zone::america::RAW_THUNDER_BAY,
            &[
                b"America/Thunder_Bay",
                b"america/thunder_bay",
                b"AMERICA/THUNDER_BAY",
                b"aMERICA/tHUNDER_bAY",
                b"AmErIcA/ThUnDeR_BaY",
                b"aMeRiCa/tHuNdEr_bAy",
            ],
        ),
        (
            &time_zone::america::TORONTO,
            time_zone::america::RAW_TORONTO,
            &[
                b"America/Toronto",
                b"america/toronto",
                b"AMERICA/TORONTO",
                b"aMERICA/tORONTO",
                b"AmErIcA/ToRoNtO",
                b"aMeRiCa/tOrOnTo",
            ],
        ),
        (
            &time_zone::canada::EASTERN,
            time_zone::canada::RAW_EASTERN,
            &[
                b"Canada/Eastern",
                b"canada/eastern",
                b"CANADA/EASTERN",
                b"cANADA/eASTERN",
                b"CaNaDa/eAsTeRn",
                b"cAnAdA/EaStErN",
            ],
        ),
        (
            &time_zone::america::MONTSERRAT,
            time_zone::america::RAW_MONTSERRAT,
            &[
                b"America/Montserrat",
                b"america/montserrat",
                b"AMERICA/MONTSERRAT",
                b"aMERICA/mONTSERRAT",
                b"AmErIcA/MoNtSeRrAt",
                b"aMeRiCa/mOnTsErRaT",
            ],
        ),
        (
            &time_zone::america::NASSAU,
            time_zone::america::RAW_NASSAU,
            &[
                b"America/Nassau",
                b"america/nassau",
                b"AMERICA/NASSAU",
                b"aMERICA/nASSAU",
                b"AmErIcA/NaSsAu",
                b"aMeRiCa/nAsSaU",
            ],
        ),
        (&time_zone::america::NOME, time_zone::america::RAW_NOME, &[
            b"America/Nome",
            b"america/nome",
            b"AMERICA/NOME",
            b"aMERICA/nOME",
            b"AmErIcA/NoMe",
            b"aMeRiCa/nOmE",
        ]),
        (
            &time_zone::america::NORONHA,
            time_zone::america::RAW_NORONHA,
            &[
                b"America/Noronha",
                b"america/noronha",
                b"AMERICA/NORONHA",
                b"aMERICA/nORONHA",
                b"AmErIcA/NoRoNhA",
                b"aMeRiCa/nOrOnHa",
            ],
        ),
        (
            &time_zone::brazil::DE_NORONHA,
            time_zone::brazil::RAW_DE_NORONHA,
            &[
                b"Brazil/DeNoronha",
                b"brazil/denoronha",
                b"BRAZIL/DENORONHA",
                b"bRAZIL/dEnORONHA",
                b"BrAzIl/dEnOrOnHa",
                b"bRaZiL/DeNoRoNhA",
            ],
        ),
        (
            &time_zone::america_north_dakota::BEULAH,
            time_zone::america_north_dakota::RAW_BEULAH,
            &[
                b"America/North_Dakota/Beulah",
                b"america/north_dakota/beulah",
                b"AMERICA/NORTH_DAKOTA/BEULAH",
                b"aMERICA/nORTH_dAKOTA/bEULAH",
                b"AmErIcA/NoRtH_DaKoTa/bEuLaH",
                b"aMeRiCa/nOrTh_dAkOtA/BeUlAh",
            ],
        ),
        (
            &time_zone::america_north_dakota::CENTER,
            time_zone::america_north_dakota::RAW_CENTER,
            &[
                b"America/North_Dakota/Center",
                b"america/north_dakota/center",
                b"AMERICA/NORTH_DAKOTA/CENTER",
                b"aMERICA/nORTH_dAKOTA/cENTER",
                b"AmErIcA/NoRtH_DaKoTa/cEnTeR",
                b"aMeRiCa/nOrTh_dAkOtA/CeNtEr",
            ],
        ),
        (
            &time_zone::america_north_dakota::NEW_SALEM,
            time_zone::america_north_dakota::RAW_NEW_SALEM,
            &[
                b"America/North_Dakota/New_Salem",
                b"america/north_dakota/new_salem",
                b"AMERICA/NORTH_DAKOTA/NEW_SALEM",
                b"aMERICA/nORTH_dAKOTA/nEW_sALEM",
                b"AmErIcA/NoRtH_DaKoTa/nEw_sAlEm",
                b"aMeRiCa/nOrTh_dAkOtA/NeW_SaLeM",
            ],
        ),
        (
            &time_zone::america::OJINAGA,
            time_zone::america::RAW_OJINAGA,
            &[
                b"America/Ojinaga",
                b"america/ojinaga",
                b"AMERICA/OJINAGA",
                b"aMERICA/oJINAGA",
                b"AmErIcA/OjInAgA",
                b"aMeRiCa/oJiNaGa",
            ],
        ),
        (
            &time_zone::america::PARAMARIBO,
            time_zone::america::RAW_PARAMARIBO,
            &[
                b"America/Paramaribo",
                b"america/paramaribo",
                b"AMERICA/PARAMARIBO",
                b"aMERICA/pARAMARIBO",
                b"AmErIcA/PaRaMaRiBo",
                b"aMeRiCa/pArAmArIbO",
            ],
        ),
        (
            &time_zone::america::PORTO_ACRE,
            time_zone::america::RAW_PORTO_ACRE,
            &[
                b"America/Porto_Acre",
                b"america/porto_acre",
                b"AMERICA/PORTO_ACRE",
                b"aMERICA/pORTO_aCRE",
                b"AmErIcA/PoRtO_AcRe",
                b"aMeRiCa/pOrTo_aCrE",
            ],
        ),
        (
            &time_zone::america::RIO_BRANCO,
            time_zone::america::RAW_RIO_BRANCO,
            &[
                b"America/Rio_Branco",
                b"america/rio_branco",
                b"AMERICA/RIO_BRANCO",
                b"aMERICA/rIO_bRANCO",
                b"AmErIcA/RiO_BrAnCo",
                b"aMeRiCa/rIo_bRaNcO",
            ],
        ),
        (&time_zone::brazil::ACRE, time_zone::brazil::RAW_ACRE, &[
            b"Brazil/Acre",
            b"brazil/acre",
            b"BRAZIL/ACRE",
            b"bRAZIL/aCRE",
            b"BrAzIl/aCrE",
            b"bRaZiL/AcRe",
        ]),
        (
            &time_zone::america::PORTO_VELHO,
            time_zone::america::RAW_PORTO_VELHO,
            &[
                b"America/Porto_Velho",
                b"america/porto_velho",
                b"AMERICA/PORTO_VELHO",
                b"aMERICA/pORTO_vELHO",
                b"AmErIcA/PoRtO_VeLhO",
                b"aMeRiCa/pOrTo_vElHo",
            ],
        ),
        (
            &time_zone::america::PORT_AU_PRINCE,
            time_zone::america::RAW_PORT_AU_PRINCE,
            &[
                b"America/Port-au-Prince",
                b"america/port-au-prince",
                b"AMERICA/PORT-AU-PRINCE",
                b"aMERICA/pORT-AU-pRINCE",
                b"AmErIcA/PoRt-aU-PrInCe",
                b"aMeRiCa/pOrT-Au-pRiNcE",
            ],
        ),
        (
            &time_zone::america::PORT_OF_SPAIN,
            time_zone::america::RAW_PORT_OF_SPAIN,
            &[
                b"America/Port_of_Spain",
                b"america/port_of_spain",
                b"AMERICA/PORT_OF_SPAIN",
                b"aMERICA/pORT_OF_sPAIN",
                b"AmErIcA/PoRt_oF_SpAiN",
                b"aMeRiCa/pOrT_Of_sPaIn",
            ],
        ),
        (
            &time_zone::america::PUNTA_ARENAS,
            time_zone::america::RAW_PUNTA_ARENAS,
            &[
                b"America/Punta_Arenas",
                b"america/punta_arenas",
                b"AMERICA/PUNTA_ARENAS",
                b"aMERICA/pUNTA_aRENAS",
                b"AmErIcA/PuNtA_ArEnAs",
                b"aMeRiCa/pUnTa_aReNaS",
            ],
        ),
        (
            &time_zone::america::RAINY_RIVER,
            time_zone::america::RAW_RAINY_RIVER,
            &[
                b"America/Rainy_River",
                b"america/rainy_river",
                b"AMERICA/RAINY_RIVER",
                b"aMERICA/rAINY_rIVER",
                b"AmErIcA/RaInY_RiVeR",
                b"aMeRiCa/rAiNy_rIvEr",
            ],
        ),
        (
            &time_zone::america::WINNIPEG,
            time_zone::america::RAW_WINNIPEG,
            &[
                b"America/Winnipeg",
                b"america/winnipeg",
                b"AMERICA/WINNIPEG",
                b"aMERICA/wINNIPEG",
                b"AmErIcA/WiNnIpEg",
                b"aMeRiCa/wInNiPeG",
            ],
        ),
        (
            &time_zone::canada::CENTRAL,
            time_zone::canada::RAW_CENTRAL,
            &[
                b"Canada/Central",
                b"canada/central",
                b"CANADA/CENTRAL",
                b"cANADA/cENTRAL",
                b"CaNaDa/cEnTrAl",
                b"cAnAdA/CeNtRaL",
            ],
        ),
        (
            &time_zone::america::RANKIN_INLET,
            time_zone::america::RAW_RANKIN_INLET,
            &[
                b"America/Rankin_Inlet",
                b"america/rankin_inlet",
                b"AMERICA/RANKIN_INLET",
                b"aMERICA/rANKIN_iNLET",
                b"AmErIcA/RaNkIn_iNlEt",
                b"aMeRiCa/rAnKiN_InLeT",
            ],
        ),
        (
            &time_zone::america::RECIFE,
            time_zone::america::RAW_RECIFE,
            &[
                b"America/Recife",
                b"america/recife",
                b"AMERICA/RECIFE",
                b"aMERICA/rECIFE",
                b"AmErIcA/ReCiFe",
                b"aMeRiCa/rEcIfE",
            ],
        ),
        (
            &time_zone::america::REGINA,
            time_zone::america::RAW_REGINA,
            &[
                b"America/Regina",
                b"america/regina",
                b"AMERICA/REGINA",
                b"aMERICA/rEGINA",
                b"AmErIcA/ReGiNa",
                b"aMeRiCa/rEgInA",
            ],
        ),
        (
            &time_zone::canada::SASKATCHEWAN,
            time_zone::canada::RAW_SASKATCHEWAN,
            &[
                b"Canada/Saskatchewan",
                b"canada/saskatchewan",
                b"CANADA/SASKATCHEWAN",
                b"cANADA/sASKATCHEWAN",
                b"CaNaDa/sAsKaTcHeWaN",
                b"cAnAdA/SaSkAtChEwAn",
            ],
        ),
        (
            &time_zone::america::RESOLUTE,
            time_zone::america::RAW_RESOLUTE,
            &[
                b"America/Resolute",
                b"america/resolute",
                b"AMERICA/RESOLUTE",
                b"aMERICA/rESOLUTE",
                b"AmErIcA/ReSoLuTe",
                b"aMeRiCa/rEsOlUtE",
            ],
        ),
        (
            &time_zone::america::SANTAREM,
            time_zone::america::RAW_SANTAREM,
            &[
                b"America/Santarem",
                b"america/santarem",
                b"AMERICA/SANTAREM",
                b"aMERICA/sANTAREM",
                b"AmErIcA/SaNtArEm",
                b"aMeRiCa/sAnTaReM",
            ],
        ),
        (
            &time_zone::america::SANTIAGO,
            time_zone::america::RAW_SANTIAGO,
            &[
                b"America/Santiago",
                b"america/santiago",
                b"AMERICA/SANTIAGO",
                b"aMERICA/sANTIAGO",
                b"AmErIcA/SaNtIaGo",
                b"aMeRiCa/sAnTiAgO",
            ],
        ),
        (
            &time_zone::chile::CONTINENTAL,
            time_zone::chile::RAW_CONTINENTAL,
            &[
                b"Chile/Continental",
                b"chile/continental",
                b"CHILE/CONTINENTAL",
                b"cHILE/cONTINENTAL",
                b"ChIlE/CoNtInEnTaL",
                b"cHiLe/cOnTiNeNtAl",
            ],
        ),
        (
            &time_zone::america::SANTO_DOMINGO,
            time_zone::america::RAW_SANTO_DOMINGO,
            &[
                b"America/Santo_Domingo",
                b"america/santo_domingo",
                b"AMERICA/SANTO_DOMINGO",
                b"aMERICA/sANTO_dOMINGO",
                b"AmErIcA/SaNtO_DoMiNgO",
                b"aMeRiCa/sAnTo_dOmInGo",
            ],
        ),
        (
            &time_zone::america::SAO_PAULO,
            time_zone::america::RAW_SAO_PAULO,
            &[
                b"America/Sao_Paulo",
                b"america/sao_paulo",
                b"AMERICA/SAO_PAULO",
                b"aMERICA/sAO_pAULO",
                b"AmErIcA/SaO_PaUlO",
                b"aMeRiCa/sAo_pAuLo",
            ],
        ),
        (&time_zone::brazil::EAST, time_zone::brazil::RAW_EAST, &[
            b"Brazil/East",
            b"brazil/east",
            b"BRAZIL/EAST",
            b"bRAZIL/eAST",
            b"BrAzIl/eAsT",
            b"bRaZiL/EaSt",
        ]),
        (
            &time_zone::america::SCORESBYSUND,
            time_zone::america::RAW_SCORESBYSUND,
            &[
                b"America/Scoresbysund",
                b"america/scoresbysund",
                b"AMERICA/SCORESBYSUND",
                b"aMERICA/sCORESBYSUND",
                b"AmErIcA/ScOrEsBySuNd",
                b"aMeRiCa/sCoReSbYsUnD",
            ],
        ),
        (
            &time_zone::america::SITKA,
            time_zone::america::RAW_SITKA,
            &[
                b"America/Sitka",
                b"america/sitka",
                b"AMERICA/SITKA",
                b"aMERICA/sITKA",
                b"AmErIcA/SiTkA",
                b"aMeRiCa/sItKa",
            ],
        ),
        (
            &time_zone::america::ST_JOHNS,
            time_zone::america::RAW_ST_JOHNS,
            &[
                b"America/St_Johns",
                b"america/st_johns",
                b"AMERICA/ST_JOHNS",
                b"aMERICA/sT_jOHNS",
                b"AmErIcA/St_jOhNs",
                b"aMeRiCa/sT_JoHnS",
            ],
        ),
        (
            &time_zone::canada::NEWFOUNDLAND,
            time_zone::canada::RAW_NEWFOUNDLAND,
            &[
                b"Canada/Newfoundland",
                b"canada/newfoundland",
                b"CANADA/NEWFOUNDLAND",
                b"cANADA/nEWFOUNDLAND",
                b"CaNaDa/nEwFoUnDlAnD",
                b"cAnAdA/NeWfOuNdLaNd",
            ],
        ),
        (
            &time_zone::america::ST_KITTS,
            time_zone::america::RAW_ST_KITTS,
            &[
                b"America/St_Kitts",
                b"america/st_kitts",
                b"AMERICA/ST_KITTS",
                b"aMERICA/sT_kITTS",
                b"AmErIcA/St_kItTs",
                b"aMeRiCa/sT_KiTtS",
            ],
        ),
        (
            &time_zone::america::ST_LUCIA,
            time_zone::america::RAW_ST_LUCIA,
            &[
                b"America/St_Lucia",
                b"america/st_lucia",
                b"AMERICA/ST_LUCIA",
                b"aMERICA/sT_lUCIA",
                b"AmErIcA/St_lUcIa",
                b"aMeRiCa/sT_LuCiA",
            ],
        ),
        (
            &time_zone::america::ST_THOMAS,
            time_zone::america::RAW_ST_THOMAS,
            &[
                b"America/St_Thomas",
                b"america/st_thomas",
                b"AMERICA/ST_THOMAS",
                b"aMERICA/sT_tHOMAS",
                b"AmErIcA/St_tHoMaS",
                b"aMeRiCa/sT_ThOmAs",
            ],
        ),
        (
            &time_zone::america::ST_VINCENT,
            time_zone::america::RAW_ST_VINCENT,
            &[
                b"America/St_Vincent",
                b"america/st_vincent",
                b"AMERICA/ST_VINCENT",
                b"aMERICA/sT_vINCENT",
                b"AmErIcA/St_vInCeNt",
                b"aMeRiCa/sT_ViNcEnT",
            ],
        ),
        (
            &time_zone::america::SWIFT_CURRENT,
            time_zone::america::RAW_SWIFT_CURRENT,
            &[
                b"America/Swift_Current",
                b"america/swift_current",
                b"AMERICA/SWIFT_CURRENT",
                b"aMERICA/sWIFT_cURRENT",
                b"AmErIcA/SwIfT_CuRrEnT",
                b"aMeRiCa/sWiFt_cUrReNt",
            ],
        ),
        (
            &time_zone::america::TEGUCIGALPA,
            time_zone::america::RAW_TEGUCIGALPA,
            &[
                b"America/Tegucigalpa",
                b"america/tegucigalpa",
                b"AMERICA/TEGUCIGALPA",
                b"aMERICA/tEGUCIGALPA",
                b"AmErIcA/TeGuCiGaLpA",
                b"aMeRiCa/tEgUcIgAlPa",
            ],
        ),
        (
            &time_zone::america::THULE,
            time_zone::america::RAW_THULE,
            &[
                b"America/Thule",
                b"america/thule",
                b"AMERICA/THULE",
                b"aMERICA/tHULE",
                b"AmErIcA/ThUlE",
                b"aMeRiCa/tHuLe",
            ],
        ),
        (
            &time_zone::america::TORTOLA,
            time_zone::america::RAW_TORTOLA,
            &[
                b"America/Tortola",
                b"america/tortola",
                b"AMERICA/TORTOLA",
                b"aMERICA/tORTOLA",
                b"AmErIcA/ToRtOlA",
                b"aMeRiCa/tOrToLa",
            ],
        ),
        (
            &time_zone::america::VANCOUVER,
            time_zone::america::RAW_VANCOUVER,
            &[
                b"America/Vancouver",
                b"america/vancouver",
                b"AMERICA/VANCOUVER",
                b"aMERICA/vANCOUVER",
                b"AmErIcA/VaNcOuVeR",
                b"aMeRiCa/vAnCoUvEr",
            ],
        ),
        (
            &time_zone::canada::PACIFIC,
            time_zone::canada::RAW_PACIFIC,
            &[
                b"Canada/Pacific",
                b"canada/pacific",
                b"CANADA/PACIFIC",
                b"cANADA/pACIFIC",
                b"CaNaDa/pAcIfIc",
                b"cAnAdA/PaCiFiC",
            ],
        ),
        (
            &time_zone::america::WHITEHORSE,
            time_zone::america::RAW_WHITEHORSE,
            &[
                b"America/Whitehorse",
                b"america/whitehorse",
                b"AMERICA/WHITEHORSE",
                b"aMERICA/wHITEHORSE",
                b"AmErIcA/WhItEhOrSe",
                b"aMeRiCa/wHiTeHoRsE",
            ],
        ),
        (&time_zone::canada::YUKON, time_zone::canada::RAW_YUKON, &[
            b"Canada/Yukon",
            b"canada/yukon",
            b"CANADA/YUKON",
            b"cANADA/yUKON",
            b"CaNaDa/yUkOn",
            b"cAnAdA/YuKoN",
        ]),
        (
            &time_zone::america::YAKUTAT,
            time_zone::america::RAW_YAKUTAT,
            &[
                b"America/Yakutat",
                b"america/yakutat",
                b"AMERICA/YAKUTAT",
                b"aMERICA/yAKUTAT",
                b"AmErIcA/YaKuTaT",
                b"aMeRiCa/yAkUtAt",
            ],
        ),
        (
            &time_zone::antarctica::CASEY,
            time_zone::antarctica::RAW_CASEY,
            &[
                b"Antarctica/Casey",
                b"antarctica/casey",
                b"ANTARCTICA/CASEY",
                b"aNTARCTICA/cASEY",
                b"AnTaRcTiCa/cAsEy",
                b"aNtArCtIcA/CaSeY",
            ],
        ),
        (
            &time_zone::antarctica::DAVIS,
            time_zone::antarctica::RAW_DAVIS,
            &[
                b"Antarctica/Davis",
                b"antarctica/davis",
                b"ANTARCTICA/DAVIS",
                b"aNTARCTICA/dAVIS",
                b"AnTaRcTiCa/dAvIs",
                b"aNtArCtIcA/DaViS",
            ],
        ),
        (
            &time_zone::antarctica::DUMONT_D_URVILLE,
            time_zone::antarctica::RAW_DUMONT_D_URVILLE,
            &[
                b"Antarctica/DumontDUrville",
                b"antarctica/dumontdurville",
                b"ANTARCTICA/DUMONTDURVILLE",
                b"aNTARCTICA/dUMONTduRVILLE",
                b"AnTaRcTiCa/dUmOnTdUrViLlE",
                b"aNtArCtIcA/DuMoNtDuRvIlLe",
            ],
        ),
        (
            &time_zone::antarctica::MACQUARIE,
            time_zone::antarctica::RAW_MACQUARIE,
            &[
                b"Antarctica/Macquarie",
                b"antarctica/macquarie",
                b"ANTARCTICA/MACQUARIE",
                b"aNTARCTICA/mACQUARIE",
                b"AnTaRcTiCa/mAcQuArIe",
                b"aNtArCtIcA/MaCqUaRiE",
            ],
        ),
        (
            &time_zone::antarctica::MAWSON,
            time_zone::antarctica::RAW_MAWSON,
            &[
                b"Antarctica/Mawson",
                b"antarctica/mawson",
                b"ANTARCTICA/MAWSON",
                b"aNTARCTICA/mAWSON",
                b"AnTaRcTiCa/mAwSoN",
                b"aNtArCtIcA/MaWsOn",
            ],
        ),
        (
            &time_zone::antarctica::MC_MURDO,
            time_zone::antarctica::RAW_MC_MURDO,
            &[
                b"Antarctica/McMurdo",
                b"antarctica/mcmurdo",
                b"ANTARCTICA/MCMURDO",
                b"aNTARCTICA/mCmURDO",
                b"AnTaRcTiCa/mCmUrDo",
                b"aNtArCtIcA/McMuRdO",
            ],
        ),
        (
            &time_zone::antarctica::PALMER,
            time_zone::antarctica::RAW_PALMER,
            &[
                b"Antarctica/Palmer",
                b"antarctica/palmer",
                b"ANTARCTICA/PALMER",
                b"aNTARCTICA/pALMER",
                b"AnTaRcTiCa/pAlMeR",
                b"aNtArCtIcA/PaLmEr",
            ],
        ),
        (
            &time_zone::antarctica::ROTHERA,
            time_zone::antarctica::RAW_ROTHERA,
            &[
                b"Antarctica/Rothera",
                b"antarctica/rothera",
                b"ANTARCTICA/ROTHERA",
                b"aNTARCTICA/rOTHERA",
                b"AnTaRcTiCa/rOtHeRa",
                b"aNtArCtIcA/RoThErA",
            ],
        ),
        (
            &time_zone::antarctica::SYOWA,
            time_zone::antarctica::RAW_SYOWA,
            &[
                b"Antarctica/Syowa",
                b"antarctica/syowa",
                b"ANTARCTICA/SYOWA",
                b"aNTARCTICA/sYOWA",
                b"AnTaRcTiCa/sYoWa",
                b"aNtArCtIcA/SyOwA",
            ],
        ),
        (
            &time_zone::antarctica::TROLL,
            time_zone::antarctica::RAW_TROLL,
            &[
                b"Antarctica/Troll",
                b"antarctica/troll",
                b"ANTARCTICA/TROLL",
                b"aNTARCTICA/tROLL",
                b"AnTaRcTiCa/tRoLl",
                b"aNtArCtIcA/TrOlL",
            ],
        ),
        (
            &time_zone::antarctica::VOSTOK,
            time_zone::antarctica::RAW_VOSTOK,
            &[
                b"Antarctica/Vostok",
                b"antarctica/vostok",
                b"ANTARCTICA/VOSTOK",
                b"aNTARCTICA/vOSTOK",
                b"AnTaRcTiCa/vOsToK",
                b"aNtArCtIcA/VoStOk",
            ],
        ),
        (
            &time_zone::arctic::LONGYEARBYEN,
            time_zone::arctic::RAW_LONGYEARBYEN,
            &[
                b"Arctic/Longyearbyen",
                b"arctic/longyearbyen",
                b"ARCTIC/LONGYEARBYEN",
                b"aRCTIC/lONGYEARBYEN",
                b"ArCtIc/lOnGyEaRbYeN",
                b"aRcTiC/LoNgYeArByEn",
            ],
        ),
        (
            &time_zone::atlantic::JAN_MAYEN,
            time_zone::atlantic::RAW_JAN_MAYEN,
            &[
                b"Atlantic/Jan_Mayen",
                b"atlantic/jan_mayen",
                b"ATLANTIC/JAN_MAYEN",
                b"aTLANTIC/jAN_mAYEN",
                b"AtLaNtIc/jAn_mAyEn",
                b"aTlAnTiC/JaN_MaYeN",
            ],
        ),
        (
            &time_zone::europe::BERLIN,
            time_zone::europe::RAW_BERLIN,
            &[
                b"Europe/Berlin",
                b"europe/berlin",
                b"EUROPE/BERLIN",
                b"eUROPE/bERLIN",
                b"EuRoPe/bErLiN",
                b"eUrOpE/BeRlIn",
            ],
        ),
        (&time_zone::asia::ADEN, time_zone::asia::RAW_ADEN, &[
            b"Asia/Aden",
            b"asia/aden",
            b"ASIA/ADEN",
            b"aSIA/aDEN",
            b"AsIa/aDeN",
            b"aSiA/AdEn",
        ]),
        (&time_zone::asia::ALMATY, time_zone::asia::RAW_ALMATY, &[
            b"Asia/Almaty",
            b"asia/almaty",
            b"ASIA/ALMATY",
            b"aSIA/aLMATY",
            b"AsIa/aLmAtY",
            b"aSiA/AlMaTy",
        ]),
        (&time_zone::asia::AMMAN, time_zone::asia::RAW_AMMAN, &[
            b"Asia/Amman",
            b"asia/amman",
            b"ASIA/AMMAN",
            b"aSIA/aMMAN",
            b"AsIa/aMmAn",
            b"aSiA/AmMaN",
        ]),
        (&time_zone::asia::ANADYR, time_zone::asia::RAW_ANADYR, &[
            b"Asia/Anadyr",
            b"asia/anadyr",
            b"ASIA/ANADYR",
            b"aSIA/aNADYR",
            b"AsIa/aNaDyR",
            b"aSiA/AnAdYr",
        ]),
        (&time_zone::asia::AQTAU, time_zone::asia::RAW_AQTAU, &[
            b"Asia/Aqtau",
            b"asia/aqtau",
            b"ASIA/AQTAU",
            b"aSIA/aQTAU",
            b"AsIa/aQtAu",
            b"aSiA/AqTaU",
        ]),
        (&time_zone::asia::AQTOBE, time_zone::asia::RAW_AQTOBE, &[
            b"Asia/Aqtobe",
            b"asia/aqtobe",
            b"ASIA/AQTOBE",
            b"aSIA/aQTOBE",
            b"AsIa/aQtObE",
            b"aSiA/AqToBe",
        ]),
        (
            &time_zone::asia::ASHGABAT,
            time_zone::asia::RAW_ASHGABAT,
            &[
                b"Asia/Ashgabat",
                b"asia/ashgabat",
                b"ASIA/ASHGABAT",
                b"aSIA/aSHGABAT",
                b"AsIa/aShGaBaT",
                b"aSiA/AsHgAbAt",
            ],
        ),
        (
            &time_zone::asia::ASHKHABAD,
            time_zone::asia::RAW_ASHKHABAD,
            &[
                b"Asia/Ashkhabad",
                b"asia/ashkhabad",
                b"ASIA/ASHKHABAD",
                b"aSIA/aSHKHABAD",
                b"AsIa/aShKhAbAd",
                b"aSiA/AsHkHaBaD",
            ],
        ),
        (&time_zone::asia::ATYRAU, time_zone::asia::RAW_ATYRAU, &[
            b"Asia/Atyrau",
            b"asia/atyrau",
            b"ASIA/ATYRAU",
            b"aSIA/aTYRAU",
            b"AsIa/aTyRaU",
            b"aSiA/AtYrAu",
        ]),
        (&time_zone::asia::BAGHDAD, time_zone::asia::RAW_BAGHDAD, &[
            b"Asia/Baghdad",
            b"asia/baghdad",
            b"ASIA/BAGHDAD",
            b"aSIA/bAGHDAD",
            b"AsIa/bAgHdAd",
            b"aSiA/BaGhDaD",
        ]),
        (&time_zone::asia::BAHRAIN, time_zone::asia::RAW_BAHRAIN, &[
            b"Asia/Bahrain",
            b"asia/bahrain",
            b"ASIA/BAHRAIN",
            b"aSIA/bAHRAIN",
            b"AsIa/bAhRaIn",
            b"aSiA/BaHrAiN",
        ]),
        (&time_zone::asia::BAKU, time_zone::asia::RAW_BAKU, &[
            b"Asia/Baku",
            b"asia/baku",
            b"ASIA/BAKU",
            b"aSIA/bAKU",
            b"AsIa/bAkU",
            b"aSiA/BaKu",
        ]),
        (&time_zone::asia::BANGKOK, time_zone::asia::RAW_BANGKOK, &[
            b"Asia/Bangkok",
            b"asia/bangkok",
            b"ASIA/BANGKOK",
            b"aSIA/bANGKOK",
            b"AsIa/bAnGkOk",
            b"aSiA/BaNgKoK",
        ]),
        (&time_zone::asia::BARNAUL, time_zone::asia::RAW_BARNAUL, &[
            b"Asia/Barnaul",
            b"asia/barnaul",
            b"ASIA/BARNAUL",
            b"aSIA/bARNAUL",
            b"AsIa/bArNaUl",
            b"aSiA/BaRnAuL",
        ]),
        (&time_zone::asia::BEIRUT, time_zone::asia::RAW_BEIRUT, &[
            b"Asia/Beirut",
            b"asia/beirut",
            b"ASIA/BEIRUT",
            b"aSIA/bEIRUT",
            b"AsIa/bEiRuT",
            b"aSiA/BeIrUt",
        ]),
        (&time_zone::asia::BISHKEK, time_zone::asia::RAW_BISHKEK, &[
            b"Asia/Bishkek",
            b"asia/bishkek",
            b"ASIA/BISHKEK",
            b"aSIA/bISHKEK",
            b"AsIa/bIsHkEk",
            b"aSiA/BiShKeK",
        ]),
        (&time_zone::asia::BRUNEI, time_zone::asia::RAW_BRUNEI, &[
            b"Asia/Brunei",
            b"asia/brunei",
            b"ASIA/BRUNEI",
            b"aSIA/bRUNEI",
            b"AsIa/bRuNeI",
            b"aSiA/BrUnEi",
        ]),
        (
            &time_zone::asia::CALCUTTA,
            time_zone::asia::RAW_CALCUTTA,
            &[
                b"Asia/Calcutta",
                b"asia/calcutta",
                b"ASIA/CALCUTTA",
                b"aSIA/cALCUTTA",
                b"AsIa/cAlCuTtA",
                b"aSiA/CaLcUtTa",
            ],
        ),
        (&time_zone::asia::KOLKATA, time_zone::asia::RAW_KOLKATA, &[
            b"Asia/Kolkata",
            b"asia/kolkata",
            b"ASIA/KOLKATA",
            b"aSIA/kOLKATA",
            b"AsIa/kOlKaTa",
            b"aSiA/KoLkAtA",
        ]),
        (&time_zone::asia::CHITA, time_zone::asia::RAW_CHITA, &[
            b"Asia/Chita",
            b"asia/chita",
            b"ASIA/CHITA",
            b"aSIA/cHITA",
            b"AsIa/cHiTa",
            b"aSiA/ChItA",
        ]),
        (
            &time_zone::asia::CHOIBALSAN,
            time_zone::asia::RAW_CHOIBALSAN,
            &[
                b"Asia/Choibalsan",
                b"asia/choibalsan",
                b"ASIA/CHOIBALSAN",
                b"aSIA/cHOIBALSAN",
                b"AsIa/cHoIbAlSaN",
                b"aSiA/ChOiBaLsAn",
            ],
        ),
        (
            &time_zone::asia::ULAANBAATAR,
            time_zone::asia::RAW_ULAANBAATAR,
            &[
                b"Asia/Ulaanbaatar",
                b"asia/ulaanbaatar",
                b"ASIA/ULAANBAATAR",
                b"aSIA/uLAANBAATAR",
                b"AsIa/uLaAnBaAtAr",
                b"aSiA/UlAaNbAaTaR",
            ],
        ),
        (
            &time_zone::asia::ULAN_BATOR,
            time_zone::asia::RAW_ULAN_BATOR,
            &[
                b"Asia/Ulan_Bator",
                b"asia/ulan_bator",
                b"ASIA/ULAN_BATOR",
                b"aSIA/uLAN_bATOR",
                b"AsIa/uLaN_BaToR",
                b"aSiA/UlAn_bAtOr",
            ],
        ),
        (&time_zone::asia::COLOMBO, time_zone::asia::RAW_COLOMBO, &[
            b"Asia/Colombo",
            b"asia/colombo",
            b"ASIA/COLOMBO",
            b"aSIA/cOLOMBO",
            b"AsIa/cOlOmBo",
            b"aSiA/CoLoMbO",
        ]),
        (&time_zone::asia::DACCA, time_zone::asia::RAW_DACCA, &[
            b"Asia/Dacca",
            b"asia/dacca",
            b"ASIA/DACCA",
            b"aSIA/dACCA",
            b"AsIa/dAcCa",
            b"aSiA/DaCcA",
        ]),
        (&time_zone::asia::DHAKA, time_zone::asia::RAW_DHAKA, &[
            b"Asia/Dhaka",
            b"asia/dhaka",
            b"ASIA/DHAKA",
            b"aSIA/dHAKA",
            b"AsIa/dHaKa",
            b"aSiA/DhAkA",
        ]),
        (
            &time_zone::asia::DAMASCUS,
            time_zone::asia::RAW_DAMASCUS,
            &[
                b"Asia/Damascus",
                b"asia/damascus",
                b"ASIA/DAMASCUS",
                b"aSIA/dAMASCUS",
                b"AsIa/dAmAsCuS",
                b"aSiA/DaMaScUs",
            ],
        ),
        (&time_zone::asia::DILI, time_zone::asia::RAW_DILI, &[
            b"Asia/Dili",
            b"asia/dili",
            b"ASIA/DILI",
            b"aSIA/dILI",
            b"AsIa/dIlI",
            b"aSiA/DiLi",
        ]),
        (&time_zone::asia::DUBAI, time_zone::asia::RAW_DUBAI, &[
            b"Asia/Dubai",
            b"asia/dubai",
            b"ASIA/DUBAI",
            b"aSIA/dUBAI",
            b"AsIa/dUbAi",
            b"aSiA/DuBaI",
        ]),
        (
            &time_zone::asia::DUSHANBE,
            time_zone::asia::RAW_DUSHANBE,
            &[
                b"Asia/Dushanbe",
                b"asia/dushanbe",
                b"ASIA/DUSHANBE",
                b"aSIA/dUSHANBE",
                b"AsIa/dUsHaNbE",
                b"aSiA/DuShAnBe",
            ],
        ),
        (
            &time_zone::asia::FAMAGUSTA,
            time_zone::asia::RAW_FAMAGUSTA,
            &[
                b"Asia/Famagusta",
                b"asia/famagusta",
                b"ASIA/FAMAGUSTA",
                b"aSIA/fAMAGUSTA",
                b"AsIa/fAmAgUsTa",
                b"aSiA/FaMaGuStA",
            ],
        ),
        (&time_zone::asia::GAZA, time_zone::asia::RAW_GAZA, &[
            b"Asia/Gaza",
            b"asia/gaza",
            b"ASIA/GAZA",
            b"aSIA/gAZA",
            b"AsIa/gAzA",
            b"aSiA/GaZa",
        ]),
        (&time_zone::asia::HEBRON, time_zone::asia::RAW_HEBRON, &[
            b"Asia/Hebron",
            b"asia/hebron",
            b"ASIA/HEBRON",
            b"aSIA/hEBRON",
            b"AsIa/hEbRoN",
            b"aSiA/HeBrOn",
        ]),
        (&time_zone::asia::HOVD, time_zone::asia::RAW_HOVD, &[
            b"Asia/Hovd",
            b"asia/hovd",
            b"ASIA/HOVD",
            b"aSIA/hOVD",
            b"AsIa/hOvD",
            b"aSiA/HoVd",
        ]),
        (
            &time_zone::asia::HO_CHI_MINH,
            time_zone::asia::RAW_HO_CHI_MINH,
            &[
                b"Asia/Ho_Chi_Minh",
                b"asia/ho_chi_minh",
                b"ASIA/HO_CHI_MINH",
                b"aSIA/hO_cHI_mINH",
                b"AsIa/hO_ChI_MiNh",
                b"aSiA/Ho_cHi_mInH",
            ],
        ),
        (&time_zone::asia::SAIGON, time_zone::asia::RAW_SAIGON, &[
            b"Asia/Saigon",
            b"asia/saigon",
            b"ASIA/SAIGON",
            b"aSIA/sAIGON",
            b"AsIa/sAiGoN",
            b"aSiA/SaIgOn",
        ]),
        (&time_zone::asia::IRKUTSK, time_zone::asia::RAW_IRKUTSK, &[
            b"Asia/Irkutsk",
            b"asia/irkutsk",
            b"ASIA/IRKUTSK",
            b"aSIA/iRKUTSK",
            b"AsIa/iRkUtSk",
            b"aSiA/IrKuTsK",
        ]),
        (&time_zone::asia::JAKARTA, time_zone::asia::RAW_JAKARTA, &[
            b"Asia/Jakarta",
            b"asia/jakarta",
            b"ASIA/JAKARTA",
            b"aSIA/jAKARTA",
            b"AsIa/jAkArTa",
            b"aSiA/JaKaRtA",
        ]),
        (
            &time_zone::asia::JAYAPURA,
            time_zone::asia::RAW_JAYAPURA,
            &[
                b"Asia/Jayapura",
                b"asia/jayapura",
                b"ASIA/JAYAPURA",
                b"aSIA/jAYAPURA",
                b"AsIa/jAyApUrA",
                b"aSiA/JaYaPuRa",
            ],
        ),
        (&time_zone::asia::KABUL, time_zone::asia::RAW_KABUL, &[
            b"Asia/Kabul",
            b"asia/kabul",
            b"ASIA/KABUL",
            b"aSIA/kABUL",
            b"AsIa/kAbUl",
            b"aSiA/KaBuL",
        ]),
        (
            &time_zone::asia::KAMCHATKA,
            time_zone::asia::RAW_KAMCHATKA,
            &[
                b"Asia/Kamchatka",
                b"asia/kamchatka",
                b"ASIA/KAMCHATKA",
                b"aSIA/kAMCHATKA",
                b"AsIa/kAmChAtKa",
                b"aSiA/KaMcHaTkA",
            ],
        ),
        (&time_zone::asia::KARACHI, time_zone::asia::RAW_KARACHI, &[
            b"Asia/Karachi",
            b"asia/karachi",
            b"ASIA/KARACHI",
            b"aSIA/kARACHI",
            b"AsIa/kArAcHi",
            b"aSiA/KaRaChI",
        ]),
        (&time_zone::asia::KASHGAR, time_zone::asia::RAW_KASHGAR, &[
            b"Asia/Kashgar",
            b"asia/kashgar",
            b"ASIA/KASHGAR",
            b"aSIA/kASHGAR",
            b"AsIa/kAsHgAr",
            b"aSiA/KaShGaR",
        ]),
        (&time_zone::asia::URUMQI, time_zone::asia::RAW_URUMQI, &[
            b"Asia/Urumqi",
            b"asia/urumqi",
            b"ASIA/URUMQI",
            b"aSIA/uRUMQI",
            b"AsIa/uRuMqI",
            b"aSiA/UrUmQi",
        ]),
        (
            &time_zone::asia::KATHMANDU,
            time_zone::asia::RAW_KATHMANDU,
            &[
                b"Asia/Kathmandu",
                b"asia/kathmandu",
                b"ASIA/KATHMANDU",
                b"aSIA/kATHMANDU",
                b"AsIa/kAtHmAnDu",
                b"aSiA/KaThMaNdU",
            ],
        ),
        (
            &time_zone::asia::KATMANDU,
            time_zone::asia::RAW_KATMANDU,
            &[
                b"Asia/Katmandu",
                b"asia/katmandu",
                b"ASIA/KATMANDU",
                b"aSIA/kATMANDU",
                b"AsIa/kAtMaNdU",
                b"aSiA/KaTmAnDu",
            ],
        ),
        (
            &time_zone::asia::KHANDYGA,
            time_zone::asia::RAW_KHANDYGA,
            &[
                b"Asia/Khandyga",
                b"asia/khandyga",
                b"ASIA/KHANDYGA",
                b"aSIA/kHANDYGA",
                b"AsIa/kHaNdYgA",
                b"aSiA/KhAnDyGa",
            ],
        ),
        (
            &time_zone::asia::KRASNOYARSK,
            time_zone::asia::RAW_KRASNOYARSK,
            &[
                b"Asia/Krasnoyarsk",
                b"asia/krasnoyarsk",
                b"ASIA/KRASNOYARSK",
                b"aSIA/kRASNOYARSK",
                b"AsIa/kRaSnOyArSk",
                b"aSiA/KrAsNoYaRsK",
            ],
        ),
        (
            &time_zone::asia::KUALA_LUMPUR,
            time_zone::asia::RAW_KUALA_LUMPUR,
            &[
                b"Asia/Kuala_Lumpur",
                b"asia/kuala_lumpur",
                b"ASIA/KUALA_LUMPUR",
                b"aSIA/kUALA_lUMPUR",
                b"AsIa/kUaLa_lUmPuR",
                b"aSiA/KuAlA_LuMpUr",
            ],
        ),
        (&time_zone::asia::KUCHING, time_zone::asia::RAW_KUCHING, &[
            b"Asia/Kuching",
            b"asia/kuching",
            b"ASIA/KUCHING",
            b"aSIA/kUCHING",
            b"AsIa/kUcHiNg",
            b"aSiA/KuChInG",
        ]),
        (&time_zone::asia::KUWAIT, time_zone::asia::RAW_KUWAIT, &[
            b"Asia/Kuwait",
            b"asia/kuwait",
            b"ASIA/KUWAIT",
            b"aSIA/kUWAIT",
            b"AsIa/kUwAiT",
            b"aSiA/KuWaIt",
        ]),
        (&time_zone::asia::MACAO, time_zone::asia::RAW_MACAO, &[
            b"Asia/Macao",
            b"asia/macao",
            b"ASIA/MACAO",
            b"aSIA/mACAO",
            b"AsIa/mAcAo",
            b"aSiA/MaCaO",
        ]),
        (&time_zone::asia::MACAU, time_zone::asia::RAW_MACAU, &[
            b"Asia/Macau",
            b"asia/macau",
            b"ASIA/MACAU",
            b"aSIA/mACAU",
            b"AsIa/mAcAu",
            b"aSiA/MaCaU",
        ]),
        (&time_zone::asia::MAGADAN, time_zone::asia::RAW_MAGADAN, &[
            b"Asia/Magadan",
            b"asia/magadan",
            b"ASIA/MAGADAN",
            b"aSIA/mAGADAN",
            b"AsIa/mAgAdAn",
            b"aSiA/MaGaDaN",
        ]),
        (
            &time_zone::asia::MAKASSAR,
            time_zone::asia::RAW_MAKASSAR,
            &[
                b"Asia/Makassar",
                b"asia/makassar",
                b"ASIA/MAKASSAR",
                b"aSIA/mAKASSAR",
                b"AsIa/mAkAsSaR",
                b"aSiA/MaKaSsAr",
            ],
        ),
        (
            &time_zone::asia::UJUNG_PANDANG,
            time_zone::asia::RAW_UJUNG_PANDANG,
            &[
                b"Asia/Ujung_Pandang",
                b"asia/ujung_pandang",
                b"ASIA/UJUNG_PANDANG",
                b"aSIA/uJUNG_pANDANG",
                b"AsIa/uJuNg_pAnDaNg",
                b"aSiA/UjUnG_PaNdAnG",
            ],
        ),
        (&time_zone::asia::MANILA, time_zone::asia::RAW_MANILA, &[
            b"Asia/Manila",
            b"asia/manila",
            b"ASIA/MANILA",
            b"aSIA/mANILA",
            b"AsIa/mAnIlA",
            b"aSiA/MaNiLa",
        ]),
        (&time_zone::asia::MUSCAT, time_zone::asia::RAW_MUSCAT, &[
            b"Asia/Muscat",
            b"asia/muscat",
            b"ASIA/MUSCAT",
            b"aSIA/mUSCAT",
            b"AsIa/mUsCaT",
            b"aSiA/MuScAt",
        ]),
        (&time_zone::asia::NICOSIA, time_zone::asia::RAW_NICOSIA, &[
            b"Asia/Nicosia",
            b"asia/nicosia",
            b"ASIA/NICOSIA",
            b"aSIA/nICOSIA",
            b"AsIa/nIcOsIa",
            b"aSiA/NiCoSiA",
        ]),
        (
            &time_zone::europe::NICOSIA,
            time_zone::europe::RAW_NICOSIA,
            &[
                b"Europe/Nicosia",
                b"europe/nicosia",
                b"EUROPE/NICOSIA",
                b"eUROPE/nICOSIA",
                b"EuRoPe/nIcOsIa",
                b"eUrOpE/NiCoSiA",
            ],
        ),
        (
            &time_zone::asia::NOVOKUZNETSK,
            time_zone::asia::RAW_NOVOKUZNETSK,
            &[
                b"Asia/Novokuznetsk",
                b"asia/novokuznetsk",
                b"ASIA/NOVOKUZNETSK",
                b"aSIA/nOVOKUZNETSK",
                b"AsIa/nOvOkUzNeTsK",
                b"aSiA/NoVoKuZnEtSk",
            ],
        ),
        (
            &time_zone::asia::NOVOSIBIRSK,
            time_zone::asia::RAW_NOVOSIBIRSK,
            &[
                b"Asia/Novosibirsk",
                b"asia/novosibirsk",
                b"ASIA/NOVOSIBIRSK",
                b"aSIA/nOVOSIBIRSK",
                b"AsIa/nOvOsIbIrSk",
                b"aSiA/NoVoSiBiRsK",
            ],
        ),
        (&time_zone::asia::OMSK, time_zone::asia::RAW_OMSK, &[
            b"Asia/Omsk",
            b"asia/omsk",
            b"ASIA/OMSK",
            b"aSIA/oMSK",
            b"AsIa/oMsK",
            b"aSiA/OmSk",
        ]),
        (&time_zone::asia::ORAL, time_zone::asia::RAW_ORAL, &[
            b"Asia/Oral",
            b"asia/oral",
            b"ASIA/ORAL",
            b"aSIA/oRAL",
            b"AsIa/oRaL",
            b"aSiA/OrAl",
        ]),
        (
            &time_zone::asia::PHNOM_PENH,
            time_zone::asia::RAW_PHNOM_PENH,
            &[
                b"Asia/Phnom_Penh",
                b"asia/phnom_penh",
                b"ASIA/PHNOM_PENH",
                b"aSIA/pHNOM_pENH",
                b"AsIa/pHnOm_pEnH",
                b"aSiA/PhNoM_PeNh",
            ],
        ),
        (
            &time_zone::asia::PONTIANAK,
            time_zone::asia::RAW_PONTIANAK,
            &[
                b"Asia/Pontianak",
                b"asia/pontianak",
                b"ASIA/PONTIANAK",
                b"aSIA/pONTIANAK",
                b"AsIa/pOnTiAnAk",
                b"aSiA/PoNtIaNaK",
            ],
        ),
        (
            &time_zone::asia::PYONGYANG,
            time_zone::asia::RAW_PYONGYANG,
            &[
                b"Asia/Pyongyang",
                b"asia/pyongyang",
                b"ASIA/PYONGYANG",
                b"aSIA/pYONGYANG",
                b"AsIa/pYoNgYaNg",
                b"aSiA/PyOnGyAnG",
            ],
        ),
        (&time_zone::asia::QATAR, time_zone::asia::RAW_QATAR, &[
            b"Asia/Qatar",
            b"asia/qatar",
            b"ASIA/QATAR",
            b"aSIA/qATAR",
            b"AsIa/qAtAr",
            b"aSiA/QaTaR",
        ]),
        (
            &time_zone::asia::QOSTANAY,
            time_zone::asia::RAW_QOSTANAY,
            &[
                b"Asia/Qostanay",
                b"asia/qostanay",
                b"ASIA/QOSTANAY",
                b"aSIA/qOSTANAY",
                b"AsIa/qOsTaNaY",
                b"aSiA/QoStAnAy",
            ],
        ),
        (
            &time_zone::asia::QYZYLORDA,
            time_zone::asia::RAW_QYZYLORDA,
            &[
                b"Asia/Qyzylorda",
                b"asia/qyzylorda",
                b"ASIA/QYZYLORDA",
                b"aSIA/qYZYLORDA",
                b"AsIa/qYzYlOrDa",
                b"aSiA/QyZyLoRdA",
            ],
        ),
        (&time_zone::asia::RANGOON, time_zone::asia::RAW_RANGOON, &[
            b"Asia/Rangoon",
            b"asia/rangoon",
            b"ASIA/RANGOON",
            b"aSIA/rANGOON",
            b"AsIa/rAnGoOn",
            b"aSiA/RaNgOoN",
        ]),
        (&time_zone::asia::YANGON, time_zone::asia::RAW_YANGON, &[
            b"Asia/Yangon",
            b"asia/yangon",
            b"ASIA/YANGON",
            b"aSIA/yANGON",
            b"AsIa/yAnGoN",
            b"aSiA/YaNgOn",
        ]),
        (&time_zone::asia::RIYADH, time_zone::asia::RAW_RIYADH, &[
            b"Asia/Riyadh",
            b"asia/riyadh",
            b"ASIA/RIYADH",
            b"aSIA/rIYADH",
            b"AsIa/rIyAdH",
            b"aSiA/RiYaDh",
        ]),
        (
            &time_zone::asia::SAKHALIN,
            time_zone::asia::RAW_SAKHALIN,
            &[
                b"Asia/Sakhalin",
                b"asia/sakhalin",
                b"ASIA/SAKHALIN",
                b"aSIA/sAKHALIN",
                b"AsIa/sAkHaLiN",
                b"aSiA/SaKhAlIn",
            ],
        ),
        (
            &time_zone::asia::SAMARKAND,
            time_zone::asia::RAW_SAMARKAND,
            &[
                b"Asia/Samarkand",
                b"asia/samarkand",
                b"ASIA/SAMARKAND",
                b"aSIA/sAMARKAND",
                b"AsIa/sAmArKaNd",
                b"aSiA/SaMaRkAnD",
            ],
        ),
        (
            &time_zone::asia::SREDNEKOLYMSK,
            time_zone::asia::RAW_SREDNEKOLYMSK,
            &[
                b"Asia/Srednekolymsk",
                b"asia/srednekolymsk",
                b"ASIA/SREDNEKOLYMSK",
                b"aSIA/sREDNEKOLYMSK",
                b"AsIa/sReDnEkOlYmSk",
                b"aSiA/SrEdNeKoLyMsK",
            ],
        ),
        (
            &time_zone::asia::TASHKENT,
            time_zone::asia::RAW_TASHKENT,
            &[
                b"Asia/Tashkent",
                b"asia/tashkent",
                b"ASIA/TASHKENT",
                b"aSIA/tASHKENT",
                b"AsIa/tAsHkEnT",
                b"aSiA/TaShKeNt",
            ],
        ),
        (&time_zone::asia::TBILISI, time_zone::asia::RAW_TBILISI, &[
            b"Asia/Tbilisi",
            b"asia/tbilisi",
            b"ASIA/TBILISI",
            b"aSIA/tBILISI",
            b"AsIa/tBiLiSi",
            b"aSiA/TbIlIsI",
        ]),
        (&time_zone::asia::THIMBU, time_zone::asia::RAW_THIMBU, &[
            b"Asia/Thimbu",
            b"asia/thimbu",
            b"ASIA/THIMBU",
            b"aSIA/tHIMBU",
            b"AsIa/tHiMbU",
            b"aSiA/ThImBu",
        ]),
        (&time_zone::asia::THIMPHU, time_zone::asia::RAW_THIMPHU, &[
            b"Asia/Thimphu",
            b"asia/thimphu",
            b"ASIA/THIMPHU",
            b"aSIA/tHIMPHU",
            b"AsIa/tHiMpHu",
            b"aSiA/ThImPhU",
        ]),
        (&time_zone::asia::TOMSK, time_zone::asia::RAW_TOMSK, &[
            b"Asia/Tomsk",
            b"asia/tomsk",
            b"ASIA/TOMSK",
            b"aSIA/tOMSK",
            b"AsIa/tOmSk",
            b"aSiA/ToMsK",
        ]),
        (
            &time_zone::asia::UST_NERA,
            time_zone::asia::RAW_UST_NERA,
            &[
                b"Asia/Ust-Nera",
                b"asia/ust-nera",
                b"ASIA/UST-NERA",
                b"aSIA/uST-nERA",
                b"AsIa/uSt-nErA",
                b"aSiA/UsT-NeRa",
            ],
        ),
        (
            &time_zone::asia::VIENTIANE,
            time_zone::asia::RAW_VIENTIANE,
            &[
                b"Asia/Vientiane",
                b"asia/vientiane",
                b"ASIA/VIENTIANE",
                b"aSIA/vIENTIANE",
                b"AsIa/vIeNtIaNe",
                b"aSiA/ViEnTiAnE",
            ],
        ),
        (
            &time_zone::asia::VLADIVOSTOK,
            time_zone::asia::RAW_VLADIVOSTOK,
            &[
                b"Asia/Vladivostok",
                b"asia/vladivostok",
                b"ASIA/VLADIVOSTOK",
                b"aSIA/vLADIVOSTOK",
                b"AsIa/vLaDiVoStOk",
                b"aSiA/VlAdIvOsToK",
            ],
        ),
        (&time_zone::asia::YAKUTSK, time_zone::asia::RAW_YAKUTSK, &[
            b"Asia/Yakutsk",
            b"asia/yakutsk",
            b"ASIA/YAKUTSK",
            b"aSIA/yAKUTSK",
            b"AsIa/yAkUtSk",
            b"aSiA/YaKuTsK",
        ]),
        (
            &time_zone::asia::YEKATERINBURG,
            time_zone::asia::RAW_YEKATERINBURG,
            &[
                b"Asia/Yekaterinburg",
                b"asia/yekaterinburg",
                b"ASIA/YEKATERINBURG",
                b"aSIA/yEKATERINBURG",
                b"AsIa/yEkAtErInBuRg",
                b"aSiA/YeKaTeRiNbUrG",
            ],
        ),
        (&time_zone::asia::YEREVAN, time_zone::asia::RAW_YEREVAN, &[
            b"Asia/Yerevan",
            b"asia/yerevan",
            b"ASIA/YEREVAN",
            b"aSIA/yEREVAN",
            b"AsIa/yErEvAn",
            b"aSiA/YeReVaN",
        ]),
        (
            &time_zone::atlantic::AZORES,
            time_zone::atlantic::RAW_AZORES,
            &[
                b"Atlantic/Azores",
                b"atlantic/azores",
                b"ATLANTIC/AZORES",
                b"aTLANTIC/aZORES",
                b"AtLaNtIc/aZoReS",
                b"aTlAnTiC/AzOrEs",
            ],
        ),
        (
            &time_zone::atlantic::BERMUDA,
            time_zone::atlantic::RAW_BERMUDA,
            &[
                b"Atlantic/Bermuda",
                b"atlantic/bermuda",
                b"ATLANTIC/BERMUDA",
                b"aTLANTIC/bERMUDA",
                b"AtLaNtIc/bErMuDa",
                b"aTlAnTiC/BeRmUdA",
            ],
        ),
        (
            &time_zone::atlantic::CANARY,
            time_zone::atlantic::RAW_CANARY,
            &[
                b"Atlantic/Canary",
                b"atlantic/canary",
                b"ATLANTIC/CANARY",
                b"aTLANTIC/cANARY",
                b"AtLaNtIc/cAnArY",
                b"aTlAnTiC/CaNaRy",
            ],
        ),
        (
            &time_zone::atlantic::CAPE_VERDE,
            time_zone::atlantic::RAW_CAPE_VERDE,
            &[
                b"Atlantic/Cape_Verde",
                b"atlantic/cape_verde",
                b"ATLANTIC/CAPE_VERDE",
                b"aTLANTIC/cAPE_vERDE",
                b"AtLaNtIc/cApE_VeRdE",
                b"aTlAnTiC/CaPe_vErDe",
            ],
        ),
        (
            &time_zone::atlantic::FAEROE,
            time_zone::atlantic::RAW_FAEROE,
            &[
                b"Atlantic/Faeroe",
                b"atlantic/faeroe",
                b"ATLANTIC/FAEROE",
                b"aTLANTIC/fAEROE",
                b"AtLaNtIc/fAeRoE",
                b"aTlAnTiC/FaErOe",
            ],
        ),
        (
            &time_zone::atlantic::FAROE,
            time_zone::atlantic::RAW_FAROE,
            &[
                b"Atlantic/Faroe",
                b"atlantic/faroe",
                b"ATLANTIC/FAROE",
                b"aTLANTIC/fAROE",
                b"AtLaNtIc/fArOe",
                b"aTlAnTiC/FaRoE",
            ],
        ),
        (
            &time_zone::atlantic::MADEIRA,
            time_zone::atlantic::RAW_MADEIRA,
            &[
                b"Atlantic/Madeira",
                b"atlantic/madeira",
                b"ATLANTIC/MADEIRA",
                b"aTLANTIC/mADEIRA",
                b"AtLaNtIc/mAdEiRa",
                b"aTlAnTiC/MaDeIrA",
            ],
        ),
        (
            &time_zone::atlantic::REYKJAVIK,
            time_zone::atlantic::RAW_REYKJAVIK,
            &[
                b"Atlantic/Reykjavik",
                b"atlantic/reykjavik",
                b"ATLANTIC/REYKJAVIK",
                b"aTLANTIC/rEYKJAVIK",
                b"AtLaNtIc/rEyKjAvIk",
                b"aTlAnTiC/ReYkJaViK",
            ],
        ),
        (
            &time_zone::atlantic::SOUTH_GEORGIA,
            time_zone::atlantic::RAW_SOUTH_GEORGIA,
            &[
                b"Atlantic/South_Georgia",
                b"atlantic/south_georgia",
                b"ATLANTIC/SOUTH_GEORGIA",
                b"aTLANTIC/sOUTH_gEORGIA",
                b"AtLaNtIc/sOuTh_gEoRgIa",
                b"aTlAnTiC/SoUtH_GeOrGiA",
            ],
        ),
        (
            &time_zone::atlantic::STANLEY,
            time_zone::atlantic::RAW_STANLEY,
            &[
                b"Atlantic/Stanley",
                b"atlantic/stanley",
                b"ATLANTIC/STANLEY",
                b"aTLANTIC/sTANLEY",
                b"AtLaNtIc/sTaNlEy",
                b"aTlAnTiC/StAnLeY",
            ],
        ),
        (
            &time_zone::atlantic::ST_HELENA,
            time_zone::atlantic::RAW_ST_HELENA,
            &[
                b"Atlantic/St_Helena",
                b"atlantic/st_helena",
                b"ATLANTIC/ST_HELENA",
                b"aTLANTIC/sT_hELENA",
                b"AtLaNtIc/sT_HeLeNa",
                b"aTlAnTiC/St_hElEnA",
            ],
        ),
        (
            &time_zone::australia::ACT,
            time_zone::australia::RAW_ACT,
            &[
                b"Australia/ACT",
                b"australia/act",
                b"AUSTRALIA/ACT",
                b"aUSTRALIA/act",
                b"AuStRaLiA/AcT",
                b"aUsTrAlIa/aCt",
            ],
        ),
        (
            &time_zone::australia::CANBERRA,
            time_zone::australia::RAW_CANBERRA,
            &[
                b"Australia/Canberra",
                b"australia/canberra",
                b"AUSTRALIA/CANBERRA",
                b"aUSTRALIA/cANBERRA",
                b"AuStRaLiA/CaNbErRa",
                b"aUsTrAlIa/cAnBeRrA",
            ],
        ),
        (
            &time_zone::australia::NSW,
            time_zone::australia::RAW_NSW,
            &[
                b"Australia/NSW",
                b"australia/nsw",
                b"AUSTRALIA/NSW",
                b"aUSTRALIA/nsw",
                b"AuStRaLiA/NsW",
                b"aUsTrAlIa/nSw",
            ],
        ),
        (
            &time_zone::australia::SYDNEY,
            time_zone::australia::RAW_SYDNEY,
            &[
                b"Australia/Sydney",
                b"australia/sydney",
                b"AUSTRALIA/SYDNEY",
                b"aUSTRALIA/sYDNEY",
                b"AuStRaLiA/SyDnEy",
                b"aUsTrAlIa/sYdNeY",
            ],
        ),
        (
            &time_zone::australia::ADELAIDE,
            time_zone::australia::RAW_ADELAIDE,
            &[
                b"Australia/Adelaide",
                b"australia/adelaide",
                b"AUSTRALIA/ADELAIDE",
                b"aUSTRALIA/aDELAIDE",
                b"AuStRaLiA/AdElAiDe",
                b"aUsTrAlIa/aDeLaIdE",
            ],
        ),
        (
            &time_zone::australia::SOUTH,
            time_zone::australia::RAW_SOUTH,
            &[
                b"Australia/South",
                b"australia/south",
                b"AUSTRALIA/SOUTH",
                b"aUSTRALIA/sOUTH",
                b"AuStRaLiA/SoUtH",
                b"aUsTrAlIa/sOuTh",
            ],
        ),
        (
            &time_zone::australia::BRISBANE,
            time_zone::australia::RAW_BRISBANE,
            &[
                b"Australia/Brisbane",
                b"australia/brisbane",
                b"AUSTRALIA/BRISBANE",
                b"aUSTRALIA/bRISBANE",
                b"AuStRaLiA/BrIsBaNe",
                b"aUsTrAlIa/bRiSbAnE",
            ],
        ),
        (
            &time_zone::australia::QUEENSLAND,
            time_zone::australia::RAW_QUEENSLAND,
            &[
                b"Australia/Queensland",
                b"australia/queensland",
                b"AUSTRALIA/QUEENSLAND",
                b"aUSTRALIA/qUEENSLAND",
                b"AuStRaLiA/QuEeNsLaNd",
                b"aUsTrAlIa/qUeEnSlAnD",
            ],
        ),
        (
            &time_zone::australia::BROKEN_HILL,
            time_zone::australia::RAW_BROKEN_HILL,
            &[
                b"Australia/Broken_Hill",
                b"australia/broken_hill",
                b"AUSTRALIA/BROKEN_HILL",
                b"aUSTRALIA/bROKEN_hILL",
                b"AuStRaLiA/BrOkEn_hIlL",
                b"aUsTrAlIa/bRoKeN_HiLl",
            ],
        ),
        (
            &time_zone::australia::YANCOWINNA,
            time_zone::australia::RAW_YANCOWINNA,
            &[
                b"Australia/Yancowinna",
                b"australia/yancowinna",
                b"AUSTRALIA/YANCOWINNA",
                b"aUSTRALIA/yANCOWINNA",
                b"AuStRaLiA/YaNcOwInNa",
                b"aUsTrAlIa/yAnCoWiNnA",
            ],
        ),
        (
            &time_zone::australia::CURRIE,
            time_zone::australia::RAW_CURRIE,
            &[
                b"Australia/Currie",
                b"australia/currie",
                b"AUSTRALIA/CURRIE",
                b"aUSTRALIA/cURRIE",
                b"AuStRaLiA/CuRrIe",
                b"aUsTrAlIa/cUrRiE",
            ],
        ),
        (
            &time_zone::australia::HOBART,
            time_zone::australia::RAW_HOBART,
            &[
                b"Australia/Hobart",
                b"australia/hobart",
                b"AUSTRALIA/HOBART",
                b"aUSTRALIA/hOBART",
                b"AuStRaLiA/HoBaRt",
                b"aUsTrAlIa/hObArT",
            ],
        ),
        (
            &time_zone::australia::TASMANIA,
            time_zone::australia::RAW_TASMANIA,
            &[
                b"Australia/Tasmania",
                b"australia/tasmania",
                b"AUSTRALIA/TASMANIA",
                b"aUSTRALIA/tASMANIA",
                b"AuStRaLiA/TaSmAnIa",
                b"aUsTrAlIa/tAsMaNiA",
            ],
        ),
        (
            &time_zone::australia::DARWIN,
            time_zone::australia::RAW_DARWIN,
            &[
                b"Australia/Darwin",
                b"australia/darwin",
                b"AUSTRALIA/DARWIN",
                b"aUSTRALIA/dARWIN",
                b"AuStRaLiA/DaRwIn",
                b"aUsTrAlIa/dArWiN",
            ],
        ),
        (
            &time_zone::australia::NORTH,
            time_zone::australia::RAW_NORTH,
            &[
                b"Australia/North",
                b"australia/north",
                b"AUSTRALIA/NORTH",
                b"aUSTRALIA/nORTH",
                b"AuStRaLiA/NoRtH",
                b"aUsTrAlIa/nOrTh",
            ],
        ),
        (
            &time_zone::australia::EUCLA,
            time_zone::australia::RAW_EUCLA,
            &[
                b"Australia/Eucla",
                b"australia/eucla",
                b"AUSTRALIA/EUCLA",
                b"aUSTRALIA/eUCLA",
                b"AuStRaLiA/EuClA",
                b"aUsTrAlIa/eUcLa",
            ],
        ),
        (
            &time_zone::australia::LHI,
            time_zone::australia::RAW_LHI,
            &[
                b"Australia/LHI",
                b"australia/lhi",
                b"AUSTRALIA/LHI",
                b"aUSTRALIA/lhi",
                b"AuStRaLiA/LhI",
                b"aUsTrAlIa/lHi",
            ],
        ),
        (
            &time_zone::australia::LORD_HOWE,
            time_zone::australia::RAW_LORD_HOWE,
            &[
                b"Australia/Lord_Howe",
                b"australia/lord_howe",
                b"AUSTRALIA/LORD_HOWE",
                b"aUSTRALIA/lORD_hOWE",
                b"AuStRaLiA/LoRd_hOwE",
                b"aUsTrAlIa/lOrD_HoWe",
            ],
        ),
        (
            &time_zone::australia::LINDEMAN,
            time_zone::australia::RAW_LINDEMAN,
            &[
                b"Australia/Lindeman",
                b"australia/lindeman",
                b"AUSTRALIA/LINDEMAN",
                b"aUSTRALIA/lINDEMAN",
                b"AuStRaLiA/LiNdEmAn",
                b"aUsTrAlIa/lInDeMaN",
            ],
        ),
        (
            &time_zone::australia::MELBOURNE,
            time_zone::australia::RAW_MELBOURNE,
            &[
                b"Australia/Melbourne",
                b"australia/melbourne",
                b"AUSTRALIA/MELBOURNE",
                b"aUSTRALIA/mELBOURNE",
                b"AuStRaLiA/MeLbOuRnE",
                b"aUsTrAlIa/mElBoUrNe",
            ],
        ),
        (
            &time_zone::australia::VICTORIA,
            time_zone::australia::RAW_VICTORIA,
            &[
                b"Australia/Victoria",
                b"australia/victoria",
                b"AUSTRALIA/VICTORIA",
                b"aUSTRALIA/vICTORIA",
                b"AuStRaLiA/ViCtOrIa",
                b"aUsTrAlIa/vIcToRiA",
            ],
        ),
        (
            &time_zone::australia::PERTH,
            time_zone::australia::RAW_PERTH,
            &[
                b"Australia/Perth",
                b"australia/perth",
                b"AUSTRALIA/PERTH",
                b"aUSTRALIA/pERTH",
                b"AuStRaLiA/PeRtH",
                b"aUsTrAlIa/pErTh",
            ],
        ),
        (
            &time_zone::australia::WEST,
            time_zone::australia::RAW_WEST,
            &[
                b"Australia/West",
                b"australia/west",
                b"AUSTRALIA/WEST",
                b"aUSTRALIA/wEST",
                b"AuStRaLiA/WeSt",
                b"aUsTrAlIa/wEsT",
            ],
        ),
        (&time_zone::CET, time_zone::RAW_CET, &[
            b"CET", b"cet", b"CET", b"cet", b"CeT", b"cEt",
        ]),
        (&time_zone::MET, time_zone::RAW_MET, &[
            b"MET", b"met", b"MET", b"met", b"MeT", b"mEt",
        ]),
        (
            &time_zone::europe::BRUSSELS,
            time_zone::europe::RAW_BRUSSELS,
            &[
                b"Europe/Brussels",
                b"europe/brussels",
                b"EUROPE/BRUSSELS",
                b"eUROPE/bRUSSELS",
                b"EuRoPe/bRuSsElS",
                b"eUrOpE/BrUsSeLs",
            ],
        ),
        (
            &time_zone::chile::EASTER_ISLAND,
            time_zone::chile::RAW_EASTER_ISLAND,
            &[
                b"Chile/EasterIsland",
                b"chile/easterisland",
                b"CHILE/EASTERISLAND",
                b"cHILE/eASTERiSLAND",
                b"ChIlE/EaStErIsLaNd",
                b"cHiLe/eAsTeRiSlAnD",
            ],
        ),
        (
            &time_zone::pacific::EASTER,
            time_zone::pacific::RAW_EASTER,
            &[
                b"Pacific/Easter",
                b"pacific/easter",
                b"PACIFIC/EASTER",
                b"pACIFIC/eASTER",
                b"PaCiFiC/EaStEr",
                b"pAcIfIc/eAsTeR",
            ],
        ),
        (&time_zone::CST_6_CDT, time_zone::RAW_CST_6_CDT, &[
            b"CST6CDT", b"cst6cdt", b"CST6CDT", b"cst6cdt", b"CsT6CdT", b"cSt6cDt",
        ]),
        (
            &time_zone::america::CHICAGO,
            time_zone::america::RAW_CHICAGO,
            &[
                b"America/Chicago",
                b"america/chicago",
                b"AMERICA/CHICAGO",
                b"aMERICA/cHICAGO",
                b"AmErIcA/ChIcAgO",
                b"aMeRiCa/cHiCaGo",
            ],
        ),
        (&time_zone::us::CENTRAL, time_zone::us::RAW_CENTRAL, &[
            b"US/Central",
            b"us/central",
            b"US/CENTRAL",
            b"us/cENTRAL",
            b"Us/cEnTrAl",
            b"uS/CeNtRaL",
        ]),
        (&time_zone::CUBA, time_zone::RAW_CUBA, &[
            b"Cuba", b"cuba", b"CUBA", b"cUBA", b"CuBa", b"cUbA",
        ]),
        (
            &time_zone::america::HAVANA,
            time_zone::america::RAW_HAVANA,
            &[
                b"America/Havana",
                b"america/havana",
                b"AMERICA/HAVANA",
                b"aMERICA/hAVANA",
                b"AmErIcA/HaVaNa",
                b"aMeRiCa/hAvAnA",
            ],
        ),
        (&time_zone::EET, time_zone::RAW_EET, &[
            b"EET", b"eet", b"EET", b"eet", b"EeT", b"eEt",
        ]),
        (
            &time_zone::europe::ATHENS,
            time_zone::europe::RAW_ATHENS,
            &[
                b"Europe/Athens",
                b"europe/athens",
                b"EUROPE/ATHENS",
                b"eUROPE/aTHENS",
                b"EuRoPe/aThEnS",
                b"eUrOpE/AtHeNs",
            ],
        ),
        (&time_zone::EGYPT, time_zone::RAW_EGYPT, &[
            b"Egypt", b"egypt", b"EGYPT", b"eGYPT", b"EgYpT", b"eGyPt",
        ]),
        (&time_zone::africa::CAIRO, time_zone::africa::RAW_CAIRO, &[
            b"Africa/Cairo",
            b"africa/cairo",
            b"AFRICA/CAIRO",
            b"aFRICA/cAIRO",
            b"AfRiCa/cAiRo",
            b"aFrIcA/CaIrO",
        ]),
        (&time_zone::EIRE, time_zone::RAW_EIRE, &[
            b"Eire", b"eire", b"EIRE", b"eIRE", b"EiRe", b"eIrE",
        ]),
        (
            &time_zone::europe::DUBLIN,
            time_zone::europe::RAW_DUBLIN,
            &[
                b"Europe/Dublin",
                b"europe/dublin",
                b"EUROPE/DUBLIN",
                b"eUROPE/dUBLIN",
                b"EuRoPe/dUbLiN",
                b"eUrOpE/DuBlIn",
            ],
        ),
        (&time_zone::EST, time_zone::RAW_EST, &[
            b"EST", b"est", b"EST", b"est", b"EsT", b"eSt",
        ]),
        (
            &time_zone::america::CORAL_HARBOUR,
            time_zone::america::RAW_CORAL_HARBOUR,
            &[
                b"America/Coral_Harbour",
                b"america/coral_harbour",
                b"AMERICA/CORAL_HARBOUR",
                b"aMERICA/cORAL_hARBOUR",
                b"AmErIcA/CoRaL_HaRbOuR",
                b"aMeRiCa/cOrAl_hArBoUr",
            ],
        ),
        (
            &time_zone::america::PANAMA,
            time_zone::america::RAW_PANAMA,
            &[
                b"America/Panama",
                b"america/panama",
                b"AMERICA/PANAMA",
                b"aMERICA/pANAMA",
                b"AmErIcA/PaNaMa",
                b"aMeRiCa/pAnAmA",
            ],
        ),
        (&time_zone::EST_5_EDT, time_zone::RAW_EST_5_EDT, &[
            b"EST5EDT", b"est5edt", b"EST5EDT", b"est5edt", b"EsT5EdT", b"eSt5eDt",
        ]),
        (
            &time_zone::america::NEW_YORK,
            time_zone::america::RAW_NEW_YORK,
            &[
                b"America/New_York",
                b"america/new_york",
                b"AMERICA/NEW_YORK",
                b"aMERICA/nEW_yORK",
                b"AmErIcA/NeW_YoRk",
                b"aMeRiCa/nEw_yOrK",
            ],
        ),
        (&time_zone::us::EASTERN, time_zone::us::RAW_EASTERN, &[
            b"US/Eastern",
            b"us/eastern",
            b"US/EASTERN",
            b"us/eASTERN",
            b"Us/eAsTeRn",
            b"uS/EaStErN",
        ]),
        (
            &time_zone::etc::GMT_MINUS_1,
            time_zone::etc::RAW_GMT_MINUS_1,
            &[
                b"Etc/GMT-1",
                b"etc/gmt-1",
                b"ETC/GMT-1",
                b"eTC/gmt-1",
                b"EtC/GmT-1",
                b"eTc/gMt-1",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_10,
            time_zone::etc::RAW_GMT_MINUS_10,
            &[
                b"Etc/GMT-10",
                b"etc/gmt-10",
                b"ETC/GMT-10",
                b"eTC/gmt-10",
                b"EtC/GmT-10",
                b"eTc/gMt-10",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_11,
            time_zone::etc::RAW_GMT_MINUS_11,
            &[
                b"Etc/GMT-11",
                b"etc/gmt-11",
                b"ETC/GMT-11",
                b"eTC/gmt-11",
                b"EtC/GmT-11",
                b"eTc/gMt-11",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_12,
            time_zone::etc::RAW_GMT_MINUS_12,
            &[
                b"Etc/GMT-12",
                b"etc/gmt-12",
                b"ETC/GMT-12",
                b"eTC/gmt-12",
                b"EtC/GmT-12",
                b"eTc/gMt-12",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_13,
            time_zone::etc::RAW_GMT_MINUS_13,
            &[
                b"Etc/GMT-13",
                b"etc/gmt-13",
                b"ETC/GMT-13",
                b"eTC/gmt-13",
                b"EtC/GmT-13",
                b"eTc/gMt-13",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_14,
            time_zone::etc::RAW_GMT_MINUS_14,
            &[
                b"Etc/GMT-14",
                b"etc/gmt-14",
                b"ETC/GMT-14",
                b"eTC/gmt-14",
                b"EtC/GmT-14",
                b"eTc/gMt-14",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_2,
            time_zone::etc::RAW_GMT_MINUS_2,
            &[
                b"Etc/GMT-2",
                b"etc/gmt-2",
                b"ETC/GMT-2",
                b"eTC/gmt-2",
                b"EtC/GmT-2",
                b"eTc/gMt-2",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_3,
            time_zone::etc::RAW_GMT_MINUS_3,
            &[
                b"Etc/GMT-3",
                b"etc/gmt-3",
                b"ETC/GMT-3",
                b"eTC/gmt-3",
                b"EtC/GmT-3",
                b"eTc/gMt-3",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_4,
            time_zone::etc::RAW_GMT_MINUS_4,
            &[
                b"Etc/GMT-4",
                b"etc/gmt-4",
                b"ETC/GMT-4",
                b"eTC/gmt-4",
                b"EtC/GmT-4",
                b"eTc/gMt-4",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_5,
            time_zone::etc::RAW_GMT_MINUS_5,
            &[
                b"Etc/GMT-5",
                b"etc/gmt-5",
                b"ETC/GMT-5",
                b"eTC/gmt-5",
                b"EtC/GmT-5",
                b"eTc/gMt-5",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_6,
            time_zone::etc::RAW_GMT_MINUS_6,
            &[
                b"Etc/GMT-6",
                b"etc/gmt-6",
                b"ETC/GMT-6",
                b"eTC/gmt-6",
                b"EtC/GmT-6",
                b"eTc/gMt-6",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_7,
            time_zone::etc::RAW_GMT_MINUS_7,
            &[
                b"Etc/GMT-7",
                b"etc/gmt-7",
                b"ETC/GMT-7",
                b"eTC/gmt-7",
                b"EtC/GmT-7",
                b"eTc/gMt-7",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_8,
            time_zone::etc::RAW_GMT_MINUS_8,
            &[
                b"Etc/GMT-8",
                b"etc/gmt-8",
                b"ETC/GMT-8",
                b"eTC/gmt-8",
                b"EtC/GmT-8",
                b"eTc/gMt-8",
            ],
        ),
        (
            &time_zone::etc::GMT_MINUS_9,
            time_zone::etc::RAW_GMT_MINUS_9,
            &[
                b"Etc/GMT-9",
                b"etc/gmt-9",
                b"ETC/GMT-9",
                b"eTC/gmt-9",
                b"EtC/GmT-9",
                b"eTc/gMt-9",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_1,
            time_zone::etc::RAW_GMT_PLUS_1,
            &[
                b"Etc/GMT+1",
                b"etc/gmt+1",
                b"ETC/GMT+1",
                b"eTC/gmt+1",
                b"EtC/GmT+1",
                b"eTc/gMt+1",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_10,
            time_zone::etc::RAW_GMT_PLUS_10,
            &[
                b"Etc/GMT+10",
                b"etc/gmt+10",
                b"ETC/GMT+10",
                b"eTC/gmt+10",
                b"EtC/GmT+10",
                b"eTc/gMt+10",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_11,
            time_zone::etc::RAW_GMT_PLUS_11,
            &[
                b"Etc/GMT+11",
                b"etc/gmt+11",
                b"ETC/GMT+11",
                b"eTC/gmt+11",
                b"EtC/GmT+11",
                b"eTc/gMt+11",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_12,
            time_zone::etc::RAW_GMT_PLUS_12,
            &[
                b"Etc/GMT+12",
                b"etc/gmt+12",
                b"ETC/GMT+12",
                b"eTC/gmt+12",
                b"EtC/GmT+12",
                b"eTc/gMt+12",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_2,
            time_zone::etc::RAW_GMT_PLUS_2,
            &[
                b"Etc/GMT+2",
                b"etc/gmt+2",
                b"ETC/GMT+2",
                b"eTC/gmt+2",
                b"EtC/GmT+2",
                b"eTc/gMt+2",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_3,
            time_zone::etc::RAW_GMT_PLUS_3,
            &[
                b"Etc/GMT+3",
                b"etc/gmt+3",
                b"ETC/GMT+3",
                b"eTC/gmt+3",
                b"EtC/GmT+3",
                b"eTc/gMt+3",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_4,
            time_zone::etc::RAW_GMT_PLUS_4,
            &[
                b"Etc/GMT+4",
                b"etc/gmt+4",
                b"ETC/GMT+4",
                b"eTC/gmt+4",
                b"EtC/GmT+4",
                b"eTc/gMt+4",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_5,
            time_zone::etc::RAW_GMT_PLUS_5,
            &[
                b"Etc/GMT+5",
                b"etc/gmt+5",
                b"ETC/GMT+5",
                b"eTC/gmt+5",
                b"EtC/GmT+5",
                b"eTc/gMt+5",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_6,
            time_zone::etc::RAW_GMT_PLUS_6,
            &[
                b"Etc/GMT+6",
                b"etc/gmt+6",
                b"ETC/GMT+6",
                b"eTC/gmt+6",
                b"EtC/GmT+6",
                b"eTc/gMt+6",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_7,
            time_zone::etc::RAW_GMT_PLUS_7,
            &[
                b"Etc/GMT+7",
                b"etc/gmt+7",
                b"ETC/GMT+7",
                b"eTC/gmt+7",
                b"EtC/GmT+7",
                b"eTc/gMt+7",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_8,
            time_zone::etc::RAW_GMT_PLUS_8,
            &[
                b"Etc/GMT+8",
                b"etc/gmt+8",
                b"ETC/GMT+8",
                b"eTC/gmt+8",
                b"EtC/GmT+8",
                b"eTc/gMt+8",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_9,
            time_zone::etc::RAW_GMT_PLUS_9,
            &[
                b"Etc/GMT+9",
                b"etc/gmt+9",
                b"ETC/GMT+9",
                b"eTC/gmt+9",
                b"EtC/GmT+9",
                b"eTc/gMt+9",
            ],
        ),
        (
            &time_zone::europe::AMSTERDAM,
            time_zone::europe::RAW_AMSTERDAM,
            &[
                b"Europe/Amsterdam",
                b"europe/amsterdam",
                b"EUROPE/AMSTERDAM",
                b"eUROPE/aMSTERDAM",
                b"EuRoPe/aMsTeRdAm",
                b"eUrOpE/AmStErDaM",
            ],
        ),
        (
            &time_zone::europe::ANDORRA,
            time_zone::europe::RAW_ANDORRA,
            &[
                b"Europe/Andorra",
                b"europe/andorra",
                b"EUROPE/ANDORRA",
                b"eUROPE/aNDORRA",
                b"EuRoPe/aNdOrRa",
                b"eUrOpE/AnDoRrA",
            ],
        ),
        (
            &time_zone::europe::ASTRAKHAN,
            time_zone::europe::RAW_ASTRAKHAN,
            &[
                b"Europe/Astrakhan",
                b"europe/astrakhan",
                b"EUROPE/ASTRAKHAN",
                b"eUROPE/aSTRAKHAN",
                b"EuRoPe/aStRaKhAn",
                b"eUrOpE/AsTrAkHaN",
            ],
        ),
        (
            &time_zone::europe::BELGRADE,
            time_zone::europe::RAW_BELGRADE,
            &[
                b"Europe/Belgrade",
                b"europe/belgrade",
                b"EUROPE/BELGRADE",
                b"eUROPE/bELGRADE",
                b"EuRoPe/bElGrAdE",
                b"eUrOpE/BeLgRaDe",
            ],
        ),
        (
            &time_zone::europe::PODGORICA,
            time_zone::europe::RAW_PODGORICA,
            &[
                b"Europe/Podgorica",
                b"europe/podgorica",
                b"EUROPE/PODGORICA",
                b"eUROPE/pODGORICA",
                b"EuRoPe/pOdGoRiCa",
                b"eUrOpE/PoDgOrIcA",
            ],
        ),
        (
            &time_zone::europe::BRATISLAVA,
            time_zone::europe::RAW_BRATISLAVA,
            &[
                b"Europe/Bratislava",
                b"europe/bratislava",
                b"EUROPE/BRATISLAVA",
                b"eUROPE/bRATISLAVA",
                b"EuRoPe/bRaTiSlAvA",
                b"eUrOpE/BrAtIsLaVa",
            ],
        ),
        (
            &time_zone::europe::PRAGUE,
            time_zone::europe::RAW_PRAGUE,
            &[
                b"Europe/Prague",
                b"europe/prague",
                b"EUROPE/PRAGUE",
                b"eUROPE/pRAGUE",
                b"EuRoPe/pRaGuE",
                b"eUrOpE/PrAgUe",
            ],
        ),
        (
            &time_zone::europe::BUCHAREST,
            time_zone::europe::RAW_BUCHAREST,
            &[
                b"Europe/Bucharest",
                b"europe/bucharest",
                b"EUROPE/BUCHAREST",
                b"eUROPE/bUCHAREST",
                b"EuRoPe/bUcHaReSt",
                b"eUrOpE/BuChArEsT",
            ],
        ),
        (
            &time_zone::europe::BUDAPEST,
            time_zone::europe::RAW_BUDAPEST,
            &[
                b"Europe/Budapest",
                b"europe/budapest",
                b"EUROPE/BUDAPEST",
                b"eUROPE/bUDAPEST",
                b"EuRoPe/bUdApEsT",
                b"eUrOpE/BuDaPeSt",
            ],
        ),
        (
            &time_zone::europe::BUSINGEN,
            time_zone::europe::RAW_BUSINGEN,
            &[
                b"Europe/Busingen",
                b"europe/busingen",
                b"EUROPE/BUSINGEN",
                b"eUROPE/bUSINGEN",
                b"EuRoPe/bUsInGeN",
                b"eUrOpE/BuSiNgEn",
            ],
        ),
        (
            &time_zone::europe::ZURICH,
            time_zone::europe::RAW_ZURICH,
            &[
                b"Europe/Zurich",
                b"europe/zurich",
                b"EUROPE/ZURICH",
                b"eUROPE/zURICH",
                b"EuRoPe/zUrIcH",
                b"eUrOpE/ZuRiCh",
            ],
        ),
        (
            &time_zone::europe::CHISINAU,
            time_zone::europe::RAW_CHISINAU,
            &[
                b"Europe/Chisinau",
                b"europe/chisinau",
                b"EUROPE/CHISINAU",
                b"eUROPE/cHISINAU",
                b"EuRoPe/cHiSiNaU",
                b"eUrOpE/ChIsInAu",
            ],
        ),
        (
            &time_zone::europe::TIRASPOL,
            time_zone::europe::RAW_TIRASPOL,
            &[
                b"Europe/Tiraspol",
                b"europe/tiraspol",
                b"EUROPE/TIRASPOL",
                b"eUROPE/tIRASPOL",
                b"EuRoPe/tIrAsPoL",
                b"eUrOpE/TiRaSpOl",
            ],
        ),
        (
            &time_zone::europe::COPENHAGEN,
            time_zone::europe::RAW_COPENHAGEN,
            &[
                b"Europe/Copenhagen",
                b"europe/copenhagen",
                b"EUROPE/COPENHAGEN",
                b"eUROPE/cOPENHAGEN",
                b"EuRoPe/cOpEnHaGeN",
                b"eUrOpE/CoPeNhAgEn",
            ],
        ),
        (
            &time_zone::europe::GIBRALTAR,
            time_zone::europe::RAW_GIBRALTAR,
            &[
                b"Europe/Gibraltar",
                b"europe/gibraltar",
                b"EUROPE/GIBRALTAR",
                b"eUROPE/gIBRALTAR",
                b"EuRoPe/gIbRaLtAr",
                b"eUrOpE/GiBrAlTaR",
            ],
        ),
        (
            &time_zone::europe::GUERNSEY,
            time_zone::europe::RAW_GUERNSEY,
            &[
                b"Europe/Guernsey",
                b"europe/guernsey",
                b"EUROPE/GUERNSEY",
                b"eUROPE/gUERNSEY",
                b"EuRoPe/gUeRnSeY",
                b"eUrOpE/GuErNsEy",
            ],
        ),
        (
            &time_zone::europe::HELSINKI,
            time_zone::europe::RAW_HELSINKI,
            &[
                b"Europe/Helsinki",
                b"europe/helsinki",
                b"EUROPE/HELSINKI",
                b"eUROPE/hELSINKI",
                b"EuRoPe/hElSiNkI",
                b"eUrOpE/HeLsInKi",
            ],
        ),
        (
            &time_zone::europe::MARIEHAMN,
            time_zone::europe::RAW_MARIEHAMN,
            &[
                b"Europe/Mariehamn",
                b"europe/mariehamn",
                b"EUROPE/MARIEHAMN",
                b"eUROPE/mARIEHAMN",
                b"EuRoPe/mArIeHaMn",
                b"eUrOpE/MaRiEhAmN",
            ],
        ),
        (
            &time_zone::europe::ISLE_OF_MAN,
            time_zone::europe::RAW_ISLE_OF_MAN,
            &[
                b"Europe/Isle_of_Man",
                b"europe/isle_of_man",
                b"EUROPE/ISLE_OF_MAN",
                b"eUROPE/iSLE_OF_mAN",
                b"EuRoPe/iSlE_Of_mAn",
                b"eUrOpE/IsLe_oF_MaN",
            ],
        ),
        (
            &time_zone::europe::JERSEY,
            time_zone::europe::RAW_JERSEY,
            &[
                b"Europe/Jersey",
                b"europe/jersey",
                b"EUROPE/JERSEY",
                b"eUROPE/jERSEY",
                b"EuRoPe/jErSeY",
                b"eUrOpE/JeRsEy",
            ],
        ),
        (
            &time_zone::europe::KALININGRAD,
            time_zone::europe::RAW_KALININGRAD,
            &[
                b"Europe/Kaliningrad",
                b"europe/kaliningrad",
                b"EUROPE/KALININGRAD",
                b"eUROPE/kALININGRAD",
                b"EuRoPe/kAlInInGrAd",
                b"eUrOpE/KaLiNiNgRaD",
            ],
        ),
        (&time_zone::europe::KIEV, time_zone::europe::RAW_KIEV, &[
            b"Europe/Kiev",
            b"europe/kiev",
            b"EUROPE/KIEV",
            b"eUROPE/kIEV",
            b"EuRoPe/kIeV",
            b"eUrOpE/KiEv",
        ]),
        (&time_zone::europe::KYIV, time_zone::europe::RAW_KYIV, &[
            b"Europe/Kyiv",
            b"europe/kyiv",
            b"EUROPE/KYIV",
            b"eUROPE/kYIV",
            b"EuRoPe/kYiV",
            b"eUrOpE/KyIv",
        ]),
        (
            &time_zone::europe::UZHGOROD,
            time_zone::europe::RAW_UZHGOROD,
            &[
                b"Europe/Uzhgorod",
                b"europe/uzhgorod",
                b"EUROPE/UZHGOROD",
                b"eUROPE/uZHGOROD",
                b"EuRoPe/uZhGoRoD",
                b"eUrOpE/UzHgOrOd",
            ],
        ),
        (
            &time_zone::europe::ZAPOROZHYE,
            time_zone::europe::RAW_ZAPOROZHYE,
            &[
                b"Europe/Zaporozhye",
                b"europe/zaporozhye",
                b"EUROPE/ZAPOROZHYE",
                b"eUROPE/zAPOROZHYE",
                b"EuRoPe/zApOrOzHyE",
                b"eUrOpE/ZaPoRoZhYe",
            ],
        ),
        (&time_zone::europe::KIROV, time_zone::europe::RAW_KIROV, &[
            b"Europe/Kirov",
            b"europe/kirov",
            b"EUROPE/KIROV",
            b"eUROPE/kIROV",
            b"EuRoPe/kIrOv",
            b"eUrOpE/KiRoV",
        ]),
        (
            &time_zone::europe::LJUBLJANA,
            time_zone::europe::RAW_LJUBLJANA,
            &[
                b"Europe/Ljubljana",
                b"europe/ljubljana",
                b"EUROPE/LJUBLJANA",
                b"eUROPE/lJUBLJANA",
                b"EuRoPe/lJuBlJaNa",
                b"eUrOpE/LjUbLjAnA",
            ],
        ),
        (
            &time_zone::europe::LUXEMBOURG,
            time_zone::europe::RAW_LUXEMBOURG,
            &[
                b"Europe/Luxembourg",
                b"europe/luxembourg",
                b"EUROPE/LUXEMBOURG",
                b"eUROPE/lUXEMBOURG",
                b"EuRoPe/lUxEmBoUrG",
                b"eUrOpE/LuXeMbOuRg",
            ],
        ),
        (
            &time_zone::europe::MADRID,
            time_zone::europe::RAW_MADRID,
            &[
                b"Europe/Madrid",
                b"europe/madrid",
                b"EUROPE/MADRID",
                b"eUROPE/mADRID",
                b"EuRoPe/mAdRiD",
                b"eUrOpE/MaDrId",
            ],
        ),
        (&time_zone::europe::MALTA, time_zone::europe::RAW_MALTA, &[
            b"Europe/Malta",
            b"europe/malta",
            b"EUROPE/MALTA",
            b"eUROPE/mALTA",
            b"EuRoPe/mAlTa",
            b"eUrOpE/MaLtA",
        ]),
        (&time_zone::europe::MINSK, time_zone::europe::RAW_MINSK, &[
            b"Europe/Minsk",
            b"europe/minsk",
            b"EUROPE/MINSK",
            b"eUROPE/mINSK",
            b"EuRoPe/mInSk",
            b"eUrOpE/MiNsK",
        ]),
        (
            &time_zone::europe::MONACO,
            time_zone::europe::RAW_MONACO,
            &[
                b"Europe/Monaco",
                b"europe/monaco",
                b"EUROPE/MONACO",
                b"eUROPE/mONACO",
                b"EuRoPe/mOnAcO",
                b"eUrOpE/MoNaCo",
            ],
        ),
        (&time_zone::europe::OSLO, time_zone::europe::RAW_OSLO, &[
            b"Europe/Oslo",
            b"europe/oslo",
            b"EUROPE/OSLO",
            b"eUROPE/oSLO",
            b"EuRoPe/oSlO",
            b"eUrOpE/OsLo",
        ]),
        (&time_zone::europe::PARIS, time_zone::europe::RAW_PARIS, &[
            b"Europe/Paris",
            b"europe/paris",
            b"EUROPE/PARIS",
            b"eUROPE/pARIS",
            b"EuRoPe/pArIs",
            b"eUrOpE/PaRiS",
        ]),
        (&time_zone::europe::RIGA, time_zone::europe::RAW_RIGA, &[
            b"Europe/Riga",
            b"europe/riga",
            b"EUROPE/RIGA",
            b"eUROPE/rIGA",
            b"EuRoPe/rIgA",
            b"eUrOpE/RiGa",
        ]),
        (&time_zone::europe::ROME, time_zone::europe::RAW_ROME, &[
            b"Europe/Rome",
            b"europe/rome",
            b"EUROPE/ROME",
            b"eUROPE/rOME",
            b"EuRoPe/rOmE",
            b"eUrOpE/RoMe",
        ]),
        (
            &time_zone::europe::SAN_MARINO,
            time_zone::europe::RAW_SAN_MARINO,
            &[
                b"Europe/San_Marino",
                b"europe/san_marino",
                b"EUROPE/SAN_MARINO",
                b"eUROPE/sAN_mARINO",
                b"EuRoPe/sAn_mArInO",
                b"eUrOpE/SaN_MaRiNo",
            ],
        ),
        (
            &time_zone::europe::VATICAN,
            time_zone::europe::RAW_VATICAN,
            &[
                b"Europe/Vatican",
                b"europe/vatican",
                b"EUROPE/VATICAN",
                b"eUROPE/vATICAN",
                b"EuRoPe/vAtIcAn",
                b"eUrOpE/VaTiCaN",
            ],
        ),
        (
            &time_zone::europe::SAMARA,
            time_zone::europe::RAW_SAMARA,
            &[
                b"Europe/Samara",
                b"europe/samara",
                b"EUROPE/SAMARA",
                b"eUROPE/sAMARA",
                b"EuRoPe/sAmArA",
                b"eUrOpE/SaMaRa",
            ],
        ),
        (
            &time_zone::europe::SARAJEVO,
            time_zone::europe::RAW_SARAJEVO,
            &[
                b"Europe/Sarajevo",
                b"europe/sarajevo",
                b"EUROPE/SARAJEVO",
                b"eUROPE/sARAJEVO",
                b"EuRoPe/sArAjEvO",
                b"eUrOpE/SaRaJeVo",
            ],
        ),
        (
            &time_zone::europe::SARATOV,
            time_zone::europe::RAW_SARATOV,
            &[
                b"Europe/Saratov",
                b"europe/saratov",
                b"EUROPE/SARATOV",
                b"eUROPE/sARATOV",
                b"EuRoPe/sArAtOv",
                b"eUrOpE/SaRaToV",
            ],
        ),
        (
            &time_zone::europe::SIMFEROPOL,
            time_zone::europe::RAW_SIMFEROPOL,
            &[
                b"Europe/Simferopol",
                b"europe/simferopol",
                b"EUROPE/SIMFEROPOL",
                b"eUROPE/sIMFEROPOL",
                b"EuRoPe/sImFeRoPoL",
                b"eUrOpE/SiMfErOpOl",
            ],
        ),
        (
            &time_zone::europe::SKOPJE,
            time_zone::europe::RAW_SKOPJE,
            &[
                b"Europe/Skopje",
                b"europe/skopje",
                b"EUROPE/SKOPJE",
                b"eUROPE/sKOPJE",
                b"EuRoPe/sKoPjE",
                b"eUrOpE/SkOpJe",
            ],
        ),
        (&time_zone::europe::SOFIA, time_zone::europe::RAW_SOFIA, &[
            b"Europe/Sofia",
            b"europe/sofia",
            b"EUROPE/SOFIA",
            b"eUROPE/sOFIA",
            b"EuRoPe/sOfIa",
            b"eUrOpE/SoFiA",
        ]),
        (
            &time_zone::europe::STOCKHOLM,
            time_zone::europe::RAW_STOCKHOLM,
            &[
                b"Europe/Stockholm",
                b"europe/stockholm",
                b"EUROPE/STOCKHOLM",
                b"eUROPE/sTOCKHOLM",
                b"EuRoPe/sToCkHoLm",
                b"eUrOpE/StOcKhOlM",
            ],
        ),
        (
            &time_zone::europe::TALLINN,
            time_zone::europe::RAW_TALLINN,
            &[
                b"Europe/Tallinn",
                b"europe/tallinn",
                b"EUROPE/TALLINN",
                b"eUROPE/tALLINN",
                b"EuRoPe/tAlLiNn",
                b"eUrOpE/TaLlInN",
            ],
        ),
        (
            &time_zone::europe::TIRANE,
            time_zone::europe::RAW_TIRANE,
            &[
                b"Europe/Tirane",
                b"europe/tirane",
                b"EUROPE/TIRANE",
                b"eUROPE/tIRANE",
                b"EuRoPe/tIrAnE",
                b"eUrOpE/TiRaNe",
            ],
        ),
        (
            &time_zone::europe::ULYANOVSK,
            time_zone::europe::RAW_ULYANOVSK,
            &[
                b"Europe/Ulyanovsk",
                b"europe/ulyanovsk",
                b"EUROPE/ULYANOVSK",
                b"eUROPE/uLYANOVSK",
                b"EuRoPe/uLyAnOvSk",
                b"eUrOpE/UlYaNoVsK",
            ],
        ),
        (&time_zone::europe::VADUZ, time_zone::europe::RAW_VADUZ, &[
            b"Europe/Vaduz",
            b"europe/vaduz",
            b"EUROPE/VADUZ",
            b"eUROPE/vADUZ",
            b"EuRoPe/vAdUz",
            b"eUrOpE/VaDuZ",
        ]),
        (
            &time_zone::europe::VIENNA,
            time_zone::europe::RAW_VIENNA,
            &[
                b"Europe/Vienna",
                b"europe/vienna",
                b"EUROPE/VIENNA",
                b"eUROPE/vIENNA",
                b"EuRoPe/vIeNnA",
                b"eUrOpE/ViEnNa",
            ],
        ),
        (
            &time_zone::europe::VILNIUS,
            time_zone::europe::RAW_VILNIUS,
            &[
                b"Europe/Vilnius",
                b"europe/vilnius",
                b"EUROPE/VILNIUS",
                b"eUROPE/vILNIUS",
                b"EuRoPe/vIlNiUs",
                b"eUrOpE/ViLnIuS",
            ],
        ),
        (
            &time_zone::europe::VOLGOGRAD,
            time_zone::europe::RAW_VOLGOGRAD,
            &[
                b"Europe/Volgograd",
                b"europe/volgograd",
                b"EUROPE/VOLGOGRAD",
                b"eUROPE/vOLGOGRAD",
                b"EuRoPe/vOlGoGrAd",
                b"eUrOpE/VoLgOgRaD",
            ],
        ),
        (
            &time_zone::europe::ZAGREB,
            time_zone::europe::RAW_ZAGREB,
            &[
                b"Europe/Zagreb",
                b"europe/zagreb",
                b"EUROPE/ZAGREB",
                b"eUROPE/zAGREB",
                b"EuRoPe/zAgReB",
                b"eUrOpE/ZaGrEb",
            ],
        ),
        (&time_zone::FACTORY, time_zone::RAW_FACTORY, &[
            b"Factory", b"factory", b"FACTORY", b"fACTORY", b"FaCtOrY", b"fAcToRy",
        ]),
        (&time_zone::GB, time_zone::RAW_GB, &[
            b"GB", b"gb", b"GB", b"gb", b"Gb", b"gB",
        ]),
        (&time_zone::GB_EIRE, time_zone::RAW_GB_EIRE, &[
            b"GB-Eire", b"gb-eire", b"GB-EIRE", b"gb-eIRE", b"Gb-eIrE", b"gB-EiRe",
        ]),
        (
            &time_zone::europe::BELFAST,
            time_zone::europe::RAW_BELFAST,
            &[
                b"Europe/Belfast",
                b"europe/belfast",
                b"EUROPE/BELFAST",
                b"eUROPE/bELFAST",
                b"EuRoPe/bElFaSt",
                b"eUrOpE/BeLfAsT",
            ],
        ),
        (
            &time_zone::europe::LONDON,
            time_zone::europe::RAW_LONDON,
            &[
                b"Europe/London",
                b"europe/london",
                b"EUROPE/LONDON",
                b"eUROPE/lONDON",
                b"EuRoPe/lOnDoN",
                b"eUrOpE/LoNdOn",
            ],
        ),
        (&time_zone::GMT, time_zone::RAW_GMT, &[
            b"GMT", b"gmt", b"GMT", b"gmt", b"GmT", b"gMt",
        ]),
        (&time_zone::GMT_0, time_zone::RAW_GMT_0, &[
            b"GMT0", b"gmt0", b"GMT0", b"gmt0", b"GmT0", b"gMt0",
        ]),
        (&time_zone::GMT_MINUS_0, time_zone::RAW_GMT_MINUS_0, &[
            b"GMT-0", b"gmt-0", b"GMT-0", b"gmt-0", b"GmT-0", b"gMt-0",
        ]),
        (&time_zone::GMT_PLUS_0, time_zone::RAW_GMT_PLUS_0, &[
            b"GMT+0", b"gmt+0", b"GMT+0", b"gmt+0", b"GmT+0", b"gMt+0",
        ]),
        (&time_zone::GREENWICH, time_zone::RAW_GREENWICH, &[
            b"Greenwich",
            b"greenwich",
            b"GREENWICH",
            b"gREENWICH",
            b"GrEeNwIcH",
            b"gReEnWiCh",
        ]),
        (&time_zone::etc::GMT, time_zone::etc::RAW_GMT, &[
            b"Etc/GMT", b"etc/gmt", b"ETC/GMT", b"eTC/gmt", b"EtC/GmT", b"eTc/gMt",
        ]),
        (&time_zone::etc::GMT_0, time_zone::etc::RAW_GMT_0, &[
            b"Etc/GMT0",
            b"etc/gmt0",
            b"ETC/GMT0",
            b"eTC/gmt0",
            b"EtC/GmT0",
            b"eTc/gMt0",
        ]),
        (
            &time_zone::etc::GMT_MINUS_0,
            time_zone::etc::RAW_GMT_MINUS_0,
            &[
                b"Etc/GMT-0",
                b"etc/gmt-0",
                b"ETC/GMT-0",
                b"eTC/gmt-0",
                b"EtC/GmT-0",
                b"eTc/gMt-0",
            ],
        ),
        (
            &time_zone::etc::GMT_PLUS_0,
            time_zone::etc::RAW_GMT_PLUS_0,
            &[
                b"Etc/GMT+0",
                b"etc/gmt+0",
                b"ETC/GMT+0",
                b"eTC/gmt+0",
                b"EtC/GmT+0",
                b"eTc/gMt+0",
            ],
        ),
        (
            &time_zone::etc::GREENWICH,
            time_zone::etc::RAW_GREENWICH,
            &[
                b"Etc/Greenwich",
                b"etc/greenwich",
                b"ETC/GREENWICH",
                b"eTC/gREENWICH",
                b"EtC/GrEeNwIcH",
                b"eTc/gReEnWiCh",
            ],
        ),
        (&time_zone::HONGKONG, time_zone::RAW_HONGKONG, &[
            b"Hongkong",
            b"hongkong",
            b"HONGKONG",
            b"hONGKONG",
            b"HoNgKoNg",
            b"hOnGkOnG",
        ]),
        (
            &time_zone::asia::HONG_KONG,
            time_zone::asia::RAW_HONG_KONG,
            &[
                b"Asia/Hong_Kong",
                b"asia/hong_kong",
                b"ASIA/HONG_KONG",
                b"aSIA/hONG_kONG",
                b"AsIa/hOnG_KoNg",
                b"aSiA/HoNg_kOnG",
            ],
        ),
        (&time_zone::HST, time_zone::RAW_HST, &[
            b"HST", b"hst", b"HST", b"hst", b"HsT", b"hSt",
        ]),
        (
            &time_zone::pacific::HONOLULU,
            time_zone::pacific::RAW_HONOLULU,
            &[
                b"Pacific/Honolulu",
                b"pacific/honolulu",
                b"PACIFIC/HONOLULU",
                b"pACIFIC/hONOLULU",
                b"PaCiFiC/HoNoLuLu",
                b"pAcIfIc/hOnOlUlU",
            ],
        ),
        (
            &time_zone::pacific::JOHNSTON,
            time_zone::pacific::RAW_JOHNSTON,
            &[
                b"Pacific/Johnston",
                b"pacific/johnston",
                b"PACIFIC/JOHNSTON",
                b"pACIFIC/jOHNSTON",
                b"PaCiFiC/JoHnStOn",
                b"pAcIfIc/jOhNsToN",
            ],
        ),
        (&time_zone::us::HAWAII, time_zone::us::RAW_HAWAII, &[
            b"US/Hawaii",
            b"us/hawaii",
            b"US/HAWAII",
            b"us/hAWAII",
            b"Us/hAwAiI",
            b"uS/HaWaIi",
        ]),
        (&time_zone::ICELAND, time_zone::RAW_ICELAND, &[
            b"Iceland", b"iceland", b"ICELAND", b"iCELAND", b"IcElAnD", b"iCeLaNd",
        ]),
        (
            &time_zone::africa::ABIDJAN,
            time_zone::africa::RAW_ABIDJAN,
            &[
                b"Africa/Abidjan",
                b"africa/abidjan",
                b"AFRICA/ABIDJAN",
                b"aFRICA/aBIDJAN",
                b"AfRiCa/aBiDjAn",
                b"aFrIcA/AbIdJaN",
            ],
        ),
        (
            &time_zone::africa::TIMBUKTU,
            time_zone::africa::RAW_TIMBUKTU,
            &[
                b"Africa/Timbuktu",
                b"africa/timbuktu",
                b"AFRICA/TIMBUKTU",
                b"aFRICA/tIMBUKTU",
                b"AfRiCa/tImBuKtU",
                b"aFrIcA/TiMbUkTu",
            ],
        ),
        (
            &time_zone::indian::ANTANANARIVO,
            time_zone::indian::RAW_ANTANANARIVO,
            &[
                b"Indian/Antananarivo",
                b"indian/antananarivo",
                b"INDIAN/ANTANANARIVO",
                b"iNDIAN/aNTANANARIVO",
                b"InDiAn/aNtAnAnArIvO",
                b"iNdIaN/AnTaNaNaRiVo",
            ],
        ),
        (
            &time_zone::indian::CHAGOS,
            time_zone::indian::RAW_CHAGOS,
            &[
                b"Indian/Chagos",
                b"indian/chagos",
                b"INDIAN/CHAGOS",
                b"iNDIAN/cHAGOS",
                b"InDiAn/cHaGoS",
                b"iNdIaN/ChAgOs",
            ],
        ),
        (
            &time_zone::indian::CHRISTMAS,
            time_zone::indian::RAW_CHRISTMAS,
            &[
                b"Indian/Christmas",
                b"indian/christmas",
                b"INDIAN/CHRISTMAS",
                b"iNDIAN/cHRISTMAS",
                b"InDiAn/cHrIsTmAs",
                b"iNdIaN/ChRiStMaS",
            ],
        ),
        (&time_zone::indian::COCOS, time_zone::indian::RAW_COCOS, &[
            b"Indian/Cocos",
            b"indian/cocos",
            b"INDIAN/COCOS",
            b"iNDIAN/cOCOS",
            b"InDiAn/cOcOs",
            b"iNdIaN/CoCoS",
        ]),
        (
            &time_zone::indian::COMORO,
            time_zone::indian::RAW_COMORO,
            &[
                b"Indian/Comoro",
                b"indian/comoro",
                b"INDIAN/COMORO",
                b"iNDIAN/cOMORO",
                b"InDiAn/cOmOrO",
                b"iNdIaN/CoMoRo",
            ],
        ),
        (
            &time_zone::indian::KERGUELEN,
            time_zone::indian::RAW_KERGUELEN,
            &[
                b"Indian/Kerguelen",
                b"indian/kerguelen",
                b"INDIAN/KERGUELEN",
                b"iNDIAN/kERGUELEN",
                b"InDiAn/kErGuElEn",
                b"iNdIaN/KeRgUeLeN",
            ],
        ),
        (&time_zone::indian::MAHE, time_zone::indian::RAW_MAHE, &[
            b"Indian/Mahe",
            b"indian/mahe",
            b"INDIAN/MAHE",
            b"iNDIAN/mAHE",
            b"InDiAn/mAhE",
            b"iNdIaN/MaHe",
        ]),
        (
            &time_zone::indian::MALDIVES,
            time_zone::indian::RAW_MALDIVES,
            &[
                b"Indian/Maldives",
                b"indian/maldives",
                b"INDIAN/MALDIVES",
                b"iNDIAN/mALDIVES",
                b"InDiAn/mAlDiVeS",
                b"iNdIaN/MaLdIvEs",
            ],
        ),
        (
            &time_zone::indian::MAURITIUS,
            time_zone::indian::RAW_MAURITIUS,
            &[
                b"Indian/Mauritius",
                b"indian/mauritius",
                b"INDIAN/MAURITIUS",
                b"iNDIAN/mAURITIUS",
                b"InDiAn/mAuRiTiUs",
                b"iNdIaN/MaUrItIuS",
            ],
        ),
        (
            &time_zone::indian::MAYOTTE,
            time_zone::indian::RAW_MAYOTTE,
            &[
                b"Indian/Mayotte",
                b"indian/mayotte",
                b"INDIAN/MAYOTTE",
                b"iNDIAN/mAYOTTE",
                b"InDiAn/mAyOtTe",
                b"iNdIaN/MaYoTtE",
            ],
        ),
        (
            &time_zone::indian::REUNION,
            time_zone::indian::RAW_REUNION,
            &[
                b"Indian/Reunion",
                b"indian/reunion",
                b"INDIAN/REUNION",
                b"iNDIAN/rEUNION",
                b"InDiAn/rEuNiOn",
                b"iNdIaN/ReUnIoN",
            ],
        ),
        (&time_zone::IRAN, time_zone::RAW_IRAN, &[
            b"Iran", b"iran", b"IRAN", b"iRAN", b"IrAn", b"iRaN",
        ]),
        (&time_zone::asia::TEHRAN, time_zone::asia::RAW_TEHRAN, &[
            b"Asia/Tehran",
            b"asia/tehran",
            b"ASIA/TEHRAN",
            b"aSIA/tEHRAN",
            b"AsIa/tEhRaN",
            b"aSiA/TeHrAn",
        ]),
        (&time_zone::ISRAEL, time_zone::RAW_ISRAEL, &[
            b"Israel", b"israel", b"ISRAEL", b"iSRAEL", b"IsRaEl", b"iSrAeL",
        ]),
        (
            &time_zone::asia::JERUSALEM,
            time_zone::asia::RAW_JERUSALEM,
            &[
                b"Asia/Jerusalem",
                b"asia/jerusalem",
                b"ASIA/JERUSALEM",
                b"aSIA/jERUSALEM",
                b"AsIa/jErUsAlEm",
                b"aSiA/JeRuSaLeM",
            ],
        ),
        (
            &time_zone::asia::TEL_AVIV,
            time_zone::asia::RAW_TEL_AVIV,
            &[
                b"Asia/Tel_Aviv",
                b"asia/tel_aviv",
                b"ASIA/TEL_AVIV",
                b"aSIA/tEL_aVIV",
                b"AsIa/tEl_aViV",
                b"aSiA/TeL_AvIv",
            ],
        ),
        (&time_zone::JAMAICA, time_zone::RAW_JAMAICA, &[
            b"Jamaica", b"jamaica", b"JAMAICA", b"jAMAICA", b"JaMaIcA", b"jAmAiCa",
        ]),
        (
            &time_zone::america::JAMAICA,
            time_zone::america::RAW_JAMAICA,
            &[
                b"America/Jamaica",
                b"america/jamaica",
                b"AMERICA/JAMAICA",
                b"aMERICA/jAMAICA",
                b"AmErIcA/JaMaIcA",
                b"aMeRiCa/jAmAiCa",
            ],
        ),
        (&time_zone::JAPAN, time_zone::RAW_JAPAN, &[
            b"Japan", b"japan", b"JAPAN", b"jAPAN", b"JaPaN", b"jApAn",
        ]),
        (&time_zone::asia::TOKYO, time_zone::asia::RAW_TOKYO, &[
            b"Asia/Tokyo",
            b"asia/tokyo",
            b"ASIA/TOKYO",
            b"aSIA/tOKYO",
            b"AsIa/tOkYo",
            b"aSiA/ToKyO",
        ]),
        (&time_zone::KWAJALEIN, time_zone::RAW_KWAJALEIN, &[
            b"Kwajalein",
            b"kwajalein",
            b"KWAJALEIN",
            b"kWAJALEIN",
            b"KwAjAlEiN",
            b"kWaJaLeIn",
        ]),
        (
            &time_zone::pacific::KWAJALEIN,
            time_zone::pacific::RAW_KWAJALEIN,
            &[
                b"Pacific/Kwajalein",
                b"pacific/kwajalein",
                b"PACIFIC/KWAJALEIN",
                b"pACIFIC/kWAJALEIN",
                b"PaCiFiC/KwAjAlEiN",
                b"pAcIfIc/kWaJaLeIn",
            ],
        ),
        (&time_zone::LIBYA, time_zone::RAW_LIBYA, &[
            b"Libya", b"libya", b"LIBYA", b"lIBYA", b"LiByA", b"lIbYa",
        ]),
        (
            &time_zone::africa::TRIPOLI,
            time_zone::africa::RAW_TRIPOLI,
            &[
                b"Africa/Tripoli",
                b"africa/tripoli",
                b"AFRICA/TRIPOLI",
                b"aFRICA/tRIPOLI",
                b"AfRiCa/tRiPoLi",
                b"aFrIcA/TrIpOlI",
            ],
        ),
        (&time_zone::MST, time_zone::RAW_MST, &[
            b"MST", b"mst", b"MST", b"mst", b"MsT", b"mSt",
        ]),
        (
            &time_zone::america::PHOENIX,
            time_zone::america::RAW_PHOENIX,
            &[
                b"America/Phoenix",
                b"america/phoenix",
                b"AMERICA/PHOENIX",
                b"aMERICA/pHOENIX",
                b"AmErIcA/PhOeNiX",
                b"aMeRiCa/pHoEnIx",
            ],
        ),
        (&time_zone::us::ARIZONA, time_zone::us::RAW_ARIZONA, &[
            b"US/Arizona",
            b"us/arizona",
            b"US/ARIZONA",
            b"us/aRIZONA",
            b"Us/aRiZoNa",
            b"uS/ArIzOnA",
        ]),
        (&time_zone::MST_7_MDT, time_zone::RAW_MST_7_MDT, &[
            b"MST7MDT", b"mst7mdt", b"MST7MDT", b"mst7mdt", b"MsT7MdT", b"mSt7mDt",
        ]),
        (&time_zone::NAVAJO, time_zone::RAW_NAVAJO, &[
            b"Navajo", b"navajo", b"NAVAJO", b"nAVAJO", b"NaVaJo", b"nAvAjO",
        ]),
        (
            &time_zone::america::DENVER,
            time_zone::america::RAW_DENVER,
            &[
                b"America/Denver",
                b"america/denver",
                b"AMERICA/DENVER",
                b"aMERICA/dENVER",
                b"AmErIcA/DeNvEr",
                b"aMeRiCa/dEnVeR",
            ],
        ),
        (
            &time_zone::america::SHIPROCK,
            time_zone::america::RAW_SHIPROCK,
            &[
                b"America/Shiprock",
                b"america/shiprock",
                b"AMERICA/SHIPROCK",
                b"aMERICA/sHIPROCK",
                b"AmErIcA/ShIpRoCk",
                b"aMeRiCa/sHiPrOcK",
            ],
        ),
        (&time_zone::us::MOUNTAIN, time_zone::us::RAW_MOUNTAIN, &[
            b"US/Mountain",
            b"us/mountain",
            b"US/MOUNTAIN",
            b"us/mOUNTAIN",
            b"Us/mOuNtAiN",
            b"uS/MoUnTaIn",
        ]),
        (&time_zone::NZ, time_zone::RAW_NZ, &[
            b"NZ", b"nz", b"NZ", b"nz", b"Nz", b"nZ",
        ]),
        (
            &time_zone::antarctica::SOUTH_POLE,
            time_zone::antarctica::RAW_SOUTH_POLE,
            &[
                b"Antarctica/South_Pole",
                b"antarctica/south_pole",
                b"ANTARCTICA/SOUTH_POLE",
                b"aNTARCTICA/sOUTH_pOLE",
                b"AnTaRcTiCa/sOuTh_pOlE",
                b"aNtArCtIcA/SoUtH_PoLe",
            ],
        ),
        (
            &time_zone::pacific::AUCKLAND,
            time_zone::pacific::RAW_AUCKLAND,
            &[
                b"Pacific/Auckland",
                b"pacific/auckland",
                b"PACIFIC/AUCKLAND",
                b"pACIFIC/aUCKLAND",
                b"PaCiFiC/AuCkLaNd",
                b"pAcIfIc/aUcKlAnD",
            ],
        ),
        (&time_zone::NZ_CHAT, time_zone::RAW_NZ_CHAT, &[
            b"NZ-CHAT", b"nz-chat", b"NZ-CHAT", b"nz-chat", b"Nz-cHaT", b"nZ-ChAt",
        ]),
        (
            &time_zone::pacific::CHATHAM,
            time_zone::pacific::RAW_CHATHAM,
            &[
                b"Pacific/Chatham",
                b"pacific/chatham",
                b"PACIFIC/CHATHAM",
                b"pACIFIC/cHATHAM",
                b"PaCiFiC/ChAtHaM",
                b"pAcIfIc/cHaThAm",
            ],
        ),
        (&time_zone::pacific::APIA, time_zone::pacific::RAW_APIA, &[
            b"Pacific/Apia",
            b"pacific/apia",
            b"PACIFIC/APIA",
            b"pACIFIC/aPIA",
            b"PaCiFiC/ApIa",
            b"pAcIfIc/aPiA",
        ]),
        (
            &time_zone::pacific::BOUGAINVILLE,
            time_zone::pacific::RAW_BOUGAINVILLE,
            &[
                b"Pacific/Bougainville",
                b"pacific/bougainville",
                b"PACIFIC/BOUGAINVILLE",
                b"pACIFIC/bOUGAINVILLE",
                b"PaCiFiC/BoUgAiNvIlLe",
                b"pAcIfIc/bOuGaInViLlE",
            ],
        ),
        (
            &time_zone::pacific::CHUUK,
            time_zone::pacific::RAW_CHUUK,
            &[
                b"Pacific/Chuuk",
                b"pacific/chuuk",
                b"PACIFIC/CHUUK",
                b"pACIFIC/cHUUK",
                b"PaCiFiC/ChUuK",
                b"pAcIfIc/cHuUk",
            ],
        ),
        (
            &time_zone::pacific::EFATE,
            time_zone::pacific::RAW_EFATE,
            &[
                b"Pacific/Efate",
                b"pacific/efate",
                b"PACIFIC/EFATE",
                b"pACIFIC/eFATE",
                b"PaCiFiC/EfAtE",
                b"pAcIfIc/eFaTe",
            ],
        ),
        (
            &time_zone::pacific::ENDERBURY,
            time_zone::pacific::RAW_ENDERBURY,
            &[
                b"Pacific/Enderbury",
                b"pacific/enderbury",
                b"PACIFIC/ENDERBURY",
                b"pACIFIC/eNDERBURY",
                b"PaCiFiC/EnDeRbUrY",
                b"pAcIfIc/eNdErBuRy",
            ],
        ),
        (
            &time_zone::pacific::KANTON,
            time_zone::pacific::RAW_KANTON,
            &[
                b"Pacific/Kanton",
                b"pacific/kanton",
                b"PACIFIC/KANTON",
                b"pACIFIC/kANTON",
                b"PaCiFiC/KaNtOn",
                b"pAcIfIc/kAnToN",
            ],
        ),
        (
            &time_zone::pacific::FAKAOFO,
            time_zone::pacific::RAW_FAKAOFO,
            &[
                b"Pacific/Fakaofo",
                b"pacific/fakaofo",
                b"PACIFIC/FAKAOFO",
                b"pACIFIC/fAKAOFO",
                b"PaCiFiC/FaKaOfO",
                b"pAcIfIc/fAkAoFo",
            ],
        ),
        (&time_zone::pacific::FIJI, time_zone::pacific::RAW_FIJI, &[
            b"Pacific/Fiji",
            b"pacific/fiji",
            b"PACIFIC/FIJI",
            b"pACIFIC/fIJI",
            b"PaCiFiC/FiJi",
            b"pAcIfIc/fIjI",
        ]),
        (
            &time_zone::pacific::FUNAFUTI,
            time_zone::pacific::RAW_FUNAFUTI,
            &[
                b"Pacific/Funafuti",
                b"pacific/funafuti",
                b"PACIFIC/FUNAFUTI",
                b"pACIFIC/fUNAFUTI",
                b"PaCiFiC/FuNaFuTi",
                b"pAcIfIc/fUnAfUtI",
            ],
        ),
        (
            &time_zone::pacific::GALAPAGOS,
            time_zone::pacific::RAW_GALAPAGOS,
            &[
                b"Pacific/Galapagos",
                b"pacific/galapagos",
                b"PACIFIC/GALAPAGOS",
                b"pACIFIC/gALAPAGOS",
                b"PaCiFiC/GaLaPaGoS",
                b"pAcIfIc/gAlApAgOs",
            ],
        ),
        (
            &time_zone::pacific::GAMBIER,
            time_zone::pacific::RAW_GAMBIER,
            &[
                b"Pacific/Gambier",
                b"pacific/gambier",
                b"PACIFIC/GAMBIER",
                b"pACIFIC/gAMBIER",
                b"PaCiFiC/GaMbIeR",
                b"pAcIfIc/gAmBiEr",
            ],
        ),
        (
            &time_zone::pacific::GUADALCANAL,
            time_zone::pacific::RAW_GUADALCANAL,
            &[
                b"Pacific/Guadalcanal",
                b"pacific/guadalcanal",
                b"PACIFIC/GUADALCANAL",
                b"pACIFIC/gUADALCANAL",
                b"PaCiFiC/GuAdAlCaNaL",
                b"pAcIfIc/gUaDaLcAnAl",
            ],
        ),
        (
            &time_zone::pacific::PONAPE,
            time_zone::pacific::RAW_PONAPE,
            &[
                b"Pacific/Ponape",
                b"pacific/ponape",
                b"PACIFIC/PONAPE",
                b"pACIFIC/pONAPE",
                b"PaCiFiC/PoNaPe",
                b"pAcIfIc/pOnApE",
            ],
        ),
        (&time_zone::pacific::GUAM, time_zone::pacific::RAW_GUAM, &[
            b"Pacific/Guam",
            b"pacific/guam",
            b"PACIFIC/GUAM",
            b"pACIFIC/gUAM",
            b"PaCiFiC/GuAm",
            b"pAcIfIc/gUaM",
        ]),
        (
            &time_zone::pacific::KIRITIMATI,
            time_zone::pacific::RAW_KIRITIMATI,
            &[
                b"Pacific/Kiritimati",
                b"pacific/kiritimati",
                b"PACIFIC/KIRITIMATI",
                b"pACIFIC/kIRITIMATI",
                b"PaCiFiC/KiRiTiMaTi",
                b"pAcIfIc/kIrItImAtI",
            ],
        ),
        (
            &time_zone::pacific::KOSRAE,
            time_zone::pacific::RAW_KOSRAE,
            &[
                b"Pacific/Kosrae",
                b"pacific/kosrae",
                b"PACIFIC/KOSRAE",
                b"pACIFIC/kOSRAE",
                b"PaCiFiC/KoSrAe",
                b"pAcIfIc/kOsRaE",
            ],
        ),
        (
            &time_zone::pacific::MAJURO,
            time_zone::pacific::RAW_MAJURO,
            &[
                b"Pacific/Majuro",
                b"pacific/majuro",
                b"PACIFIC/MAJURO",
                b"pACIFIC/mAJURO",
                b"PaCiFiC/MaJuRo",
                b"pAcIfIc/mAjUrO",
            ],
        ),
        (
            &time_zone::pacific::MARQUESAS,
            time_zone::pacific::RAW_MARQUESAS,
            &[
                b"Pacific/Marquesas",
                b"pacific/marquesas",
                b"PACIFIC/MARQUESAS",
                b"pACIFIC/mARQUESAS",
                b"PaCiFiC/MaRqUeSaS",
                b"pAcIfIc/mArQuEsAs",
            ],
        ),
        (
            &time_zone::pacific::MIDWAY,
            time_zone::pacific::RAW_MIDWAY,
            &[
                b"Pacific/Midway",
                b"pacific/midway",
                b"PACIFIC/MIDWAY",
                b"pACIFIC/mIDWAY",
                b"PaCiFiC/MiDwAy",
                b"pAcIfIc/mIdWaY",
            ],
        ),
        (
            &time_zone::pacific::NAURU,
            time_zone::pacific::RAW_NAURU,
            &[
                b"Pacific/Nauru",
                b"pacific/nauru",
                b"PACIFIC/NAURU",
                b"pACIFIC/nAURU",
                b"PaCiFiC/NaUrU",
                b"pAcIfIc/nAuRu",
            ],
        ),
        (&time_zone::pacific::NIUE, time_zone::pacific::RAW_NIUE, &[
            b"Pacific/Niue",
            b"pacific/niue",
            b"PACIFIC/NIUE",
            b"pACIFIC/nIUE",
            b"PaCiFiC/NiUe",
            b"pAcIfIc/nIuE",
        ]),
        (
            &time_zone::pacific::NORFOLK,
            time_zone::pacific::RAW_NORFOLK,
            &[
                b"Pacific/Norfolk",
                b"pacific/norfolk",
                b"PACIFIC/NORFOLK",
                b"pACIFIC/nORFOLK",
                b"PaCiFiC/NoRfOlK",
                b"pAcIfIc/nOrFoLk",
            ],
        ),
        (
            &time_zone::pacific::NOUMEA,
            time_zone::pacific::RAW_NOUMEA,
            &[
                b"Pacific/Noumea",
                b"pacific/noumea",
                b"PACIFIC/NOUMEA",
                b"pACIFIC/nOUMEA",
                b"PaCiFiC/NoUmEa",
                b"pAcIfIc/nOuMeA",
            ],
        ),
        (
            &time_zone::pacific::PAGO_PAGO,
            time_zone::pacific::RAW_PAGO_PAGO,
            &[
                b"Pacific/Pago_Pago",
                b"pacific/pago_pago",
                b"PACIFIC/PAGO_PAGO",
                b"pACIFIC/pAGO_pAGO",
                b"PaCiFiC/PaGo_pAgO",
                b"pAcIfIc/pAgO_PaGo",
            ],
        ),
        (
            &time_zone::pacific::SAMOA,
            time_zone::pacific::RAW_SAMOA,
            &[
                b"Pacific/Samoa",
                b"pacific/samoa",
                b"PACIFIC/SAMOA",
                b"pACIFIC/sAMOA",
                b"PaCiFiC/SaMoA",
                b"pAcIfIc/sAmOa",
            ],
        ),
        (&time_zone::us::SAMOA, time_zone::us::RAW_SAMOA, &[
            b"US/Samoa",
            b"us/samoa",
            b"US/SAMOA",
            b"us/sAMOA",
            b"Us/sAmOa",
            b"uS/SaMoA",
        ]),
        (
            &time_zone::pacific::PALAU,
            time_zone::pacific::RAW_PALAU,
            &[
                b"Pacific/Palau",
                b"pacific/palau",
                b"PACIFIC/PALAU",
                b"pACIFIC/pALAU",
                b"PaCiFiC/PaLaU",
                b"pAcIfIc/pAlAu",
            ],
        ),
        (
            &time_zone::pacific::PITCAIRN,
            time_zone::pacific::RAW_PITCAIRN,
            &[
                b"Pacific/Pitcairn",
                b"pacific/pitcairn",
                b"PACIFIC/PITCAIRN",
                b"pACIFIC/pITCAIRN",
                b"PaCiFiC/PiTcAiRn",
                b"pAcIfIc/pItCaIrN",
            ],
        ),
        (
            &time_zone::pacific::POHNPEI,
            time_zone::pacific::RAW_POHNPEI,
            &[
                b"Pacific/Pohnpei",
                b"pacific/pohnpei",
                b"PACIFIC/POHNPEI",
                b"pACIFIC/pOHNPEI",
                b"PaCiFiC/PoHnPeI",
                b"pAcIfIc/pOhNpEi",
            ],
        ),
        (
            &time_zone::pacific::PORT_MORESBY,
            time_zone::pacific::RAW_PORT_MORESBY,
            &[
                b"Pacific/Port_Moresby",
                b"pacific/port_moresby",
                b"PACIFIC/PORT_MORESBY",
                b"pACIFIC/pORT_mORESBY",
                b"PaCiFiC/PoRt_mOrEsBy",
                b"pAcIfIc/pOrT_MoReSbY",
            ],
        ),
        (&time_zone::pacific::TRUK, time_zone::pacific::RAW_TRUK, &[
            b"Pacific/Truk",
            b"pacific/truk",
            b"PACIFIC/TRUK",
            b"pACIFIC/tRUK",
            b"PaCiFiC/TrUk",
            b"pAcIfIc/tRuK",
        ]),
        (&time_zone::pacific::YAP, time_zone::pacific::RAW_YAP, &[
            b"Pacific/Yap",
            b"pacific/yap",
            b"PACIFIC/YAP",
            b"pACIFIC/yAP",
            b"PaCiFiC/YaP",
            b"pAcIfIc/yAp",
        ]),
        (
            &time_zone::pacific::RAROTONGA,
            time_zone::pacific::RAW_RAROTONGA,
            &[
                b"Pacific/Rarotonga",
                b"pacific/rarotonga",
                b"PACIFIC/RAROTONGA",
                b"pACIFIC/rAROTONGA",
                b"PaCiFiC/RaRoToNgA",
                b"pAcIfIc/rArOtOnGa",
            ],
        ),
        (
            &time_zone::pacific::SAIPAN,
            time_zone::pacific::RAW_SAIPAN,
            &[
                b"Pacific/Saipan",
                b"pacific/saipan",
                b"PACIFIC/SAIPAN",
                b"pACIFIC/sAIPAN",
                b"PaCiFiC/SaIpAn",
                b"pAcIfIc/sAiPaN",
            ],
        ),
        (
            &time_zone::pacific::TAHITI,
            time_zone::pacific::RAW_TAHITI,
            &[
                b"Pacific/Tahiti",
                b"pacific/tahiti",
                b"PACIFIC/TAHITI",
                b"pACIFIC/tAHITI",
                b"PaCiFiC/TaHiTi",
                b"pAcIfIc/tAhItI",
            ],
        ),
        (
            &time_zone::pacific::TARAWA,
            time_zone::pacific::RAW_TARAWA,
            &[
                b"Pacific/Tarawa",
                b"pacific/tarawa",
                b"PACIFIC/TARAWA",
                b"pACIFIC/tARAWA",
                b"PaCiFiC/TaRaWa",
                b"pAcIfIc/tArAwA",
            ],
        ),
        (
            &time_zone::pacific::TONGATAPU,
            time_zone::pacific::RAW_TONGATAPU,
            &[
                b"Pacific/Tongatapu",
                b"pacific/tongatapu",
                b"PACIFIC/TONGATAPU",
                b"pACIFIC/tONGATAPU",
                b"PaCiFiC/ToNgAtApU",
                b"pAcIfIc/tOnGaTaPu",
            ],
        ),
        (&time_zone::pacific::WAKE, time_zone::pacific::RAW_WAKE, &[
            b"Pacific/Wake",
            b"pacific/wake",
            b"PACIFIC/WAKE",
            b"pACIFIC/wAKE",
            b"PaCiFiC/WaKe",
            b"pAcIfIc/wAkE",
        ]),
        (
            &time_zone::pacific::WALLIS,
            time_zone::pacific::RAW_WALLIS,
            &[
                b"Pacific/Wallis",
                b"pacific/wallis",
                b"PACIFIC/WALLIS",
                b"pACIFIC/wALLIS",
                b"PaCiFiC/WaLlIs",
                b"pAcIfIc/wAlLiS",
            ],
        ),
        (&time_zone::POLAND, time_zone::RAW_POLAND, &[
            b"Poland", b"poland", b"POLAND", b"pOLAND", b"PoLaNd", b"pOlAnD",
        ]),
        (
            &time_zone::europe::WARSAW,
            time_zone::europe::RAW_WARSAW,
            &[
                b"Europe/Warsaw",
                b"europe/warsaw",
                b"EUROPE/WARSAW",
                b"eUROPE/wARSAW",
                b"EuRoPe/wArSaW",
                b"eUrOpE/WaRsAw",
            ],
        ),
        (&time_zone::PORTUGAL, time_zone::RAW_PORTUGAL, &[
            b"Portugal",
            b"portugal",
            b"PORTUGAL",
            b"pORTUGAL",
            b"PoRtUgAl",
            b"pOrTuGaL",
        ]),
        (&time_zone::WET, time_zone::RAW_WET, &[
            b"WET", b"wet", b"WET", b"wet", b"WeT", b"wEt",
        ]),
        (
            &time_zone::europe::LISBON,
            time_zone::europe::RAW_LISBON,
            &[
                b"Europe/Lisbon",
                b"europe/lisbon",
                b"EUROPE/LISBON",
                b"eUROPE/lISBON",
                b"EuRoPe/lIsBoN",
                b"eUrOpE/LiSbOn",
            ],
        ),
        (&time_zone::PRC, time_zone::RAW_PRC, &[
            b"PRC", b"prc", b"PRC", b"prc", b"PrC", b"pRc",
        ]),
        (
            &time_zone::asia::CHONGQING,
            time_zone::asia::RAW_CHONGQING,
            &[
                b"Asia/Chongqing",
                b"asia/chongqing",
                b"ASIA/CHONGQING",
                b"aSIA/cHONGQING",
                b"AsIa/cHoNgQiNg",
                b"aSiA/ChOnGqInG",
            ],
        ),
        (
            &time_zone::asia::CHUNGKING,
            time_zone::asia::RAW_CHUNGKING,
            &[
                b"Asia/Chungking",
                b"asia/chungking",
                b"ASIA/CHUNGKING",
                b"aSIA/cHUNGKING",
                b"AsIa/cHuNgKiNg",
                b"aSiA/ChUnGkInG",
            ],
        ),
        (&time_zone::asia::HARBIN, time_zone::asia::RAW_HARBIN, &[
            b"Asia/Harbin",
            b"asia/harbin",
            b"ASIA/HARBIN",
            b"aSIA/hARBIN",
            b"AsIa/hArBiN",
            b"aSiA/HaRbIn",
        ]),
        (
            &time_zone::asia::SHANGHAI,
            time_zone::asia::RAW_SHANGHAI,
            &[
                b"Asia/Shanghai",
                b"asia/shanghai",
                b"ASIA/SHANGHAI",
                b"aSIA/sHANGHAI",
                b"AsIa/sHaNgHaI",
                b"aSiA/ShAnGhAi",
            ],
        ),
        (&time_zone::PST_8_PDT, time_zone::RAW_PST_8_PDT, &[
            b"PST8PDT", b"pst8pdt", b"PST8PDT", b"pst8pdt", b"PsT8PdT", b"pSt8pDt",
        ]),
        (
            &time_zone::america::LOS_ANGELES,
            time_zone::america::RAW_LOS_ANGELES,
            &[
                b"America/Los_Angeles",
                b"america/los_angeles",
                b"AMERICA/LOS_ANGELES",
                b"aMERICA/lOS_aNGELES",
                b"AmErIcA/LoS_AnGeLeS",
                b"aMeRiCa/lOs_aNgElEs",
            ],
        ),
        (&time_zone::us::PACIFIC, time_zone::us::RAW_PACIFIC, &[
            b"US/Pacific",
            b"us/pacific",
            b"US/PACIFIC",
            b"us/pACIFIC",
            b"Us/pAcIfIc",
            b"uS/PaCiFiC",
        ]),
        (&time_zone::ROC, time_zone::RAW_ROC, &[
            b"ROC", b"roc", b"ROC", b"roc", b"RoC", b"rOc",
        ]),
        (&time_zone::asia::TAIPEI, time_zone::asia::RAW_TAIPEI, &[
            b"Asia/Taipei",
            b"asia/taipei",
            b"ASIA/TAIPEI",
            b"aSIA/tAIPEI",
            b"AsIa/tAiPeI",
            b"aSiA/TaIpEi",
        ]),
        (&time_zone::ROK, time_zone::RAW_ROK, &[
            b"ROK", b"rok", b"ROK", b"rok", b"RoK", b"rOk",
        ]),
        (&time_zone::asia::SEOUL, time_zone::asia::RAW_SEOUL, &[
            b"Asia/Seoul",
            b"asia/seoul",
            b"ASIA/SEOUL",
            b"aSIA/sEOUL",
            b"AsIa/sEoUl",
            b"aSiA/SeOuL",
        ]),
        (&time_zone::SINGAPORE, time_zone::RAW_SINGAPORE, &[
            b"Singapore",
            b"singapore",
            b"SINGAPORE",
            b"sINGAPORE",
            b"SiNgApOrE",
            b"sInGaPoRe",
        ]),
        (
            &time_zone::asia::SINGAPORE,
            time_zone::asia::RAW_SINGAPORE,
            &[
                b"Asia/Singapore",
                b"asia/singapore",
                b"ASIA/SINGAPORE",
                b"aSIA/sINGAPORE",
                b"AsIa/sInGaPoRe",
                b"aSiA/SiNgApOrE",
            ],
        ),
        (&time_zone::TURKEY, time_zone::RAW_TURKEY, &[
            b"Turkey", b"turkey", b"TURKEY", b"tURKEY", b"TuRkEy", b"tUrKeY",
        ]),
        (
            &time_zone::asia::ISTANBUL,
            time_zone::asia::RAW_ISTANBUL,
            &[
                b"Asia/Istanbul",
                b"asia/istanbul",
                b"ASIA/ISTANBUL",
                b"aSIA/iSTANBUL",
                b"AsIa/iStAnBuL",
                b"aSiA/IsTaNbUl",
            ],
        ),
        (
            &time_zone::europe::ISTANBUL,
            time_zone::europe::RAW_ISTANBUL,
            &[
                b"Europe/Istanbul",
                b"europe/istanbul",
                b"EUROPE/ISTANBUL",
                b"eUROPE/iSTANBUL",
                b"EuRoPe/iStAnBuL",
                b"eUrOpE/IsTaNbUl",
            ],
        ),
        (&time_zone::UCT, time_zone::RAW_UCT, &[
            b"UCT", b"uct", b"UCT", b"uct", b"UcT", b"uCt",
        ]),
        (&time_zone::UNIVERSAL, time_zone::RAW_UNIVERSAL, &[
            b"Universal",
            b"universal",
            b"UNIVERSAL",
            b"uNIVERSAL",
            b"UnIvErSaL",
            b"uNiVeRsAl",
        ]),
        (&time_zone::UTC, time_zone::RAW_UTC, &[
            b"UTC", b"utc", b"UTC", b"utc", b"UtC", b"uTc",
        ]),
        (&time_zone::ZULU, time_zone::RAW_ZULU, &[
            b"Zulu", b"zulu", b"ZULU", b"zULU", b"ZuLu", b"zUlU",
        ]),
        (&time_zone::etc::UCT, time_zone::etc::RAW_UCT, &[
            b"Etc/UCT", b"etc/uct", b"ETC/UCT", b"eTC/uct", b"EtC/UcT", b"eTc/uCt",
        ]),
        (
            &time_zone::etc::UNIVERSAL,
            time_zone::etc::RAW_UNIVERSAL,
            &[
                b"Etc/Universal",
                b"etc/universal",
                b"ETC/UNIVERSAL",
                b"eTC/uNIVERSAL",
                b"EtC/UnIvErSaL",
                b"eTc/uNiVeRsAl",
            ],
        ),
        (&time_zone::etc::UTC, time_zone::etc::RAW_UTC, &[
            b"Etc/UTC", b"etc/utc", b"ETC/UTC", b"eTC/utc", b"EtC/UtC", b"eTc/uTc",
        ]),
        (&time_zone::etc::ZULU, time_zone::etc::RAW_ZULU, &[
            b"Etc/Zulu",
            b"etc/zulu",
            b"ETC/ZULU",
            b"eTC/zULU",
            b"EtC/ZuLu",
            b"eTc/zUlU",
        ]),
        (&time_zone::W_SU, time_zone::RAW_W_SU, &[
            b"W-SU", b"w-su", b"W-SU", b"w-su", b"W-Su", b"w-sU",
        ]),
        (
            &time_zone::europe::MOSCOW,
            time_zone::europe::RAW_MOSCOW,
            &[
                b"Europe/Moscow",
                b"europe/moscow",
                b"EUROPE/MOSCOW",
                b"eUROPE/mOSCOW",
                b"EuRoPe/mOsCoW",
                b"eUrOpE/MoScOw",
            ],
        ),
    ];

    for &(tz, raw, names) in TIME_ZONES {
        for name in names {
            assert_eq!(Some(tz), find_tz(name), "find_tz({:?})", name);
            assert_eq!(Some(raw), find_raw(name), "find_raw({:?})", name);
        }
    }
}
